# ------------------------------------------------------------------------------
#
#	FILENAME
#		Additions.make
#
#	DESCRIPTION
#		This is the make file for the Additions printing extension.
#
#	COPYRIGHT
#		Copyright Apple Computer, Inc. 1991-1994
#		All rights reserved. 
#	
#	MODIFICATION HISTORY
#		05/15/91			ALA			Initial implementation
#		10/22/92			Duano		Added changes for version control
#		12/22/93			dmh			Made makefile self-supporting for b3.
#		 8/26/94			dmh			Finalized for the SDK.
#
#-------------------------------------------------------------------------------

# Change the following identifiers to point to your
# GX interface & library files.

GXPrintingInterfaces	=	{CIncludes}
GXGraphicsInterfaces	=	{GXPrintingInterfaces}
GXPrintingLibs			=	Backwash:QuickDraw GX Libraries:printing libraries:
GXGraphicsLibs			=	Backwash:QuickDraw GX Libraries:graphics libraries:


#========== Directories Containing Source and Object Files ==========

SourceFiles		= 
Objects			= :Objects:
OutputDir		=

#========== Compile, Assemble, and Link Options ==========

AsmOptions		= -sym off -i {GXPrintingInterfaces} -case obj
CompileOptions	= -mbg full -sym off  -d applec -opt full -b2 -r -i {GXPrintingInterfaces} -i {GXGraphicsInterfaces}
RezOptions		= -i {GXPrintingInterfaces} -d SystemSevenOrLater=1

#========== Files to Link With ==========

CObjs			=	"{Objects}Additions.a.o" 				
					"{Objects}Additions.c.o"				
					"{Objects}InitializeMessage.c.o"		
					"{Objects}DespoolPageMessage.c.o"		
					"{Objects}FinishJobMessage.c.o"			
					"{Objects}PrintDialogMessage.c.o"		
					"{Objects}RenderPageMessage.c.o"		
					"{Objects}StartJobMessage.c.o"			
					"{Objects}Utilities.c.o"				
					
					"{Objects}picture library.c.o"			
					"{Objects}font library.c.o"				
					"{Objects}roundRect library.c.o"		
					"{Objects}shape library.c.o"			
					
					{CLibraries}StdCLib.o					
					{Libraries}Runtime.o					
					{Libraries}Interface.o

#========== Compile Build Statements - font library.c ==========

"{Objects}font library.c.o"		"{GXGraphicsLibs}font library.c"
	Echo "Compiling font library.c"
	C {CompileOptions} "{GXGraphicsLibs}font library.c" 
	  -o "{Objects}font library.c.o"

#========== Compile Build Statements - roundRect library.c.c ==========

"{Objects}roundRect library.c.o"		"{GXGraphicsLibs}roundRect library.c"
	Echo "Compiling roundRect library.c"
	C {CompileOptions} "{GXGraphicsLibs}roundRect library.c"  
	  -o "{Objects}roundRect library.c.o"

#========== Compile Build Statements - shape library.c ==========

"{Objects}shape library.c.o"		"{GXGraphicsLibs}shape library.c"
	Echo "Compiling shape library.c"
	C {CompileOptions} "{GXGraphicsLibs}shape library.c"  
	  -o "{Objects}shape library.c.o"

#=== Compile Build Statements - picture library.c ====

"{Objects}picture library.c.o"	 "{GXGraphicsLibs}picture library.c"
	Echo "Compiling picture library.c"
	C {CompileOptions} "{GXGraphicsLibs}picture library.c" 
	  -o "{Objects}picture library.c.o"

#========== Assembly Build Statements - Additions.a ==========

{Objects}Additions.a.o		{SourceFiles}Additions.a
	Echo "Assembling Additions.a"
	Asm {AsmOptions}  {SourceFiles}Additions.a -o {Objects}Additions.a.o

#========== Compile Build Statements - Additions.c ==========

{Objects}Additions.c.o		{SourceFiles}Additions.c			
									{SourceFiles}Additions.h	
									{SourceFiles}Utilities.h
	Echo "Compiling Additions.c"
	C {CompileOptions} {SourceFiles}Additions.c  -o {Objects}Additions.c.o


#========== Compile Build Statements - InitializeMessage.c ==========

{Objects}InitializeMessage.c.o		{SourceFiles}InitializeMessage.c	
									{SourceFiles}Additions.h
	Echo "Compiling InitializeMessage.c"
	C {CompileOptions} {SourceFiles}InitializeMessage.c  -o {Objects}InitializeMessage.c.o


#========== Compile Build Statements - DespoolPageMessage.c ==========

{Objects}DespoolPageMessage.c.o		{SourceFiles}DespoolPageMessage.c	
									{SourceFiles}Additions.h			
									{SourceFiles}Utilities.h		
	Echo "Compiling DespoolPageMessage.c"
	C {CompileOptions} {SourceFiles}DespoolPageMessage.c  -o {Objects}DespoolPageMessage.c.o


#========== Compile Build Statements - FinishJobMessage.c ==========

{Objects}FinishJobMessage.c.o		{SourceFiles}FinishJobMessage.c		
									{SourceFiles}Additions.h			
									{SourceFiles}Utilities.h		
	Echo "Compiling FinishJobMessage.c"
	C {CompileOptions} {SourceFiles}FinishJobMessage.c  -o {Objects}FinishJobMessage.c.o


#========== Compile Build Statements - PrintDialogMessage.c ==========

{Objects}PrintDialogMessage.c.o		{SourceFiles}PrintDialogMessage.c	
									{SourceFiles}Additions.h			
									{SourceFiles}Utilities.h		
	Echo "Compiling PrintDialogMessage.c"
	C {CompileOptions} {SourceFiles}PrintDialogMessage.c  -o {Objects}PrintDialogMessage.c.o


#========== Compile Build Statements - RenderPageMessage.c ==========

{Objects}RenderPageMessage.c.o		{SourceFiles}RenderPageMessage.c	
									{SourceFiles}Additions.h			
									{SourceFiles}Utilities.h		
	Echo "Compiling RenderPageMessage.c"
	C {CompileOptions} {SourceFiles}RenderPageMessage.c  -o {Objects}RenderPageMessage.c.o


#========== Compile Build Statements - StartJobMessage.c ==========

{Objects}StartJobMessage.c.o		{SourceFiles}StartJobMessage.c	
									{SourceFiles}Additions.h		
									{SourceFiles}Utilities.h		
	Echo "Compiling StartJobMessage.c"
	C {CompileOptions} {SourceFiles}StartJobMessage.c  -o {Objects}StartJobMessage.c.o


#========== Compile Build Statements - Utilities.c ==========

{Objects}Utilities.c.o		{SourceFiles}Utilities.c		
							{SourceFiles}Additions.h		
							{SourceFiles}Additions.h	
	Echo "Compiling Utilities.c"
	C {CompileOptions} {SourceFiles}Utilities.c  -o {Objects}Utilities.c.o


#========== Link and Rez Build Statements ==========

{OutputDir}Additions 		{CObjs}							
									{SourceFiles}Additions.r		
									{SourceFiles}Additions.make
	Echo "Linking Additions Printing Extension"
	Link	-ra =resSysHeap,resPurgeable 
			-t 'pext'			
			-c 'addi'			
			-rt pext=0			
			-sg Additions		
			-m AdditionsIntf	
			{CObjs}				
			-o {OutputDir}Additions;
	SetFile {OutputDir}Additions -a iB;
	Echo "Rezzing Additions Printing Extension"
	Rez {RezOptions} -rd -o {OutputDir}Additions {SourceFiles}Additions.r -append
