/*________________________________________________

	File: Back2Front.r
		
	Rez file for a printing extension.

	Dave Hersey
	Apple Developer Technical Support

	 3/22/94 - dmh - Created.
	 5/03/94 - dmh - Updated for f2.

	(Note: resource labels are in the Mark menu)

  ________________________________________________*/

#include "SysTypes.r"
#include "Types.r"
#include "PrintingResTypes.h"
#include "PrintingResTypes.r"

#define kCreator			'B2Fr'			/* This is our creator type.		*/

#define r_FinderBNDL		128				/* Finder BNDL & icon IDs.			*/
#define r_ExtensionPanel	6000			/* ID of our panel and panel icon.	*/


/*=================== Print Dialog Panel Related Resources ==================== */


/*==== Description of the panel resource added to print dialog by extension ==== */

resource gxPrintPanelType (r_ExtensionPanel, sysheap, purgeable)
{
		"Back2Front", smRoman, r_ExtensionPanel, r_ExtensionPanel
};


resource 'DITL' (r_ExtensionPanel, sysheap, purgeable)
{
	{
		/* [1] */
		{41, 122, 59, 230},
		CheckBox {
			enabled,
			"Print Pages in Reverse Order"
		}
	}
};

resource 'DITL' (r_ExtensionPanel, sysheap, purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{45, 67, 63, 277},
		CheckBox {
			enabled,
			"Print Pages in Reverse Order"
		},
		/* [2] */
		{2, 129, 21, 216},
		StaticText {
			disabled,
			"Back2Front"
		},
		/* [3] */
		{87, 28, 121, 317},
		StaticText {
			disabled,
			"Selecting this checkbox will cause your "
			"document to be printed from back to front."
		}
	}
};


/*======= 'xdtl' describing how to process the items in the Print Dialog Panel ======= */

resource 'xdtl' (r_ExtensionPanel, sysheap, purgeable)
{
	{
/*	This is the xdtl declaration for a checkbox which
	consist of DITL item 1, and whose value should be
	stored in a collection item of tag kCreator, and ID
	gxPrintingTagID.  We also specify that the data should be
	stored at offset 0 in that collection item.  See the
	ExtensionCollection declaration in Back2Front.h to better
	understand this.  The data we store is the value of the
	checkbox.  So, if 0 is stored, that means the control was
	not selected, if 1 was stored, that means it was selected.	*/

		CheckBox { kCreator, gxPrintingTagID, 0, 1 }
	};
};


/*=================== Required Printing Extension Types and Resources =================== */


/*======= Scope ('scop') Resource ======= */

/*	This resource tells the printing system which types
	of drivers we work with.  (We work with all of them.) */

resource gxExtensionScopeType (gxDriverScopeID, sysheap, purgeable)
{
	{
		gxAnyPrinterType		
	};
};


/*======= Message Override ('over') Resource ======= */

/*	This resource tells the printing system which messages we
	want to override and where the override code is located. */

resource gxOverrideType (gxExtensionUniversalOverrideID, sysheap, purgeable)
{
	{
		// message to override	segmentID		offset into jump table
		gxInitialize, 				0, 					 4,
		gxShutDown, 				0, 					 8,
		gxJobPrintDialog, 			0, 			  		12,
		gxImageDocument,			0, 			  		16
	};
};


/*======= Extension Optimization ('eopt') Resource ======= */

/*	This resource tells the printing system at which times we'll
	be doing things so that it can optimize for us.  */

resource gxExtensionOptimizationType (gxExtensionOptimizationID, sysheap, purgeable)
{
	gxExecuteDuringImaging,
	gxDontNeedDeviceStatus,
	gxDontChangePageAtGXDespoolPage,
	gxDontChangePageAtGXImagePage,
	gxDontChangePageAtGXRenderPage,
	gxNotServerPresenceRequired,
	gxClientPresenceRequired
};


/*======= Extension Load ('load') Resource ======= */

/*	This resource tells the printing system where we want
	to be loaded in the handler chain.  We don't care
	where we load.	*/

resource gxExtensionLoadType (gxExtensionLoadID, sysheap, purgeable)
{
	gxExtensionLoadAnywhere
};


/*================ 'vers' resource that's required by all extensions ================== */

/*	The first byte of this resource must be zero or one for
	this extension to be compatible with GX v1.0.  The
	remainder of the data is ignored.						*/

resource 'vers' (gxPrintingExtensionBaseID, sysheap, purgeable) {
	0x0,
	0x0,
	release,
	0x0,
	verUS,
	"",
	""
};


/*=================== Standard 'vers', bundle and icon resources follow =================== */

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0,  Apple Computer, Inc. 1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"Back2Front Extension v1.0"
};


resource 'BNDL' (r_FinderBNDL, sysheap, purgeable) {
	kCreator,
	0,
	{
		'ICN#', {0, r_FinderBNDL},
		'FREF', {0, r_FinderBNDL}
	}
};


resource 'FREF' (r_FinderBNDL, sysheap, purgeable) {
	gxPrintingExtensionType,
	0,
	""
};


Type kCreator as 'STR ';

resource kCreator (0, "Owner resource", sysheap, purgeable) {
	"This is the Back2Front printing extension."
};


resource 'ics8' (r_FinderBNDL, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'ics4' (r_FinderBNDL, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFFF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FCC CCCC CCCC CCCF FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0"
	$"FCCC CCCC CCCC CCF0 FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FFF FFFF FFFF FFFF"
};


resource 'ics#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFF 4001 4001 4001 C003 C003 8002 8002 8002 8002 C003 C003"
		$"4001 4001 4001 7FFF",
		/* [2] */
		$"7FFF 7FFF 7FFF 7FFF FFFF FFFF FFFE FFFE FFFE FFFE FFFF FFFF"
		$"7FFF 7FFF 7FFF 7FFF"
	}
};


resource 'ICN#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0FFF FFFE 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 1000 0001 1000 0005 5000 000B B000 0009 9000 0008"
		$"8000 0008 8000 0008 8000 0008 8000 0008 8000 0008 8000 0008"
		$"8000 0008 8000 0008 8000 0008 B000 0009 5000 000B 1000 0005"
		$"1000 0001 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 0FFF FFFE",
		/* [2] */
		$"0FFF FFFE 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 5FFF FFFB FFFF FFF9 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF9 5FFF FFFB 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 0FFF FFFE"
	}
};


resource 'icl8' (r_FinderBNDL, sysheap, purgeable) {
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FF00 0000 00FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 FFFF FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 00FF FF00 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 00FF 00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'icl4' (r_FinderBNDL, sysheap, purgeable) {
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFF0 000F 0000 0000 0000"
	$"0000 0000 0000 000F 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"0F0F 0CCC CCCC CCCC CCCC CCCC CCCC F0FF F0FF 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F00F F00F 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CF 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0FF 0CCC CCCC CCCC CCCC CCCC CCCC F00F 0F0F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F0FF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFF0"
};

resource 'ics8' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 0000 0000 0000 FFFF 0000 FFFF 0000 0000 0000 0000 0000 FFFF"
	$"0000 FFFF 0000 0000 0000 0000 0000 00FF FFFF FF00 0000 0000 0000"
	$"0000 0000 00FF FFFF FF00 0000 0000 0000 0000 00FF FFFF 0000 FFFF"
	$"0000 0000 0000 00FF FFFF FF00 FFFF 00FF 0000 0000 00FF FF17 05FF"
	$"00FF FFFF FF00 0000 0000 FFFF B717 05FF FFFF FFFF FF00 0000 00FF"
	$"FFB7 B717 1705 FF00 00FF FFFF FF00 FFFF B7B7 B7B7 1705 FFFF FFFF"
	$"FFFF FFFF FF90 0CB7 B7B7 1717 FFFF FF9C 9C9C FFFF FF90 900C B7B7"
	$"23FF FF9C 9C90 9090 90FF FF90 9090 0CFF FFFF 059C 9C90 0CB8 B8FF"
	$"FF11 9C9C 18FF FF11 A89C 9C90 B8B8 B8FF FFFF 9C9C 18E3 FFFF FFFF"
	$"9090 B8B8 05FF 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics4' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 0000 FF00 FF00 0000 0000 FF00 FF00 0000 0000 0FFF F000 0000"
	$"0000 0FFF F000 0000 000F FF00 FF00 0000 0FFF F0FF 0F00 000F F21F"
	$"0FFF F000 00FF 821F FFFF F000 0FF8 8221 F00F FFF0 FF88 8821 FFFF"
	$"FFFF F708 8822 FFF7 77FF F770 883F F777 777F F777 0FFF 1777 088F"
	$"F277 4FF2 6777 888F FF77 48FF FF77 881F 0FFF FFFF FFFF FFFF"
};

resource 'ics#' (r_ExtensionPanel, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"00CC 00CC 0078 0078 01CC 07B4 1978 31F8 609E C0FF 80E3 8381 8701"
		$"8681 C7C1 7FFF",
		/* [2] */
		$"00CC 00CC 0078 0078 01FC 07FC 1FF8 3FF8 7FFE FFFF FFFF FFFF FFFF"
		$"FFFF FFFF 7FFF"
	}
};

resource 'ICN#' (r_ExtensionPanel, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 2040 0000 50A0 0000 50A0 0000 50A0 0000 2940 0000 2940 0000"
		$"1980 0000 1F80 0000 2040 0003 4020 000D 4920 0031 4020 00C1 2040"
		$"0181 1680 0201 0F00 0400 B0C0 0800 C03C 1000 C3F4 2000 4224 6000"
		$"7DC2 4000 4406 8000 7802 8008 C002 800F 0001 800E 0001 8018 0001"
		$"8018 0001 C00C 4001 401F E001 301F F002 181F FE0E 07FF CFF8",
		/* [2] */
		$"0000 2040 0000 70E0 0000 70E0 0000 70E0 0000 39C0 0000 39C0 0000"
		$"1980 0000 1F80 0000 3FC0 0003 7FE0 000F 7FE0 003F 7FE0 00FF 3FC0"
		$"01FF 1F80 03FF 0F00 07FF BFC0 0FFF FFFC 1FFF FFFC 3FFF FFFC 7FFF"
		$"FFFE 7FFF FFFE FFFF FFFE FFFF FFFE FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF 7FFF FFFF 3FFF FFFE 1FFF FFFE 07FF CFF8"
	}
};

resource 'icl8' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 FF00 0000 0000 00FF"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 00FF 00FF"
	$"0000 0000 FF00 FF00 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 00FF 00FF 0000 0000 FF00 FF00 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 00FF 00FF 0000 0000 FF00 FF00 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 FF00 FF00 00FF 00FF 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 FF00 FF00"
	$"00FF 00FF 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 00FF FF00 00FF FF00 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 00FF FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 FF00 0000 0000 00FF 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 FFFF 00FF 0000 0000 0000"
	$"0000 FF00 0000 0000 0000 0000 0000 0000 0000 0000 FFFF 05FF 00FF"
	$"0000 FF00 00FF 0000 FF00 0000 0000 0000 0000 0000 0000 0000 FFFF"
	$"0505 05FF 00FF 0000 0000 0000 0000 FF00 0000 0000 0000 0000 0000"
	$"0000 FFFF 1705 0505 05FF 0000 FF00 0000 0000 00FF 0000 0000 0000"
	$"0000 0000 0000 00FF FF17 1705 0505 05FF 0000 00FF 00FF FF00 FF00"
	$"0000 0000 0000 0000 0000 0000 FFB7 1717 1717 0505 05FF 0000 0000"
	$"FFFF FFFF 0000 0000 0000 0000 0000 0000 00FF B7B7 B717 1717 0505"
	$"0505 FF00 FFFF 0000 0000 FFFF 0000 0000 0000 0000 0000 FFB7 B7B7"
	$"B7B7 1717 1705 0505 FFFF 0000 0000 0000 0000 FFFF FFFF 0000 0000"
	$"00FF B7B7 B7B7 B7B7 1717 1705 0505 FFFF 0000 0000 FFFF FFFF FFFF"
	$"9CFF 0000 0000 FF0C 0CB7 B7B7 B7B7 B717 1717 0505 05FF 0000 0000"
	$"FF00 0000 FF9C 9CFF 0000 00FF FF0C 0CB7 0CB7 B7B7 1717 1705 0505"
	$"05FF FFFF FFFF 9CFF FFFF 9C9C 9C90 FF00 00FF 0C0C 0C0C 0CB7 B7B7"
	$"B717 1717 0505 05FF 0000 00FF 9C9C 9C9C 9C9C 90FF FF00 FF90 900C"
	$"0C0C 0CB7 0CB7 B717 1717 1717 17FF FFFF FF9C 9C9C 909C 9090 9090"
	$"FF00 FF90 9090 900C 0C0C 0CB7 1717 2317 1717 FFFF 059C 9C9C 9090"
	$"9090 9090 900C FF00 FF05 9090 900C 0C0C 0C0C B717 2323 FFFF 0505"
	$"0505 9C9C 9090 0C0C 0C90 0C0C 0CFF FF05 1190 9090 900C 0C0C B7B7"
	$"FFFF FF11 0505 059C 9C90 9090 0C0C 0C0C 0C0C 0CFF FF11 1105 9090"
	$"9090 0C0C 0CFF FF11 1111 0505 059C 9C9C 900C 0C0C 0CB8 B8B8 B8FF"
	$"FF11 1105 9090 900C 0C0C B7FF FF11 1111 1111 9C9C 9C90 9090 0C0C"
	$"B8B8 B8B8 B8FF FFFF 1111 119C 909C 0C18 18B7 FFFF 1111 11A8 9C9C"
	$"9C90 9090 0CB8 B8B8 B8B8 B8FF 00FF 1111 9C9C 9C9C 1818 18E3 E3FF"
	$"FFFF FFA8 A89C 9090 900C 0C0C B8B8 0505 05FF 0000 FFFF 119C 9C9C"
	$"1818 18E3 E3E3 E3FF FFFF FFFF 9090 0C0C B8B8 B805 0505 FF00 0000"
	$"00FF FF9C 9C9C 1818 18E3 E3E3 E3E3 E3FF FFFF FFFF FF0C 0CB8 B8B8"
	$"FFFF FF00 0000 0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF 0000 FFFF"
	$"FFFF FFFF FFFF FF"
};

resource 'icl4' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 0000 0000 0000 00F0 0000 0F00 0000 0000 0000 0000 0000 0F0F"
	$"0000 F0F0 0000 0000 0000 0000 0000 0F0F 0000 F0F0 0000 0000 0000"
	$"0000 0000 0F0F 0000 F0F0 0000 0000 0000 0000 0000 00F0 F00F 0F00"
	$"0000 0000 0000 0000 0000 00F0 F00F 0F00 0000 0000 0000 0000 0000"
	$"000F F00F F000 0000 0000 0000 0000 0000 000F FFFF F000 0000 0000"
	$"0000 0000 0000 00F0 0000 0F00 0000 0000 0000 0000 00FF 0F00 0000"
	$"00F0 0000 0000 0000 0000 FF1F 0F00 F00F 00F0 0000 0000 0000 00FF"
	$"111F 0F00 0000 00F0 0000 0000 0000 FF21 111F 00F0 0000 0F00 0000"
	$"0000 000F F221 111F 000F 0FF0 F000 0000 0000 00F8 2222 111F 0000"
	$"FFFF 0000 0000 0000 0F88 8222 1111 F0FF 0000 FF00 0000 0000 F888"
	$"8822 2111 FF00 0000 00FF FF00 000F 8888 8822 2111 FF00 00FF FFFF"
	$"7F00 00F0 0888 8882 2211 1F00 00F0 00F7 7F00 0FF0 0808 8822 2111"
	$"1FFF FF7F FF77 77F0 0F00 0008 8882 2211 1F00 0F77 7777 7FF0 F770"
	$"0008 0882 2222 2FFF F777 7777 77F0 F777 7000 0822 3222 FF17 7777"
	$"7777 70F0 F177 7000 0082 33FF 1111 7777 0007 000F F127 7770 0088"
	$"FFF2 1117 7777 0000 000F F221 7777 000F F222 1117 7770 0008 888F"
	$"F221 7770 008F F222 2277 7777 0088 888F FF22 2777 0448 FF22 2677"
	$"7777 0888 888F 0F22 7777 4448 8FFF F667 7770 0088 111F 00FF 2777"
	$"4448 888F FFFF 7700 8881 11F0 000F F777 4448 8888 8FFF FFF0 0888"
	$"FFF0 0000 0FFF FFFF FFFF FF00 FFFF FFFF F0"
};
