/*________________________________________________________

	File: Backwash.r
	
	Rez file for a printing extension that adds a
	QuickDraw picture to each page despooled.

	Dave Hersey
	Apple Developer Technical Support

	11/11/92 - dmh - Created.
	 1/28/93 - dmh - Cleaned up for a5 seed CD.
	 3/26/93 - dmh - Updated for b1c2 (Translator changes).
	 8/24/93 - dmh - Updated for b2.
	 		 - The picture is now rolled into the spool
			   file as a resource, and applied to each
			   page during despooling.
			 - Added a TextEdit compatibility mode which
			   strips out the white rectangles drawn by
			   apps which use TextEdit to print (like
			   TeachText).
			 - The "intensity" panel item actually
			   functions now.
			 - Switched to Exception.h assertion stuff
			   for error checking.
	 9/09/93 - dmh - AddBackwash now displays progress info.
	12/18/93 - dmh - Updated for b3.
	 3/22/94 - dmh - Updated for b4.
	 5/03/94 - dmh - Updated for f2.
	 8/26/94 - dmh - Finalized for SDK (added 'open' resource).

	(Note: resource types are in the Mark menu.)

__________________________________________________________*/

#include "SysTypes.r"
#include "Types.r"
#include "GXPrintingResTypes.r"
#include "GXPrintingResEquates.r"

#define kCreator				'SpIT'
#define r_backwashPanel			6000
#define r_backwashPanelIcon		240
#define r_backwashBNDL			128

#define r_BackwashStatus		1000


/*================= Resource required to avoid EasyOpen dialog =============== */

resource 'open' (128, sysheap, purgeable)
{
	kCreator,
	{'PICT'}
};


/*=================== Print Dialog Panel-related Resources =================== */


/*======= Description of the panel resource added to Print Dialog by Backwash ======= */

resource gxPrintPanelType (r_backwashPanel, sysheap, purgeable)
{
	"Backwash", smRoman, r_backwashPanelIcon, r_backwashPanel
};


resource 'DITL' (r_backwashPanel, sysheap, purgeable)
{
	{
		/* [1] */
		{2, 115, 18, 240},
		StaticText {
			disabled,
			"Picture Backwash"
		},
		/* [2] */
		{26, 134, 44, 180},
		RadioButton {
			enabled,
			"Off"
		},
		/* [3] */
		{26, 182, 44, 227},
		RadioButton {
			enabled,
			"On"
		},
		/* [4] */
		{107, 5, 125, 143},
		StaticText {
			disabled,
			"Backwash intensity:"
		},
		/* [5] */
		{109, 148, 125, 176},
		EditText {
			enabled,
			""
		},
		/* [6] */
		{109, 180, 125, 195},
		StaticText {
			disabled,
			"%"
		},
		/* [7] */
		{53, 131, 73, 220},
		Button {
			enabled,
			"Select PICT"
		},
		/* [8] */
		{81, 5, 97, 113},
		StaticText {
			disabled,
			"Current picture:"
		},
		/* [9] */
		{81, 114, 99, 332},
		StaticText {
			disabled,
			""
		},
		/* [10] */
		{135, 5, 153, 237},
		CheckBox {
			enabled,
			"Application prints with TextEdit."
		},
	}
};


/*======= 'xdtl' describing how to process the items in the Print Dialog Panel ======= */

resource 'xdtl' (r_backwashPanel, sysheap, purgeable)
{
	{
// 			Type			tag	    tag item ID	 		data offset  DITL item(s) other

		EditTextInteger	{ kCreator, gxPrintingExtensionBaseID,	0,	5,	0, "5", "100" },
		RadioButtons	{ kCreator, gxPrintingExtensionBaseID,	4,	{2,3}},
		CheckBox		{ kCreator, gxPrintingExtensionBaseID,	5,	10}
	};
};


/*================== Required Printing Extension Types and Resources ================= */


/*======= Scope ('scop') Resource ======= */

/*	This resource tells the printing system which drivers
	we work with.  (We work with PostScript and Raster.)
*/

resource gxExtensionScopeType (gxDriverScopeID, sysheap, purgeable)
{
	{
		gxPostScriptPrinterType,
		gxRasterPrinterType	
	};
};


/*======= Message Override ('over') Resource ======= */

/*	This resource tells the printing system which messages we
	want to override and where the override code is located. */

resource gxOverrideType (gxExtensionUniversalOverrideID, sysheap, purgeable)
{
	{
		// message to override	segmentID	offset into jump table

		gxInitialize,				0, 				4,
		gxShutDown,					0, 				8,
		gxJobPrintDialog,			0, 				12,
		gxHandlePanelEvent,			0, 				16,
		gxCreateSpoolFile,			0,				20,
		gxDespoolPage,				0,				24,
		gxCloseSpoolFile,			0, 				28
	};
};


/*======= Extension Optimization ('eopt') Resource ======= */

/*	This resource tells the printing system at which times
	we'll be doing things, so that it can optimize for us.  */

resource gxExtensionOptimizationType (gxExtensionOptimizationID, sysheap, purgeable)
{
	gxDontExecuteDuringImaging,
	gxDontNeedDeviceStatus,
	gxChangePageAtGXDespoolPage,
	gxDontChangePageAtGXImagePage,
	gxDontChangePageAtGXRenderPage,
	gxNotServerPresenceRequired,
	gxClientPresenceRequired
};


/*======= Extension Load ('load') Resource ======= */

/*	This resource tells the printing system where we want
	to be loaded in the handler chain.  We'd liked to be
	last to execute so we can modify the final shape to
	be despooled.  Last to execute == first to load.			*/

resource gxExtensionLoadType (gxExtensionLoadID, sysheap, purgeable)
{
	gxExtensionLoadFirst
};



/*	These resources are used to display status messages while
	Backwash is loading, converting, and adding the backwash
	shape.  Note that we can't use the status handling
	messages, because those only work when PrinterShare GX
	or the Finder have control.  We'll be displaying this info
	during spooling, when the user's application has control.	*/

resource 'STR#' (r_BackwashStatus, sysheap, purgeable)
{
	{
		"Loading Backwash picture",
		"Converting Backwash picture to a QuickDraw GX shape",
		"Adjusting intensity of Backwash shape",
		"Adding Backwash shape to print file",
		"ERROR - Unable to load Backwash picture.  File may be busy or missing."
	}
};


resource 'DLOG' (r_BackwashStatus, sysheap, purgeable)
{
	{73, 67, 186, 327},
	dBoxProc,
	invisible,
	goAway,
	0x0,
	r_BackwashStatus,
	""
};


resource 'DITL' (r_BackwashStatus, sysheap, purgeable)
{
	{
		{20, 46, 81, 253},
		StaticText {
			disabled,
			""
		},
		{78, 227, 110, 259},
		Picture {
			disabled,
			r_BackwashStatus
		},
		{3, 3, 35, 35},
		Icon {
			disabled,
			1
		}
	}
};


resource 'PICT' (r_BackwashStatus, sysheap, purgeable)
{
	2606,
	{0, 0, 32, 32},
	$"0011 02FF 0C00 FFFF FFFF 0000 0000 0000 0000 0020 0000 0020"
	$"0000 0000 0000 00A0 0082 0001 000A 0000 0000 0020 0020 0098"
	$"8020 0000 0000 0020 0020 0000 0000 0000 0000 0048 0000 0048"
	$"0000 0000 0008 0001 0008 0000 0000 0034 D350 0000 0000 0000"
	$"0008 0000 00FF 0000 FFFF FFFF FFFF 0001 FFFF FFFF CCCC 0002"
	$"FFFF FFFF 9999 0003 FFFF FFFF 6666 0004 FFFF FFFF 3333 0005"
	$"FFFF FFFF 0000 0006 FFFF CCCC FFFF 0007 FFFF CCCC CCCC 0008"
	$"FFFF CCCC 9999 0009 FFFF CCCC 6666 000A FFFF CCCC 3333 000B"
	$"FFFF CCCC 0000 000C FFFF 9999 FFFF 000D FFFF 9999 CCCC 000E"
	$"FFFF 9999 9999 000F FFFF 9999 6666 0010 FFFF 9999 3333 0011"
	$"FFFF 9999 0000 0012 FFFF 6666 FFFF 0013 FFFF 6666 CCCC 0014"
	$"FFFF 6666 9999 0015 FFFF 6666 6666 0016 FFFF 6666 3333 0017"
	$"FFFF 6666 0000 0018 FFFF 3333 FFFF 0019 FFFF 3333 CCCC 001A"
	$"FFFF 3333 9999 001B FFFF 3333 6666 001C FFFF 3333 3333 001D"
	$"FFFF 3333 0000 001E FFFF 0000 FFFF 001F FFFF 0000 CCCC 0020"
	$"FFFF 0000 9999 0021 FFFF 0000 6666 0022 FFFF 0000 3333 0023"
	$"FFFF 0000 0000 0024 CCCC FFFF FFFF 0025 CCCC FFFF CCCC 0026"
	$"CCCC FFFF 9999 0027 CCCC FFFF 6666 0028 CCCC FFFF 3333 0029"
	$"CCCC FFFF 0000 002A CCCC CCCC FFFF 002B CCCC CCCC CCCC 002C"
	$"CCCC CCCC 9999 002D CCCC CCCC 6666 002E CCCC CCCC 3333 002F"
	$"CCCC CCCC 0000 0030 CCCC 9999 FFFF 0031 CCCC 9999 CCCC 0032"
	$"CCCC 9999 9999 0033 CCCC 9999 6666 0034 CCCC 9999 3333 0035"
	$"CCCC 9999 0000 0036 CCCC 6666 FFFF 0037 CCCC 6666 CCCC 0038"
	$"CCCC 6666 9999 0039 CCCC 6666 6666 003A CCCC 6666 3333 003B"
	$"CCCC 6666 0000 003C CCCC 3333 FFFF 003D CCCC 3333 CCCC 003E"
	$"CCCC 3333 9999 003F CCCC 3333 6666 0040 CCCC 3333 3333 0041"
	$"CCCC 3333 0000 0042 CCCC 0000 FFFF 0043 CCCC 0000 CCCC 0044"
	$"CCCC 0000 9999 0045 CCCC 0000 6666 0046 CCCC 0000 3333 0047"
	$"CCCC 0000 0000 0048 9999 FFFF FFFF 0049 9999 FFFF CCCC 004A"
	$"9999 FFFF 9999 004B 9999 FFFF 6666 004C 9999 FFFF 3333 004D"
	$"9999 FFFF 0000 004E 9999 CCCC FFFF 004F 9999 CCCC CCCC 0050"
	$"9999 CCCC 9999 0051 9999 CCCC 6666 0052 9999 CCCC 3333 0053"
	$"9999 CCCC 0000 0054 9999 9999 FFFF 0055 9999 9999 CCCC 0056"
	$"9999 9999 9999 0057 9999 9999 6666 0058 9999 9999 3333 0059"
	$"9999 9999 0000 005A 9999 6666 FFFF 005B 9999 6666 CCCC 005C"
	$"9999 6666 9999 005D 9999 6666 6666 005E 9999 6666 3333 005F"
	$"9999 6666 0000 0060 9999 3333 FFFF 0061 9999 3333 CCCC 0062"
	$"9999 3333 9999 0063 9999 3333 6666 0064 9999 3333 3333 0065"
	$"9999 3333 0000 0066 9999 0000 FFFF 0067 9999 0000 CCCC 0068"
	$"9999 0000 9999 0069 9999 0000 6666 006A 9999 0000 3333 006B"
	$"9999 0000 0000 006C 6666 FFFF FFFF 006D 6666 FFFF CCCC 006E"
	$"6666 FFFF 9999 006F 6666 FFFF 6666 0070 6666 FFFF 3333 0071"
	$"6666 FFFF 0000 0072 6666 CCCC FFFF 0073 6666 CCCC CCCC 0074"
	$"6666 CCCC 9999 0075 6666 CCCC 6666 0076 6666 CCCC 3333 0077"
	$"6666 CCCC 0000 0078 6666 9999 FFFF 0079 6666 9999 CCCC 007A"
	$"6666 9999 9999 007B 6666 9999 6666 007C 6666 9999 3333 007D"
	$"6666 9999 0000 007E 6666 6666 FFFF 007F 6666 6666 CCCC 0080"
	$"6666 6666 9999 0081 6666 6666 6666 0082 6666 6666 3333 0083"
	$"6666 6666 0000 0084 6666 3333 FFFF 0085 6666 3333 CCCC 0086"
	$"6666 3333 9999 0087 6666 3333 6666 0088 6666 3333 3333 0089"
	$"6666 3333 0000 008A 6666 0000 FFFF 008B 6666 0000 CCCC 008C"
	$"6666 0000 9999 008D 6666 0000 6666 008E 6666 0000 3333 008F"
	$"6666 0000 0000 0090 3333 FFFF FFFF 0091 3333 FFFF CCCC 0092"
	$"3333 FFFF 9999 0093 3333 FFFF 6666 0094 3333 FFFF 3333 0095"
	$"3333 FFFF 0000 0096 3333 CCCC FFFF 0097 3333 CCCC CCCC 0098"
	$"3333 CCCC 9999 0099 3333 CCCC 6666 009A 3333 CCCC 3333 009B"
	$"3333 CCCC 0000 009C 3333 9999 FFFF 009D 3333 9999 CCCC 009E"
	$"3333 9999 9999 009F 3333 9999 6666 00A0 3333 9999 3333 00A1"
	$"3333 9999 0000 00A2 3333 6666 FFFF 00A3 3333 6666 CCCC 00A4"
	$"3333 6666 9999 00A5 3333 6666 6666 00A6 3333 6666 3333 00A7"
	$"3333 6666 0000 00A8 3333 3333 FFFF 00A9 3333 3333 CCCC 00AA"
	$"3333 3333 9999 00AB 3333 3333 6666 00AC 3333 3333 3333 00AD"
	$"3333 3333 0000 00AE 3333 0000 FFFF 00AF 3333 0000 CCCC 00B0"
	$"3333 0000 9999 00B1 3333 0000 6666 00B2 3333 0000 3333 00B3"
	$"3333 0000 0000 00B4 0000 FFFF FFFF 00B5 0000 FFFF CCCC 00B6"
	$"0000 FFFF 9999 00B7 0000 FFFF 6666 00B8 0000 FFFF 3333 00B9"
	$"0000 FFFF 0000 00BA 0000 CCCC FFFF 00BB 0000 CCCC CCCC 00BC"
	$"0000 CCCC 9999 00BD 0000 CCCC 6666 00BE 0000 CCCC 3333 00BF"
	$"0000 CCCC 0000 00C0 0000 9999 FFFF 00C1 0000 9999 CCCC 00C2"
	$"0000 9999 9999 00C3 0000 9999 6666 00C4 0000 9999 3333 00C5"
	$"0000 9999 0000 00C6 0000 6666 FFFF 00C7 0000 6666 CCCC 00C8"
	$"0000 6666 9999 00C9 0000 6666 6666 00CA 0000 6666 3333 00CB"
	$"0000 6666 0000 00CC 0000 3333 FFFF 00CD 0000 3333 CCCC 00CE"
	$"0000 3333 9999 00CF 0000 3333 6666 00D0 0000 3333 3333 00D1"
	$"0000 3333 0000 00D2 0000 0000 FFFF 00D3 0000 0000 CCCC 00D4"
	$"0000 0000 9999 00D5 0000 0000 6666 00D6 0000 0000 3333 00D7"
	$"EEEE 0000 0000 00D8 DDDD 0000 0000 00D9 BBBB 0000 0000 00DA"
	$"AAAA 0000 0000 00DB 8888 0000 0000 00DC 7777 0000 0000 00DD"
	$"5555 0000 0000 00DE 4444 0000 0000 00DF 2222 0000 0000 00E0"
	$"1111 0000 0000 00E1 0000 EEEE 0000 00E2 0000 DDDD 0000 00E3"
	$"0000 BBBB 0000 00E4 0000 AAAA 0000 00E5 0000 8888 0000 00E6"
	$"0000 7777 0000 00E7 0000 5555 0000 00E8 0000 4444 0000 00E9"
	$"0000 2222 0000 00EA 0000 1111 0000 00EB 0000 0000 EEEE 00EC"
	$"0000 0000 DDDD 00ED 0000 0000 BBBB 00EE 0000 0000 AAAA 00EF"
	$"0000 0000 8888 00F0 0000 0000 7777 00F1 0000 0000 5555 00F2"
	$"0000 0000 4444 00F3 0000 0000 2222 00F4 0000 0000 1111 00F5"
	$"EEEE EEEE EEEE 00F6 DDDD DDDD DDDD 00F7 BBBB BBBB BBBB 00F8"
	$"AAAA AAAA AAAA 00F9 8888 8888 8888 00FA 7777 7777 7777 00FB"
	$"5555 5555 5555 00FC 4444 4444 4444 00FD 2222 2222 2222 00FE"
	$"1111 1111 1111 00FF 0000 0000 0000 0000 0000 0020 0020 0000"
	$"0000 0020 0020 0000 02E1 0002 E100 02E1 0002 E100 06F8 00F5"
	$"F6F6 0006 FA00 EFF6 FA00 06FB 00ED F6FB 0006 FC00 ECF6 FB00"
	$"06FC 00EA F6FD 000D FC00 F6F6 0381 8156 81F9 F6FD 0011 FC00"
	$"F7F6 0781 FF81 4F2B 8156 2BFC F6FD 0013 FC00 F8F6 0981 6B22"
	$"64A5 AC2B 5681 56FD F6FD 0013 FD00 F7F6 09B3 2146 0724 56AC"
	$"AC81 81FD F6FD 0015 FE00 F7F6 0B81 6A22 2214 222B 328F FFAC"
	$"81FE F6FD 0015 FE00 F7F6 0B64 1B22 1500 1522 4622 8FB2 2BFE"
	$"F6FD 0015 FE00 F8F6 0B88 4622 0000 2200 461C 8FB2 4FFD F6FD"
	$"0015 FE00 F9F6 0B56 6A3F 460E 2200 221B 4563 81FC F6FD 0015"
	$"FE00 F9F6 0BB3 4647 1C00 1546 2246 46AC 2BFC F6FD 0015 FE00"
	$"FAF6 0B81 8F21 0000 0E00 2222 1BB3 7AFB F6FD 0016 FE00 FBF6"
	$"0C7A 883F 2240 0039 2246 218E 8124 FBF6 FD00 15FC 00FD F60B"
	$"AC6A 1B00 0715 1C22 1B46 AC2B FAF6 FD00 14FC 00FD F60A 6447"
	$"3F00 221B 4746 466A 81F9 F6FD 0014 FC00 FDF6 0A81 8E31 2B14"
	$"461B 406A 882B F9F6 FD00 12FC 00FC F608 2BA5 565D 4046 3FB3"
	$"56F8 F6FD 0010 FC00 FAF6 062B 5656 0663 562B F8F6 FD00 0DFC"
	$"00F9 F603 5656 AC5D F6F6 FD00 06FC 00EC F6FB 0006 FB00 EEF6"
	$"FA00 06F6 00F4 F6F9 0006 F300 F9F6 F700 02E1 0002 E100 00A0"
	$"0083 00FF"
};


/*================ 'vers' resource that's required by all extensions ================== */

/*	The first byte of this resource must be zero or one for
	this extension to be compatible with GX v1.0.  The
	remainder of the data is ignored.						*/

resource 'vers' (gxPrintingExtensionBaseID, sysheap, purgeable) {
	0x0,
	0x0,
	release,
	0x0,
	verUS,
	"",
	""
};


/*=============== Standard 'vers', bundle and icon resources follow ================= */

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0,  Apple Computer, Inc. 1992-1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"Backwash v1.0"
};


resource 'BNDL' (r_backwashBNDL, sysheap, purgeable) {
	kCreator,
	0,
	{
		'ICN#', {0, r_backwashBNDL},
		'FREF', {0, r_backwashBNDL}
	}
};


// You must include a 'pext' FREF for your extension.

resource 'FREF' (r_backwashBNDL, sysheap, purgeable) {
	gxPrintingExtensionType,
	0,
	""
};


Type kCreator as 'STR ';

resource kCreator (0, "Owner resource", sysheap, purgeable) {
	"This is the backwash printing extension."
};


resource 'ics8' (r_backwashBNDL, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 FFAC 81F6 F6F6 FFFF"
	$"FFF6 F6F6 F6F6 F6B3 4656 ACFF F6F6 FF00 FFF6 F6F6 F6F6 F622"
	$"2246 8FB2 F6F6 FF00 FFF6 F6F6 F6F6 6A46 4646 ACF6 F6F6 FF00"
	$"FFF6 F6F6 F68F 4039 468E B3F6 F6F6 FF00 FFFF F6F6 F66A 2247"
	$"46AC F6F6 F6F6 FFFF FFFF F6F6 F6A5 5D46 B3F6 F6F6 F6F6 FFFF"
	$"00FF F6F6 F6F6 F6AC F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'ics8' (r_backwashPanelIcon) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F6F6 F600 0000"
	$"0000 F6F6 F6F6 F6F6 F6F6 F6F6 F600 0000 0000 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 0000 0000 F6F6 F6F6 F6F6 FFAC 81F6 F6F6 0000"
	$"00F6 F6F6 F6F6 F6B3 4656 ACFF F6F6 0000 00F6 F6F6 F6F6 F622"
	$"2246 8FB2 F6F6 0000 00F6 F6F6 F6F6 6A46 4646 ACF6 F6F6 0000"
	$"00F6 F6F6 F68F 4039 468E B3F6 F6F6 0000 0000 F6F6 F66A 2247"
	$"46AC F6F6 F6F6 0000 0000 F6F6 F6A5 5D46 B3F6 F6F6 F6F6 0000"
	$"0000 F6F6 F6F6 F6AC F6F6 F6F6 F6F6 0000 0000 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F600 0000 0000 0000 00F6 F6F6 F6F6 F6F6"
};


resource 'ics4' (r_backwashBNDL, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFFF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FCC CCCC CCCC CCCF FFCC CCCC DDCC CCFF FFCC CCCD FEDD CCFF"
	$"FCCC CCDF CDEF DCF0 FCCC CCE4 33AF CCF0 FCCC CF4C 34ED CCF0"
	$"FCCC DE4C 3AFC CCF0 FFCC E4C4 4ECC CCFF FFCC DED4 FECC CCFF"
	$"0FCC CCDE DCCC CCCF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FFF FFFF FFFF FFFF"
};


resource 'ics4' (r_backwashPanelIcon) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 000C CCCC CCCC C000"
	$"00CC CCCC CCCC C000 00CC CCCC DDCC CC00 00CC CCCD FEDD CC00"
	$"0CCC CCDF CDEF DC00 0CCC CCE4 33AF CC00 0CCC CF4C 34ED CC00"
	$"0CCC DE4C 3AFC CC00 00CC E4C4 4ECC CC00 00CC DED4 FECC CC00"
	$"00CC CCDE DCCC CC00 00CC CCCC CCCC C000 0000 0CCC CCCC"
};


resource 'ics#' (r_backwashBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFF 4001 4001 4001 C0E3 C1D3 817A 829A 86B2 8522 C543 C2C3"
		$"4181 4001 4001 7FFF",
		/* [2] */
		$"7FFF 7FFF 7FFF 7FFF FFFF FFFF FFFE FFFE FFFE FFFE FFFF FFFF"
		$"7FFF 7FFF 7FFF 7FFF"
	}
};


resource 'ics#' (r_backwashPanelIcon) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0000 0000 0000 00E0 01F0 0378 0250 04F0 0D20 0F40 03C0"
		$"0180",
		/* [2] */
		$"0000 0000 1FF8 3FF8 3FFC 3FFC 7FFC 7FFC 7FFC 7FFC 3FFC 3FFC"
		$"3FFC 3FF8 07F0"
	}
};


resource 'ICN#' (r_backwashBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0FFF FFFE 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 1000 0001 1000 6005 5000 D80B B001 4609 9001 2508"
		$"8002 1B88 8004 0788 8004 6108 8008 4208 8010 A208 8010 0408"
		$"8021 0808 8042 0808 9068 1008 B036 2009 5008 200B 1006 4005"
		$"1001 8001 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 0FFF FFFE",
		/* [2] */
		$"0FFF FFFE 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 5FFF FFFB FFFF FFF9 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF9 5FFF FFFB 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 0FFF FFFE"
	}
};


resource 'ICN#' (r_backwashPanelIcon) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
		$"0000 0000 0000 0000 0000 6000 0000 D800 0001 4600 0001 2500"
		$"0002 1B80 0004 0780 0004 2100 0008 0200 0010 A200 0010 0400"
		$"0021 0800 0042 0800 0068 1000 0036 2000 0008 2000 0006 4000"
		$"0001 80",
		/* [2] */
		$"0000 0000 0000 0000 0000 0000 0000 0000 007F F800 01FF FF80"
		$"03FF FFC0 07FF FFC0 07FF FFF0 07FF FFF0 07FF FFF0 07FF FFF0"
		$"0FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 07FF FFF0 07FF FFF0 07FF FFF0 07FF FFF0"
		$"07FF FFF0 07FF FFF0 07FF FFC0 03FF FF80 001F FF00 0003 FC"
	}
};


resource 'icl8' (r_backwashBNDL, sysheap, purgeable) {
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FF00 0000 00FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 8181 F681 F6F6 F6F6"
	$"F6F6 F6F6 FF00 FFFF FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F681"
	$"FF81 812B 8156 F6F6 F6F6 F6F6 FF00 00FF FF00 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 816B 2264 A5AC 2B56 81F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 B321 4607 F656 ACAC 8181"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F681 6A22"
	$"2214 222B 328F FFAC 81F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F664 1B22 1500 1522 4622 8FB2 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 8846 2200 0022 0046 1C8F B2F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F656 6A3F 460E"
	$"2200 221B 4563 81F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6B3 4647 1C00 1546 2246 46AC 2BF6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 818F 2100 000E 0022 221B B37A F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F67A 883F 2240 0039"
	$"2246 218E 81F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6FF 00F6 F6F6"
	$"F6AC 6A1B 0007 151C 221B 46AC 2BF6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 FFFF 00F6 F6F6 F664 473F 0022 1B47 4646 6A81 F6F6 F6F6"
	$"F6F6 F6F6 FF00 00FF 00FF 00FF 00F6 F6F6 F681 8EF6 2B14 461B"
	$"406A 882B F6F6 F6F6 F6F6 F6F6 FF00 FFFF 0000 00FF 00F6 F6F6"
	$"F6F6 F6A5 565D 4046 3FB3 56F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F656 56F6 6356 2BF6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F656 56AC"
	$"5DF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'icl8' (r_backwashPanelIcon, sysheap, purgeable) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 00F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F600 0000 0000 0000 0000 0000 0000 0000 0000 00F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F600 0000 0000 0000"
	$"0000 0000 0000 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 0000 0000 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 0000 0000 0000 0000 0000 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 0000 0000"
	$"0000 0000 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 8181 5681 F6F6 F6F6"
	$"F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F6F6 F681"
	$"FF81 4F2B 8156 2BF6 F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6"
	$"F6F6 F6F6 F6F6 816B 2264 A5AC 2B56 8156 F6F6 F6F6 0000 0000"
	$"0000 0000 F6F6 F6F6 F6F6 F6F6 F6F6 B321 4607 2456 ACAC 8181"
	$"F6F6 F6F6 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F6F6 F681 6A22"
	$"2214 222B 328F FFAC 81F6 F6F6 0000 0000 0000 00F6 F6F6 F6F6"
	$"F6F6 F6F6 F664 1B22 1500 1522 4622 8FB2 2BF6 F6F6 0000 0000"
	$"0000 00F6 F6F6 F6F6 F6F6 F6F6 8846 2200 0022 0046 1C8F B24F"
	$"F6F6 F6F6 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F656 6A3F 460E"
	$"2200 221B 4563 81F6 F6F6 F6F6 0000 0000 0000 00F6 F6F6 F6F6"
	$"F6F6 F6B3 4647 1C00 1546 2246 46AC 2BF6 F6F6 F6F6 0000 0000"
	$"0000 00F6 F6F6 F6F6 F6F6 818F 2100 000E 0022 221B B37A F6F6"
	$"F6F6 F6F6 0000 0000 0000 00F6 F6F6 F6F6 F67A 883F 2240 0039"
	$"2246 218E 8124 F6F6 F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6"
	$"F6AC 6A1B 0007 151C 221B 46AC 2BF6 F6F6 F6F6 F6F6 0000 0000"
	$"0000 0000 00F6 F6F6 F664 473F 0022 1B47 4646 6A81 F6F6 F6F6"
	$"F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6 F681 8E31 2B14 461B"
	$"406A 882B F6F6 F6F6 F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6"
	$"F6F6 2BA5 565D 4046 3FB3 56F6 F6F6 F6F6 F6F6 F6F6 0000 0000"
	$"0000 0000 00F6 F6F6 F6F6 F6F6 2B56 5606 6356 2BF6 F6F6 F6F6"
	$"F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6 F6F6 F6F6 F656 56AC"
	$"5DF6 F6F6 F6F6 F6F6 F6F6 F6F6 0000 0000 0000 0000 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 0000 0000 0000"
	$"0000 0000 0000 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F600 0000 0000 0000 0000 0000 0000 0000 0000 00F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 F6F6 F6F6 F6F6 F6F6"
};


resource 'icl4' (r_backwashBNDL, sysheap, purgeable) {
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFF0 000F 0000 0000 0000"
	$"0000 0000 0000 000F 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"0F0F 0CCC CCCC CCCC DDDD CCCC CCCC F0FF F0FF 0CCC CCCC CCCD"
	$"FDCC DDCC CCCC F00F F00F 0CCC CCCC CCD3 3BEE CDDD CCCC F000"
	$"F0CC CCCC CCCC CCF4 3C0D EEDD CCCC F000 F0CC CCCC CCCC CD33"
	$"343C CAFE DCCC F000 F0CC CCCC CCCC CB43 2023 33AF CCCC F000"
	$"F0CC CCCC CCCC E330 0303 2AFC CCCC F000 F0CC CCCC CCCD 343C"
	$"3034 4BDC CCCC F000 F0CC CCCC CCCF 3320 2333 3ECC CCCC F000"
	$"F0CC CCCC CCDA 400C 0334 FDCC CCCC F000 F0CC CCCC CDE4 330B"
	$"334A D0CC CCCC F000 F0CF 0CCC CE34 0C22 343E CCCC CCCC F000"
	$"F0FF 0CCC CB34 0343 333D CCCC CCCC F00F 0F0F 0CCC CDAC C434"
	$"33EC CCCC CCCC F0FF 000F 0CCC CCCE DB33 4FDC CCCC CCCC CFCF"
	$"000F 0CCC CCCC CDD0 BDCC CCCC CCCC CCCF 000F 0CCC CCCC CDDE"
	$"BCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFF0"
};


resource 'icl4' (r_backwashPanelIcon) {
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0CCC CCCC"
	$"CCCC C000 0000 0000 0000 000C CCCC CCCC CCCC CCCC C000 0000"
	$"0000 00CC CCCC CCCC CCCC CCCC CC00 0000 0000 0CCC CCCC CCCC"
	$"CCCC CCCC CC00 0000 0000 0CCC CCCC CCCC CCCC CCCC CCCC 0000"
	$"0000 0CCC CCCC CCCC DDDD CCCC CCCC 0000 0000 0CCC CCCC CCCD"
	$"FDCC DDCC CCCC 0000 0000 0CCC CCCC CCD3 3BEE CDDD CCCC 0000"
	$"0000 CCCC CCCC CCF4 3C0D EEDD CCCC 0000 000C CCCC CCCC CD33"
	$"343C CAFE DCCC 0000 000C CCCC CCCC CB43 3023 33AF CCCC 0000"
	$"000C CCCC CCCC E330 0303 2AFC CCCC 0000 000C CCCC CCCD 343C"
	$"3034 4BDC CCCC 0000 000C CCCC CCCF 3330 0333 3ECC CCCC 0000"
	$"000C CCCC CCDA 400C 3334 FDCC CCCC 0000 000C CCCC CDE4 330B"
	$"334A D0CC CCCC 0000 0000 0CCC CE34 0C23 343E CCCC CCCC 0000"
	$"0000 0CCC CB33 0343 333D CCCC CCCC 0000 0000 0CCC CDAC C434"
	$"33EC CCCC CCCC 0000 0000 0CCC CCCE DB33 4FDC CCCC CCCC 0000"
	$"0000 0CCC CCCC CDD0 3DCC CCCC CCCC 0000 0000 0CCC CCCC CDDE"
	$"BCCC CCCC CCCC 0000 0000 0CCC CCCC CCCC CCCC CCCC CC00 0000"
	$"0000 00CC CCCC CCCC CCCC CCCC C000 0000 0000 0000 000C CCCC"
	$"CCCC CCCC 0000 0000 0000 0000 0000 00CC CCCC CC"
};

