/*________________________________________________

	File: PS Extension.r
		
	Rez file for a printing extension.

	Dave Hersey
	Apple Developer Technical Support

	(Based on the "Extension Shell" sample.)

	12/01/92 - dmh - Created.
	 4/26/93 - dmh - Updated to use recommended approach
	 				 to global data initialization.
	 9/05/93 - dmh - Updated for b2.
	 			   - Fixed minor problem with highlighting
				     of editText panel items.
				   - Switched to Exception.h assertion stuff
					 for error checking.
	 9/08/93 - dmh - Modified to override
	 				 GXPostScriptDoPageSetup.
				   - Added a "PS " before the file names.
				   - Changed creator type.
	12/18/93 - dmh - Updated for b3.
	 3/22/94 - dmh - Updated for b4.
	 5/03/94 - dmh - Updated for f2.

	(Note: resource labels are in the Mark menu)

  ________________________________________________*/

#include "SysTypes.r"
#include "Types.r"
#include "PrintingResTypes.h"
#include "PrintingResTypes.r"

#define kCreator			'GPxt'			/* This is our creator type.		*/

#define r_FinderBNDL		128				/* Finder BNDL & icon IDs.			*/
#define r_ExtensionPanel	6000			/* ID of our panel and panel icon.	*/


/*=================== Print Dialog Panel Related Resources ==================== */


/*==== Description of the panel resource added to print dialog by extension ==== */

resource gxPrintPanelType (r_ExtensionPanel, sysheap, purgeable)
{
		"PS Extension", smRoman, r_ExtensionPanel, r_ExtensionPanel
};


resource 'DITL' (r_ExtensionPanel, sysheap, purgeable) {
	{
		/* [1] */
		{39, 120, 57, 166},
		RadioButton {
			enabled,
			"Off"
		},
		/* [2] */
		{39, 175, 57, 220},
		RadioButton {
			enabled,
			"On"
		},
		/* [3] */
		{9, 75, 26, 285},
		StaticText {
			disabled,
			"PostScript Extension Sample"
		},
		/* [4] */
		{79, 43, 133, 293},
		StaticText {
			disabled,
			"(When turned on, your computer will beep "
			"whenever a page starts to print on a "
			"PostScript printer.)"
		}
	}
};


/*======= 'xdtl' describing how to process the items in the Print Dialog Panel ======= */

resource 'xdtl' (r_ExtensionPanel, sysheap, purgeable)
{
	{
/*	This is the xdtl declaration for a set of radio buttons which
	consist of DITL items 1 and 2, and whose value should be
	stored in a collection item of tag kCreator, and ID
	gxPrintingTagID.  We also specify that the data should be
	stored at offset 0 in that collection item.  See the
	ExtensionCollection declaration in PS Extension.h to better
	understand this.  The data we store is the index to the
	radio button which is selected, using the ordering we
	show below.  So, if 0 is stored, that means item #1 was
	selected, if 1 was stored, that means item #2 was selected.	*/

		RadioButtons { kCreator, gxPrintingTagID, 0, {1,2} }
	};
};


/*=================== Required Printing Extension Types and Resources =================== */


/*======= Scope ('scop') Resource ======= */

/*	This resource tells the printing system which types
	of drivers we work with.  (We only work with PostScript
	drivers.)	*/

resource gxExtensionScopeType (gxDriverScopeID, sysheap, purgeable)
{
	{
		gxPostscriptPrinterType		
	};
};


/*======= PostScript Override Mapping ('post') Resource ======= */

/*	This declaration and resource tells the printing system where
	our imaging-system-specific message override resource is.  If
	you were overriding raster messages, you would use a
	gxRasterPrinterType resource.  If you were overriding vector
	messages, you would use a gxVectorPrinterType resource.	*/

type gxPostscriptPrinterType
{
	integer;		// ID of 'over' resource to use.
};

type gxRasterPrinterType as gxPostscriptPrinterType;
type gxVectorPrinterType as gxPostscriptPrinterType;


resource gxPostscriptPrinterType (gxExtensionImagingOverrideSelectorID, sysheap, purgeable)
{
	gxExtensionUniversalOverrideID +1
};


/*======= Message Override ('over') Resource ======= */

/*	These resources tell the printing system which messages we
	want to override and where the override code is located.
	Because of the gxPostscriptPrinterType resource above,
	this first resource is for PostScript imaging system
	message overrides, and the second is for universal message
	overrides.	*/


resource gxOverrideType (gxExtensionUniversalOverrideID +1, sysheap, purgeable)
{
	{
		// message to override	segmentID		offset into jump table
		gxPostScriptDoPageSetup,	0, 				   20
	};
};


resource gxOverrideType (gxExtensionUniversalOverrideID, sysheap, purgeable)
{
	{
		// message to override	segmentID		offset into jump table
		gxInitialize, 				0, 					 4,
		gxShutDown, 				0, 					 8,
		gxJobPrintDialog, 			0, 			  		12,
		gxHandlePanelEvent, 		0, 			  		16,
	};
};


/*======= Extension Optimization ('eopt') Resource ======= */

/*	This resource tells the printing system at which times we'll
	be doing things so that it can optimize for us.  */

resource gxExtensionOptimizationType (gxExtensionOptimizationID, sysheap, purgeable)
{
	gxDontExecuteDuringImaging,
	gxDontNeedDeviceStatus,
	gxDontChangePageAtGXDespoolPage,
	gxDontChangePageAtGXImagePage,
	gxDontChangePageAtGXRenderPage,
	gxNotServerPresenceRequired,
	gxNotClientPresenceRequired
};


/*======= Extension Load ('load') Resource ======= */

/*	This resource tells the printing system where we want
	to be loaded in the handler chain.  We don't care
	where we load.	*/

resource gxExtensionLoadType (gxExtensionLoadID, sysheap, purgeable)
{
	gxExtensionLoadAnywhere
};


/*================ 'vers' resource that's required by all extensions ================== */

/*	The first byte of this resource must be zero or one for
	this extension to be compatible with GX v1.0.  The
	remainder of the data is ignored.						*/

resource 'vers' (gxPrintingExtensionBaseID, sysheap, purgeable) {
	0x0,
	0x0,
	release,
	0x0,
	verUS,
	"",
	""
};


/*=================== Standard 'vers', bundle and icon resources follow =================== */

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0,  <Your name here>, Inc. 1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"Generic Extension v1.0"
};


resource 'BNDL' (r_FinderBNDL, sysheap, purgeable) {
	kCreator,
	0,
	{
		'ICN#', {0, r_FinderBNDL},
		'FREF', {0, r_FinderBNDL}
	}
};


resource 'FREF' (r_FinderBNDL, sysheap, purgeable) {
	gxPrintingExtensionType,
	0,
	""
};


Type kCreator as 'STR ';

resource kCreator (0, "Owner resource", sysheap, purgeable) {
	"This is the generic PostScript printing extension."
};


resource 'ics8' (r_FinderBNDL, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'ics4' (r_FinderBNDL, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFFF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FCC CCCC CCCC CCCF FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0"
	$"FCCC CCCC CCCC CCF0 FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FFF FFFF FFFF FFFF"
};


resource 'ics#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFF 4001 4001 4001 C003 C003 8002 8002 8002 8002 C003 C003"
		$"4001 4001 4001 7FFF",
		/* [2] */
		$"7FFF 7FFF 7FFF 7FFF FFFF FFFF FFFE FFFE FFFE FFFE FFFF FFFF"
		$"7FFF 7FFF 7FFF 7FFF"
	}
};


resource 'ICN#' (r_FinderBNDL, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0FFF FFFE 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 1000 0001 1000 0005 5000 000B B000 0009 9000 0008"
		$"8000 0008 8000 0008 8000 0008 8000 0008 8000 0008 8000 0008"
		$"8000 0008 8000 0008 8000 0008 B000 0009 5000 000B 1000 0005"
		$"1000 0001 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 0FFF FFFE",
		/* [2] */
		$"0FFF FFFE 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 5FFF FFFB FFFF FFF9 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF9 5FFF FFFB 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 0FFF FFFE"
	}
};


resource 'icl8' (r_FinderBNDL, sysheap, purgeable) {
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FF00 0000 00FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 FFFF FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 00FF FF00 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 00FF 00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'icl4' (r_FinderBNDL, sysheap, purgeable) {
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFF0 000F 0000 0000 0000"
	$"0000 0000 0000 000F 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"0F0F 0CCC CCCC CCCC CCCC CCCC CCCC F0FF F0FF 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F00F F00F 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CF 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0FF 0CCC CCCC CCCC CCCC CCCC CCCC F00F 0F0F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F0FF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFF0"
};


resource 'ics8' (r_ExtensionPanel, sysheap, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FF00 FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00"
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 FFFF FFFF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF"
	$"00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 00FF F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};


resource 'ics4' (r_ExtensionPanel, sysheap, purgeable) {
	$"0FFF FFFF FFFF FFFF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FCC CCCC CCCC CCCF FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0 FCCC CCCC CCCC CCF0"
	$"FCCC CCCC CCCC CCF0 FFCC CCCC CCCC CCFF FFCC CCCC CCCC CCFF"
	$"0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF 0FCC CCCC CCCC CCCF"
	$"0FFF FFFF FFFF FFFF"
};


resource 'ics#' (r_ExtensionPanel, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FFF 4001 4001 4001 C003 C003 8002 8002 8002 8002 C003 C003"
		$"4001 4001 4001 7FFF",
		/* [2] */
		$"7FFF 7FFF 7FFF 7FFF FFFF FFFF FFFE FFFE FFFE FFFE FFFF FFFF"
		$"7FFF 7FFF 7FFF 7FFF"
	}
};


resource 'ICN#' (r_ExtensionPanel, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0FFF FFFE 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 1000 0001 1000 0005 5000 000B B000 0009 9000 0008"
		$"8000 0008 8000 0008 8000 0008 8000 0008 8000 0008 8000 0008"
		$"8000 0008 8000 0008 8000 0008 B000 0009 5000 000B 1000 0005"
		$"1000 0001 1000 0001 1000 0001 1000 0001 1000 0001 1000 0001"
		$"1000 0001 0FFF FFFE",
		/* [2] */
		$"0FFF FFFE 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 5FFF FFFB FFFF FFF9 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF9 5FFF FFFB 1FFF FFFF"
		$"1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF 1FFF FFFF"
		$"1FFF FFFF 0FFF FFFE"
	}
};


resource 'icl8' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FF00 0000 00FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 FFFF FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 00FF FF00 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 0000 FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000 FF00 F6FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 0000"
	$"FF00 FFFF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 FF00 00FF 00FF 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 FF00 FFFF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF 0000 00FF 00F6 F6F6"
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"
	$"0000 00FF 00F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"
	$"F6F6 F6F6 F6F6 F6FF 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF"
};


resource 'icl4' (r_ExtensionPanel, sysheap, purgeable) {
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFF0 000F 0000 0000 0000"
	$"0000 0000 0000 000F 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"0F0F 0CCC CCCC CCCC CCCC CCCC CCCC F0FF F0FF 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F00F F00F 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCCC F000 F0CC CCCC CCCC CCCC"
	$"CCCC CCCC CCCC F000 F0CF 0CCC CCCC CCCC CCCC CCCC CCCC F000"
	$"F0FF 0CCC CCCC CCCC CCCC CCCC CCCC F00F 0F0F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC F0FF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CFCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC"
	$"CCCC CCCC CCCC CCCF 000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF"
	$"000F 0CCC CCCC CCCC CCCC CCCC CCCC CCCF 0000 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFF0"
};
