/*
	FILENAME
		CommonDefines.h

	DESCRIPTION
		Contains defines used by the various .r and .h files.

	COPYRIGHT
		Copyright  1995 Apple Computer, Inc.
		All rights reserved.
	
	Modification history
		10/04/95 - David Hayward -	Version 1.0.4 modified code so that
									the driver can be build under MPW,
									Metrowerks, and Symantec.
									Also made a few changes so that the
									driver can be rebuilt to support any
									resolution by changing the #defines
									kResolution and kPatStretch in
									"CommonDefines.h"

		06/14/95 - Dave Hersey -	Version 1.0.3 to fix a bug in
									CustomBufferingAndIO.c when creating
									high-res PICTs, and to make the size
									of buffers more flexible.

		05/26/95 - Dave Hersey -	Version 1.0.2 to add the new 'outp'
									desktop printer resource in NewApp.c.

		05/03/95 - Dave Hersey -	Version 1.0.1 to fix some minor bugs in
									CustomBufferingAndIO.c.

		01/14/95 - Dave Hersey -	Created from the shell of a hollowed-out
									ImageWriter driver.
*/


// Driver info
#define DriverName				"CustomWriter GX"
#define DriverCreator 			'cuWR'
#define DriverType 				'pdvr'

// PICT file resolution
#define kResolution 			72
#define kPatStretch 			1	// should be resolution/72

// Code segment info-- all driver overrides go in 'pdvr' resources;
// these are the IDs we use for ours.
#define NewSegID				0
#define OldSegID				1

// The creator and type of the files we create.  (SimpleText PICTs)
#define kFileCreator			'ttxt'
#define kFileType				'PICT'

// Status defines
#define kTransmissionStatID		gxPrintingDriverBaseID	// stat resource ID
#define kSendingPartStatIdx		1	// item number for sending data
#define kPreparingPartStatIdx	2	// item number for preparing data
#define kPrintingPageStatIdx	3	// item number for writing page

// The number of our custom buffers, and percentage of free RAM they should use.
#define kNumBuffs				(4)
#define kBuffRAMPercentage		(30)

// The maximum amount of RAM we should gobble up for buffers.
#define kMaxRAMToUse			(2000 * 1024)

// Defines used by the old-application compatibility code.
#define kPortrait				(0x04)
#define kPrintRecordVers		(12)
#define kDriverWDev				(0x8800)
