#
#	FILENAME
#		CustomWriter GX.make
#
#	DESCRIPTION
#		Makefile for the CustomWriter GX driver.
#
#	COPYRIGHT
#		Copyright  1995 Apple Computer, Inc.
#		All rights reserved.
#	
#	Modification history
#		10/04/95 - David Hayward -	Version 1.0.4 modified code so that
#									the driver can be build under MPW,
#									Metrowerks, and Symantec.  In general,
#									all that was required to do this was 
#									to add an inline-assembly jumptable
#									and to store all globals off of the
#									message manager instance context.
#									Also made a few changes so that the
#									driver can be rebuilt to support any
#									resolution by changing the #defines
#									kResolution and kPatStretch in
#									"CommonDefines.h"
#
#		06/14/95 - Dave Hersey -	Version 1.0.3 to fix a bug in
#									CustomBufferingAndIO.c when creating
#									high-res PICTs, and to make the size
#									of buffers more flexible.
#
#		05/26/95 - Dave Hersey -	Version 1.0.2 to add the new 'outp'
#									desktop printer resource in NewApp.c.
#
#		05/03/95 - Dave Hersey -	Version 1.0.1 to fix some minor bugs in
#									CustomBufferingAndIO.c.
#
#		01/14/95 - Dave Hersey -	Created from the shell of a hollowed-out
#									ImageWriter driver.
#

#========== Directories Containing Source and Object Files ==========

ObjDir					= :Objects:
SrcDir					= 
DestDir					= 
GXLibs					= {MPW}GXLibraries
GXCompatIntf			= {MPW}GXCompatibilityInterfaces

#========== Compiler Options ==========

AsmOptions				= -sym off -i "{CIncludes}" -i "{GXLibs}" -i "{GXCompatIntf}" -case obj
COptions				= -sym off -i "{CIncludes}" -i "{GXLibs}" -i "{GXCompatIntf}" -mbg full -b2
RezOptions				= -i "{RIncludes}" -d SystemSevenOrLater=1
LinkOptions				= -ra =resSysHeap,resPurgeable


DriverName 				= "CustomWriterGX"
DriverCreator 			= 'cuWR'
NewSegID				= 0
OldSegID				= 1


### Compile and assemble statements ###

{ObjDir}OldApp.c.o  {SrcDir}OldApp.c
	Echo "{DriverName}: Compiling old application"
	C {COptions} {SrcDir}OldApp.c -o {Targ}

{ObjDir}OldApp.a.o	 	{SrcDir}OldApp.a
	Echo "{DriverName}: Assembling old app jump table"
	Asm {AsmOptions} {SrcDir}OldApp.a -o {Targ}

{ObjDir}NewApp.c.o	 {SrcDir}NewApp.c {SrcDir}NewApp.h {SrcDir}CommonDefines.h
	Echo "{DriverName}: Compiling new application"
	C {COptions} {SrcDir}NewApp.c -o {Targ}

{ObjDir}NewApp.a.o	 	{SrcDir}NewApp.a
	Echo "{DriverName}: Assembling new app jump table"
	Asm {AsmOptions} {SrcDir}NewApp.a -o {Targ}

{ObjDir}ChooserLDEF.c.o	 {SrcDir}ChooserLDEF.c {SrcDir}ChooserLDEF.h
	Echo "{DriverName}: Compiling Chooser LDEF"
	C {COptions} {SrcDir}ChooserLDEF.c -o {Targ}

{ObjDir}ChooserPACK.c.o	 {SrcDir}ChooserPACK.c
	Echo "{DriverName}: Compiling Chooser PACK"
	C {COptions} {SrcDir}ChooserPACK.c -o {Targ}

{ObjDir}ChooserPACK.a.o	 	{SrcDir}ChooserPACK.a
	Echo "{DriverName}: Assembling Chooser PACK"
	Asm {AsmOptions} {SrcDir}ChooserPACK.a -o {Targ}

{ObjDir}GlobalData.c.o	 {SrcDir}GlobalData.c {SrcDir}GlobalData.h
	Echo "{DriverName}: Compiling global data support"
	C {COptions} {SrcDir}GlobalData.c -o {Targ}


### Rez statements ###

{DestDir}{DriverName}  {SrcDir}OldApp.r {SrcDir}CommonDefines.h
	Echo "{DriverName}: Rezzing old application"
	Rez {RezOptions} -append {SrcDir}OldApp.r -o {Targ}
		
{DestDir}{DriverName}  {SrcDir}NewApp.r {SrcDir}CommonDefines.h
	Echo "{DriverName}: Rezzing new application"
	Rez {RezOptions} -append {SrcDir}NewApp.r -o {Targ}

{DestDir}{DriverName}  {SrcDir}ChooserPACK.r
	Echo "{DriverName}: Rezzing Chooser PACK resources"
	Rez {RezOptions} -append {SrcDir}ChooserPACK.r -o {Targ}

{DestDir}{DriverName}  {SrcDir}ChooserLDEF.r {SrcDir}ChooserLDEF.h
	Echo "{DriverName}: Rezzing Chooser LDEF resources"
	Rez {RezOptions} -append {SrcDir}ChooserLDEF.r -o {Targ}


### Link statements ###

{DestDir}{DriverName}   {ObjDir}NewApp.a.o {ObjDir}NewApp.c.o {ObjDir}GlobalData.c.o
	Echo "{DriverName}: linking new API"
	Link										
		{ObjDir}NewApp.a.o						
		{ObjDir}NewApp.c.o						
		{ObjDir}GlobalData.c.o					
		{Libraries}Interface.o					
		{Libraries}RunTime.o					
		{LinkOptions}							
		-rt 'pdvr'={NewSegID}					
		-sg NewAppOverrides						
		-m SD_JumpTable							
		-o {Targ}

{DestDir}{DriverName}  {ObjDir}OldApp.a.o {ObjDir}OldApp.c.o
	Echo "{DriverName}: linking old API"
	Link										
		{ObjDir}OldApp.a.o						
		{ObjDir}OldApp.c.o						
		{LinkOptions}							
		-rt 'pdvr'={OldSegID}					
		-sg OldAppOverrides						
		-m SD_JumpTable							
		-o {Targ}

{DestDir}{DriverName}  {ObjDir}ChooserPACK.a.o {ObjDir}ChooserPACK.c.o
	Echo "{DriverName}: Linking PACK"
	Link										
		{ObjDir}ChooserPACK.a.o					
		{ObjDir}ChooserPACK.c.o					
		-rt PACK=-4096							
		-sg ChooserPACK							
		-m PACKENTRY							
		-o {Targ}

{DestDir}{DriverName}  {ObjDir}ChooserLDEF.c.o
	Echo "{DriverName}: Linking LDEF"
	Link										
		{ObjDir}ChooserLDEF.c.o					
		-rt LDEF=-4096							
		-sg ChooserLDEF							
		-m MAIN									
		-o {Targ} 


### Set Attributes ###

{DestDir}{DriverName} 														
	{ObjDir}ChooserLDEF.c.o  {SrcDir}ChooserLDEF.r								
	{ObjDir}ChooserPACK.a.o  {ObjDir}ChooserPACK.c.o  {SrcDir}ChooserPACK.r		
	{ObjDir}OldApp.a.o       {ObjDir}OldApp.c.o       {SrcDir}OldApp.r			
	{ObjDir}NewApp.a.o       {ObjDir}NewApp.c.o       {SrcDir}NewApp.r			
	{SrcDir}CommonDefines.h														
	{ObjDir}GlobalData.c.o
	Echo "{DriverName}: Setting type/creator  {NewerDeps}"
	SetFile -a Bi -t 'pdvr' -c {DriverCreator} {Targ}
