/*
	ChooserSupport.r - other resources needed in order for driver to work
	with the Chooser.
	
    3/22/94 - dmh - Updated for the b4 seed.
   12/18/93 - dmh - Updated for the b3 seed.
	9/13/93 - dmh - Updated for the b2 seed.
	
	Copyright  1992-1994 Apple Computer, Inc.
	All rights reserved.
*/

#include "Types.r"
#include "SysTypes.r"
#include "PrintingResTypes.r"

//--------------------------------------------------------------------------------------------
// THINGS TO CONTROL THE DEFAULT CHOOSING MECHANSIM
//--------------------------------------------------------------------------------------------

// what type of communication does this device use (this is the default, as the actual
// value can be found in the desktop printer).
resource 'look' (-4096, sysheap, purgeable) {
	1,				// use the first in our list by default
	
	{
	"AppleTalk",	-4096,		isAppleTalk,				"LaserWriter";
	"Servers",		-4095,		isAppleTalk+isPrinterShare,	"LaserWriterIS";
	"Serial",		-4094,		iconCells,					"Modem Port";
	};
};


resource 'comm' (-4096, sysheap, purgeable) {
	PAP
		{
		8,
		"",
		0, 0, 0, 0
		};
};

resource 'comm' (-4095, sysheap, purgeable) {
	PrinterShare
		{
		"",
		0
		};
};

resource 'comm' (-4094, sysheap, purgeable) {
	Serial
		{
		baud57600,		/* Output baud rate */
		noParity,		/* Output parity */
		oneStop,		/* Output stop bits */
		data8,			/* Output data size */
		0x00010000,		/* Output handshaking */
		0x00000000,
		baud57600,		/* Input baud rate */
		noParity,		/* Input parity */
		oneStop,		/* Input stop bits */
		data8,			/* Input data bits */
		0,				/* Input handshaking */
		0,
		1024,			/* Input buffer size */
		".AIn",			/* Input driver name */
		".AOut"			/* Output driver name */
		};
};



//--------------------------------------------------------------------------------------------
// STANDARD CHOOSER PACK STUFF
//--------------------------------------------------------------------------------------------

// NBP Lookup type (maxed out so resource file won't need updating)
resource 'STR ' (-4096, sysheap, purgeable)
{
	"XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
};

// NBP timeout value
type 'GNRL'
{
	byte;	// timeout
	byte;	// retries
};

resource 'GNRL' (-4096, sysheap, purgeable)
{
	11,
	5
};

// title string (we put the pop-up control here, so we don't want a title)
resource 'STR ' (-4091, sysheap, purgeable)
{
	"";
};

// "left" button title
resource 'STR ' (-4093, sysheap, purgeable)
{
	"Create";
};

// rectangle list
resource 'nrct' (-4096, sysheap, purgeable) {
	{
	{112, 251, 132, 311};			// left button
	{0,0,0,0};						// right button
	{-101, 180, -101+20, 400};		// on button (location of device list - popup is placed here)
	{0,0,0,0};						// off button
	{0,0,0,0};						// button label
	};
};

// Menu used to select between direct connect, AppleTalk, and Servers
resource 'MENU' (-4096, sysheap, purgeable)
{
	-4096,
	textMenuProc,
	0xFFFFFFFF,	
	enabled,
	"",
	{
	}
};

// Pop-up control used to select between direct connect printers and those being shared on the network
resource 'CNTL' (-4096, sysheap, purgeable)
{
	{0, 0, 20, 213},							// zero based control location
	0,											// Title options 0 = Left justified
	visible,									// Should we display the control?
	95,											// Title Width
	-4096,										// 'MENU' to display
	popupMenuCDEFproc+popupFixedWidth,			// CDEF = CDEFID * 16 + varCode
	0, 											// refCon = ResType to append = None
	"Connect via:"								// Control title
};

resource 'DITL' (-4096, sysheap, purgeable) 
{
	{
		{3, 238, 23, 238 + 213}, 
			Control {enabled, -4096},
	};
};
