#
#	File:		ImageWriter.make
#
#	Contains:	Makefile for the sample ImageWriter II driver.
#
#	Copyright:	 1983-1994 by Apple Computer, Inc., all rights reserved.
#
#	Change History (most recent first):
#
#				12/22/93	dmh		Added custom dialog code.
#				 9/12/93	dmh		Modified for b2 seed.
#				 4/26/93	dmh		Modified for b1 seed.
#				 2/04/93	dmh		Modified for a5 seed.
#		 <5>	10/22/92	DB		Added changes for version control
#
#

#======= Point these variables to your interface and library directories =======

GraphicsInterfaces	=	{CIncludes}
GXLibrariesSources	=	{CIncludes}


#========== Directories Containing Source and Object Files ==========

ObjDir					=	:Objects:
SrcDir					=	
DestDir					=	


#========== Compiler Options ==========

AsmOptions				=	-case obj
RezOptions				=	-i {GraphicsInterfaces} -d SystemSevenOrLater=1
COptions				=	-mbg off -b2 -i {GraphicsInterfaces}
LinkOptions				=	-ra =resSysHeap,resPurgeable

DriverName 		= ImageWriter
DriverType 		= 'pdvr'
DriverCreator 	= 'IWcd'
NewSegID		= 0
OldSegID		= 1

# Compile and assemble statements
{ObjDir}OldApp.c.o  {SrcDir}OldApp.c
	Echo "{DriverName}: Compiling old application"
	C {COptions} -o {ObjDir} {SrcDir}OldApp.c

{ObjDir}OldApp.a.o	 	{SrcDir}OldApp.a
	Echo "{DriverName}: Assembling old app jump table"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}OldApp.a -o {ObjDir}

{ObjDir}NewApp.c.o	 {SrcDir}NewApp.c
	Echo "{DriverName}: Compiling new application"
	C {COptions} -o {ObjDir} {SrcDir}NewApp.c

{ObjDir}NewApp.a.o	 	{SrcDir}NewApp.a
	Echo "{DriverName}: Assembling new app jump table"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}NewApp.a -o {ObjDir}

{ObjDir}CommonCode.c.o	 	{SrcDir}CommonCode.c
	Echo "{DriverName}: Compiling common code"
	C {COptions} -o {ObjDir} {SrcDir}CommonCode.c

{ObjDir}ChooserSupport.c.o	 {SrcDir}ChooserSupport.c
	Echo "{DriverName}: Compiling Chooser support"
	C {COptions} -o {ObjDir} {SrcDir}ChooserSupport.c

{ObjDir}ChooserSupport.a.o	 	{SrcDir}ChooserSupport.a
	Echo "{DriverName}: Assembling Chooser support"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}ChooserSupport.a -o {ObjDir}

# Link and Rez statements
{DestDir}{DriverName}  {SrcDir}OldApp.r
	Echo "{DriverName}: Rezzing old application"
	Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}OldApp.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}
		
{DestDir}{DriverName}  {ObjDir}OldApp.c.o
	Echo "{DriverName}: Linking old application"
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

"{ObjDir}text library.c.o"		 {GXLibrariesSources}"text library.c"
	Echo "compiling text library.c"
	C {COptions} -o {ObjDir} {GXLibrariesSources}"text library.c"

"{ObjDir}picture library.c.o"		 {GXLibrariesSources}"picture library.c"
	Echo "compiling picture library.c"
	C {COptions} -o {ObjDir} {GXLibrariesSources}"picture library.c"

"{ObjDir}font library.c.o"		 {GXLibrariesSources}"font library.c"
	Echo "compiling font library.c"
	C {COptions} -o {ObjDir} {GXLibrariesSources}"font library.c"

"{ObjDir}color library.c.o"		 {GXLibrariesSources}"color library.c"
	Echo "compiling color library.c"
	C {COptions} -o {ObjDir} {GXLibrariesSources}"color library.c"

"{ObjDir}graphics library.c.o"		 {GXLibrariesSources}"graphics library.c"
	Echo "compiling graphics library.c"
	C {COptions} -o {ObjDir} {GXLibrariesSources}"graphics library.c"

{DestDir}{DriverName}  {SrcDir}NewApp.r
	Echo "{DriverName}: Rezzing new application"
	Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}NewApp.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}NewApp.a.o							
	{ObjDir}NewApp.c.o							
	"{ObjDir}text library.c.o"					
	"{ObjDir}picture library.c.o"				
	"{ObjDir}font library.c.o"					
	"{ObjDir}color library.c.o"					
	"{ObjDir}graphics library.c.o"				
	{ObjDir}CommonCode.c.o
	Echo "{DriverName}: linking new API"
	Link										
		{ObjDir}NewApp.a.o						
		{ObjDir}NewApp.c.o						
		{ObjDir}CommonCode.c.o					
		
		"{ObjDir}text library.c.o"				
		"{ObjDir}picture library.c.o"			
		"{ObjDir}font library.c.o"				
		"{ObjDir}color library.c.o"				
		"{ObjDir}graphics library.c.o"			
		
		"{Libraries}Interface.o" 				
		"{Libraries}Runtime.o"	 				
		-msg nodup						 		
		
		{LinkOptions}							
		-rt {DriverType}={NewSegID}				
		-c {DriverCreator}						
		-t {DriverType}							
		-sg {DriverName}						
		-m SD_JumpTable							
		
		-o {DestDir}{DriverName}
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}OldApp.a.o							
	{ObjDir}OldApp.c.o							
	{ObjDir}CommonCode.c.o
	Echo "{DriverName}: linking old API"
	Link										
		{ObjDir}OldApp.a.o						
		{ObjDir}OldApp.c.o						
		{ObjDir}CommonCode.c.o					
		
		"{Libraries}Interface.o" 				
		"{Libraries}Runtime.o"	 				
		
		{LinkOptions}							
		-rt {DriverType}={OldSegID}				
		-c {DriverCreator}						
		-t {DriverType}							
		-sg {DriverName}						
		-m SD_JumpTable							
		
		-o {DestDir}{DriverName}
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  {SrcDir}ChooserSupport.r
	Echo "{DriverName}: Rezzing Chooser resources"
	Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}ChooserSupport.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}ChooserSupport.a.o					
	{ObjDir}ChooserSupport.c.o
	Echo "{DriverName}: Linking PACK"
	Link										
		{ObjDir}ChooserSupport.a.o				
		{ObjDir}ChooserSupport.c.o				
		
		"{Libraries}Interface.o" 				
		
		-rt PACK=-4096							
		-sg PrintingPACK						
		-m EntryPoint							
		
		-o {Targ}

{DestDir}{DriverName}	 {ObjDir}ChooserSupport.c.o
	Echo "{DriverName}: Linking LDEF"
	Link -w -rt LDEF=-4096 -m LDEF -sg LDEF -o {Targ} {ObjDir}ChooserSupport.c.o
