#==============================================================================================
#
#	Make FILE:		ImageWriterLQ.make
#
#	VERSION:		1.0
#
#	COPYRIGHT:		(c) 1992-1994 Apple Computer Inc.
#						All rights reserved.
#
#	PURPOSE:		This file contains the build commands for the
#					ImageWriter LQ driver.
#
#	4/26/93 - dmh - Made makefile totally self-supporting for b1 seed.
#	9/13/93 - dmh - Updated for the b2 seed.
#  12/18/93 - dmh - Updated for the b3 seed.
#	8/28/94 - dmh - Finalized for SDK.
#
#==============================================================================================

#======= Point these variables to your library directory =======

GXLibrariesSources		= 'Backwash:QuickDraw GX Libraries:Graphics Libraries:'

#========== Directories Containing Source and Object Files ==========

Objects					=	:Objects:
Sources					=	
Targets					=

#========== Compiler Options ==========

AsmOptions				=	-case obj
COptions				=	-b2 -d applec -i {CIncludes}
DriverLinkOptions		=	-ra =resSysHeap,resPurgeable

#========== Printing Manager Dependent Header Files ==========

PrintManagerHeaderFiles	=	{CIncludes}PrintingManager.h		
							{CIncludes}PrintingMessages.h		
							{CIncludes}PrintingExtensions.h	
							{CIncludes}Collections.h			
							{CIncludes}Messages.h				
							{CIncludes}PrintingResTypes.h		
							{CIncludes}PrintingErrors.h

GraphicsHeaderFiles		=	{CIncludes}"graphics routines.h"	
							{CIncludes}"graphics libraries.h"	
							{CIncludes}"math routines.h"			


#========== Files to Link into OldAPI Segment ==========

OldAPISegObjs	=	"{Objects}OldAPIMsgJumpTable.a.o"			
					"{Objects}OldAPIMessageIntf.c.o"			
					"{Libraries}"Runtime.o


#========== Files to Link into Universal Message Segment ==========

UnivSegObjs		=	"{Objects}UniversalMsgJumpTable.a.o"		
					"{Objects}UniversalMessageIntf.c.o"			
					"{Objects}DialogRoutines.c.o"				
					"{Objects}text library.c.o"					
					"{Objects}picture library.c.o"				
					"{Objects}font library.c.o"					
					"{Objects}color library.c.o"				
					"{Objects}graphics library.c.o"				
					"{Libraries}"Runtime.o						
					"{Libraries}"Interface.o					


#========== Files to Link into the Chooser PACK ==========

ChooserPackObjs =	"{Objects}ChooserSupport.a.o"				
					"{Objects}ChooserSupport.c.o"				
					"{Libraries}Interface.o"


#========== Files to Link into the Chooser LDEF ==========

ChooserLDEFObjs =	"{Objects}ChooserSupport.c.o"				


#========== Link and Rez Build Statements ==========

"ImageWriterLQ"		{OldAPISegObjs} 													
					{UnivSegObjs}								
					{ChooserPackObjs}							
					{ChooserLDEFObjs}							
					"{Sources}ImageWriterLQ.make"				
					"{Sources}Resources.r"						
					"{Sources}OldAPIResources.r"				
					"{Sources}UniversalMessageResources.r"
		Echo "Linking ImageWriterLQ"
		Link {OldAPISegObjs}									
			  {DriverLinkOptions}								
			  -rt pdvr=1										
			  -sg "ImageWriterLQ"								
			  -m SD_OldAPIMsgJumpTable							
			  -o "{Objects}IWLQ_OldAPISeg"
		Link {UnivSegObjs}										
			  {DriverLinkOptions}								
			  -rt pdvr=0										
			  -sg "ImageWriterLQ"								
			  -m SD_UniversalMsgJumpTable						
			  -o "{Objects}IWLQ_UnivSeg"
		Link	{ChooserPackObjs}								
				-rt PACK=-4096									
				-sg PrintingPACK								
				-m EntryPoint									
				-o "{Objects}IWLQ_PACK"
		Link	{ChooserLDEFObjs}								
				-w												
				-rt LDEF=-4096									
				-sg LDEF										
				-m LDEF											
				-o "{Objects}IWLQ_LDEF"
		Echo "Rezzing ImageWriterLQ Driver"
		Rez	-rd -i {RIncludes} -c 'scLQ' -t 'pdvr' -ov -s {Objects} 
				-o "{Targets}ImageWriterLQ" "{Sources}Resources.r" "{Sources}OldAPIResources.r" 
				"{Sources}UniversalMessageResources.r" "{Sources}ChooserSupport.r" -append


#========== Assemble Build Statements - OldAPIMsgJumpTable.a ==========

"{Objects}OldAPIMsgJumpTable.a.o"		 	"{Sources}OldAPIMsgJumpTable.a"		
											"{Sources}ImageWriterLQ.make"
	Echo "Assembling OldAPIMsgJumpTable.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}OldAPIMsgJumpTable.a -o {Objects}OldAPIMsgJumpTable.a.o
	

#========== Assemble Build Statements - UniversalMsgJumpTable.a ==========

"{Objects}UniversalMsgJumpTable.a.o"	 	"{Sources}UniversalMsgJumpTable.a"	
											"{Sources}ImageWriterLQ.make"
	Echo "Assembling UniversalMsgJumpTable.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}UniversalMsgJumpTable.a -o {Objects}UniversalMsgJumpTable.a.o
	

#========== Assemble Build Statements - ChooserSupport.a ==========

"{Objects}ChooserSupport.a.o"	 	"{Sources}ChooserSupport.a"		
									"{Sources}ImageWriterLQ.make"
	Echo "Assembling ChooserSupport.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}ChooserSupport.a -o {Objects}ChooserSupport.a.o


#========== Compile Build Statements - OldAPIMessageIntf.c ==========

"{Objects}OldAPIMessageIntf.c.o"		"{Sources}OldAPIMessageIntf.c"	
										{PrintManagerHeaderFiles}		
										{GraphicsHeaderFiles}			
										"{Sources}ImageWriterLQ.make"	
										"{Sources}Resources.h" 			
										"{Sources}OldAPIMessageIntf.h"
	Echo "Compiling OldAPIMessageIntf.c"
	C "{Sources}OldAPIMessageIntf.c" -o "{Objects}OldAPIMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - UniversalMessageIntf.c ==========

"{Objects}text library.c.o"			 {GXLibrariesSources}"text library.c"
	Echo "compiling text library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"text library.c"

"{Objects}picture library.c.o"		 {GXLibrariesSources}"picture library.c"
	Echo "compiling picture library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"picture library.c"

"{Objects}font library.c.o"			 {GXLibrariesSources}"font library.c"
	Echo "compiling font library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"font library.c"

"{Objects}color library.c.o"		 {GXLibrariesSources}"color library.c"
	Echo "compiling color library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"color library.c"

"{Objects}graphics library.c.o"		 {GXLibrariesSources}"graphics library.c"
	Echo "compiling graphics library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"graphics library.c"


"{Objects}UniversalMessageIntf.c.o"		"{Sources}UniversalMessageIntf.c"		
										{PrintManagerHeaderFiles}				
										{GraphicsHeaderFiles}					
										"{Sources}ImageWriterLQ.make"			
										"{Sources}Resources.h" 					
										"{Sources}UniversalMessageIntf.h"
	Echo "Compiling UniversalMessageIntf.c"
	C "{Sources}UniversalMessageIntf.c" -o "{Objects}UniversalMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - ChooserSupport.c ==========

"{Objects}ChooserSupport.c.o"		"{Sources}ChooserSupport.c"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}ImageWriterLQ.make"		
									"{Sources}ChooserSupport.a" 		
									"{Sources}ChooserSupport.r"
	Echo "Compiling ChooserSupport.c"
	C "{Sources}ChooserSupport.c" -o "{Objects}ChooserSupport.c.o"  {COptions}


#========== Compile Build Statements - DialogRoutines.c ==========

"{Objects}DialogRoutines.c.o"		"{Sources}DialogRoutines.c"			
									"{Sources}DialogRoutines.h"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}ImageWriterLQ.make"		
									"{Sources}Resources.h" 				
									"{Sources}UniversalMessageIntf.h"
	Echo "Compiling DialogRoutines.c"
	C "{Sources}DialogRoutines.c" -o "{Objects}DialogRoutines.c.o"  {COptions}


