/* ------------------------------------------------------------------------------
FILENAME
	Resources.r

DESCRIPTION
	This module contains the standard ImageWriter LQ constants, types, and resources 
	that are common to most drivers.  They include the appropriate bundle and
	icon resources.
	
	Note: All driver resources should be designated to be loaded into the system
	heap.
		
COPYRIGHT
	 Copyright Apple Computer, Inc. 1992-1994
	 All rights reserved. 

	 12/20/93		dmh		Sync'd with the shipping 1.0b3 GX driver.
	  3/22/94		dmh		Updated for the b4 seed.
	  5/03/94		dmh		Updated for the f2 seed.
	  8/28/94		dmh		Sync'd with the shipping 1.0.1 GX driver.

-------------------------------------------------------------------------------- */

// System 7.0 Compatible
#define SystemSevenOrLater		1

// Include System Resource Definitions
#include "Types.r"
#include "SysTypes.r"

// Include the ImageWriter LQ driver constants that are used in the resources 
#include "Resources.h"

// Include the public QuickDraw GX printing files 
#include "PrintingResTypes.r"


// Include the ImageWriter LQ Driver's Code Segments ===== */

include "IWLQ_OldAPISeg";
include "IWLQ_UnivSeg";


/**********************************************************************************
 *        						CONSTANTS		 									 				 *
 *********************************************************************************/

#define	kDriverIconID				(gxPrintingDriverBaseID + 1)		// Resource ID of the driver file's FREF, BNDL, and icons 
#define	kDTPIconID					(gxPrintingDriverBaseID + 2)		// Resource ID of the desktop printer file's FREF and icons 

#define	kDTPCurrentNotSharedID	(gxPrintingDriverBaseID + 3)		// Resource ID of DTP icon for current/not shared representation 
#define	kDTPNotCurrentSharedID	(gxPrintingDriverBaseID + 4)		// Resource ID of DTP icon for not current/shared representation 
#define	kDTPCurrentSharedID		(gxPrintingDriverBaseID + 5)		// Resource ID of DTP icon for current/shared representation 
#define	kDTPNotActiveID			(gxPrintingDriverBaseID + 6)		// Resource ID of DTP icon for not active representation 
#define	kDTPNoGXID					(gxPrintingDriverBaseID + 7)		// Resource ID of DTP icon for no GX representation 
#define	kDTPPuzzleID				(gxPrintingDriverBaseID + 8)		// Resource ID of DTP icon for puzzle representation 


/**********************************************************************************
 *        						TYPES				 									 				 *
 *********************************************************************************/

// File type resource for use with the FREF below 
type kDrvrCreatorType
{
	pstring;
};


/**********************************************************************************
 *        						RESOURCES			 							 					 *
 *********************************************************************************/

resource kDrvrCreatorType (0, sysheap)
{
	kDriverName " Driver"
};


resource 'vers' (gxPrintingDriverBaseID, purgeable, sysheap) {
	0x01, 0x00, release, 0x00,
	verUS,
	"1.00",
	"1.00, Copyright \251 Apple Computer, Inc. 1989-1994"
};


// Normal 'vers' resources so we can tell what version we've got.

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0,  Apple Computer, Inc. 1989-1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"Sample Printer Driver"
};


// The BNDL resource references icons for both the driver file and desktop printer file 
// representations. 
resource 'BNDL' (kDriverIconID, sysheap, purgeable) 
{
	kDrvrCreatorType,
	0,
	{ 
		'ICN#', { 0, kDTPIconID; 1, kDTPCurrentNotSharedID; 2, kDTPNotCurrentSharedID; 3, kDTPCurrentSharedID; 4, kDTPNotActiveID; 5, kDTPNoGXID; 6, kDTPPuzzleID},
		'FREF', { 0, kDTPIconID; 1, kDTPCurrentNotSharedID; 2, kDTPNotCurrentSharedID; 4, kDTPCurrentSharedID; 4, kDTPNotActiveID; 5, kDTPNoGXID; 6, kDTPPuzzleID; 0, kDriverIconID}
	}
};

// The FREF for the ImageWriter LQ driver file 
resource 'FREF' (kDriverIconID, sysheap, purgeable) 
{ 
	kDrvrFileType, 
	0, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file 
resource 'FREF' (kDTPIconID, sysheap, purgeable) 
{ 
	'dpnn', 
	0, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in current/not shared mode
resource 'FREF' (kDTPCurrentNotSharedID, sysheap, purgeable) 
{ 
	'dpcn', 
	1, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in not current/shared mode
resource 'FREF' (kDTPNotCurrentSharedID, sysheap, purgeable) 
{ 
	'dpns', 
	2, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in current/shared mode
resource 'FREF' (kDTPCurrentSharedID, sysheap, purgeable) 
{ 
	'dpcs', 
	3, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in not active mode
resource 'FREF' (kDTPNotActiveID, sysheap, purgeable) 
{ 
	'dpna', 
	4, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in no GX mode
resource 'FREF' (kDTPNoGXID, sysheap, purgeable) 
{ 
	'dvcf', 
	4, 
	"" 
};

// The FREF for the ImageWriter LQ desktop printer file in puzzle mode
resource 'FREF' (kDTPPuzzleID, sysheap, purgeable) 
{ 
	'dppz', 
	6, 
	"" 
};


/************** ImageWriter LQ Driver Icons **************/
/************** ImageWriter LQ Desktop Printer Icons - notCurrent/notShared  representation **************/

data 'ics#' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 1FFE 300D 2447 34AC 24A4 366C 2004"            /* ....0$G4$6l . */
	$"3FFC FFFF E005 BFFF A001 FFFE 0000 0000"            /* ?............. */
	$"0000 1FFE 3FFF 3FFF 3FFC 3FFC 3FFC 3FFC"            /* ....?.?.?.?.?.?. */
	$"3FFC FFFF FFFF FFFF FFFF FFFE 0000 0000"            /* ?............... */
};

data 'ics4' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 000F FFFF FFFF FFF0"            /* ................ */
	$"00FE 0000 0000 EFCF 00F0 0F00 0F00 0FFF"            /* ............... */
	$"00FE 0F00 F0F0 EF00 00F0 0F00 F0F0 0F00"            /* ................ */
	$"00FE 0FF0 0FF0 EF00 00F0 0000 0000 0F00"            /* ................ */
	$"00FF FFFF FFFF FF00 FFFE EEEE EEEE EFFF"            /* ................ */
	$"FEFC CCCC CCCC CFCF F8FF FFFF FFFF FFFF"            /* .......... */
	$"F3EC CCCC CCCC CCCF FFFF FFFF FFFF FFF0"            /* .......... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

resource 'ics8' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 FFFB F5F5 F5F5 F5F5 F5F5 FBFF 2BFF"            /* ..............+. */
	$"0000 FFF5 F5FF F5F5 F5FF F5F5 F5FF FFFF"            /* ................ */
	$"0000 FFFB F5FF F5F5 FFF5 FFF5 FBFF 0000"            /* ................ */
	$"0000 FFF5 F5FF F5F5 FFF5 FFF5 F5FF 0000"            /* ................ */
	$"0000 FFFB F5FF FFF5 F5FF FFF5 FBFF 0000"            /* ................ */
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"FFFF FFFC FCFC FCFC FCFC FCFC FCFF FFFF"            /* ................ */
	$"FFFC FF2B 2B2B 2B2B 2B2B 2B2B 2BFF 2BFF"            /* ...++++++++++.+. */
	$"FFE3 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFD8 FC2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF"            /* ..++++++++++++. */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'ICN#' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 01FF FFF8"            /* ................ */
	$"0200 0014 0400 0022 0500 00A2 0400 003E"            /* ......."......> */
	$"0520 60A0 0420 9020 0521 08A0 0421 0820"            /* . `.  .!..!.  */
	$"0521 28A0 0420 9020 053C 68A0 0400 0020"            /* .!(.  .<h...  */
	$"0500 00A0 0400 0020 0FFF FFF0 F800 001F"            /* ...... ........ */
	$"8FFF FFF5 F800 001D 8800 0015 8FFF FFF5"            /* ............. */
	$"A000 0005 8000 0007 FFFF FFFC D555 5554"            /* ..........UUT */
	$"FFFF FFFC 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 01FF FFF8"            /* ................ */
	$"03FF FFFC 07FF FFFE 07FF FFFE 07FF FFFE"            /* ................ */
	$"07FF FFE0 07FF FFE0 07FF FFE0 07FF FFE0"            /* ................ */
	$"07FF FFE0 07FF FFE0 07FF FFE0 07FF FFE0"            /* ................ */
	$"07FF FFE0 07FF FFE0 0FFF FFF0 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFFC"            /* ................ */
	$"FFFF FFFC 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 000F FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"0000 00FC 0C0C 0C0C 0C0C 0C0C 0C0F CF00"            /* ............... */
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 C0FC CCF0"            /* ..... */
	$"0000 0F0E 0C0C 0C0C 0C0C 0C0C ECFC CCF0"            /* ............... */
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 C0FF FFF0"            /* ...... */
	$"0000 0F0E 0CFC 0C0C 0FFC 0C0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0F0 C0C0 F0CF C0C0 C0F0 0000"            /* ........ */
	$"0000 0F0E 0CFC 0C0F 0C0C FC0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0F0 C0CF C0C0 F0C0 C0F0 0000"            /* ........ */
	$"0000 0F0E 0CFC 0C0F 0CFC FC0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0F0 C0C0 F0CF C0C0 C0F0 0000"            /* ........ */
	$"0000 0F0E 0CFF FF0C 0FFC FC0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 C0F0 0000"            /* ...... */
	$"0000 0F0E 0C0C 0C0C 0C0C 0C0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 C0F0 0000"            /* ...... */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"FFFF FCCC CCCC CCCC CCCC CCCC CCCF FFFE"            /* ..... */
	$"FCCC FEEE EEEE EEEE EEEE EEEE EEEF CFEF"            /* .............. */
	$"FEEE FCCC CCCC CCCC CCCC CCCC CCCF EF0F"            /* ..... */
	$"FCCC FCCC CCCC CCCC CCCC CCCC CCCF CFCF"            /* .. */
	$"FC88 FFFF FFFF FFFF FFFF FFFF FFFF CFDF"            /* .............. */
	$"FC33 CCCC CCCC CCCC CCCC CCCC CCCC CFEF"            /* .3. */
	$"FCCC CCCC CCCC CCCC CCCC CCCC CCCC CFFE"            /* .. */
	$"FDED EDED EDED EDED EDED EDED EDED EF00"            /* ................ */
	$"FCEC ECEC ECEC ECEC ECEC ECEC ECEC EF00"            /* ................ */
	$"EFFF FFFF FFFF FFFF FFFF FFFF FFFF FEFF"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

resource 'icl8' (kDTPIconID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 2BFF 0000"            /* ............+... */
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF2B 2B2B FF00"            /* ...........+++.. */
	$"0000 0000 00FF F5FB F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FBF5 FF2B 2B2B FF00"            /* ...........+++.. */
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FFFF FF00"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5F5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFFF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"FFFF FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF FFFC"            /* +++++++++++..... */
	$"FF2B 2B2B FFFC FCFC FCFC FCFC FCFC FCFC"            /* .+++............ */
	$"FCFC FCFC FCFC FCFC FCFC FCFF 2BFF FCFF"            /* ............+... */
	$"FFFC FCFC FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FCFF F5FF"            /* +++++++++++..... */
	$"FF2B 2B2B FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .+++.+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF 2BFF 2BFF"            /* +++++++++++.+.+. */
	$"FF2B E3E3 FFFF FFFF FFFF FFFF FFFF FFFF"            /* .+.............. */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 2BFF FAFF"            /* ............+... */
	$"FF2B D8D8 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FCFF"            /* +++++++++++++... */
	$"FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .+++++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFC"            /* +++++++++++++... */
	$"FFF9 FCF9 FCF9 FCF9 FCF9 FCF9 FCF9 FCF9"            /* ................ */
	$"FCF9 FCF9 FCF9 FCF9 FCF9 FCF9 FCFF 0000"            /* ................ */
	$"FFF8 FBF8 FBF8 FBF8 FBF8 FBF8 FBF8 FBF8"            /* ................ */
	$"FBF8 FBF8 FBF8 FBF8 FBF8 FBF8 FBFF 0000"            /* ................ */
	$"FCFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


/************** ImageWriter LQ Desktop Printer Icons - Not Current/Shared  representation **************/

data 'ICN#' (kDTPNotCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 000F FF80"            /* ............... */
	$"0010 0140 0020 0220 0040 0220 0050 63E0"            /* ...@. . .@. .Pc. */
	$"0050 9200 0051 0A00 0051 2A00 0050 9200"            /* .P..Q...Q*..P. */
	$"005C 6A00 0040 0200 00FF FF00 0F80 01F0"            /* .\j..@......... */
	$"08FF FF70 0F80 01D0 0880 0150 0BFF FF70"            /* ...p....P...p */
	$"0B00 0040 0800 0040 0AAA BEC0 0FFF E3C0"            /* ...@...@.... */
	$"0000 2200 0000 3E00 0000 2A00 BFFF C9FD"            /* .."...>...*... */
	$"0000 1400 BFFF E3FD 0000 0000 0000 0000"            /* ............... */
	$"0000 0000 0000 0000 0000 0000 000F FF80"            /* ............... */
	$"001F FFC0 003F FFE0 007F FFE0 007F FFE0"            /* ....?.......... */
	$"007F FE00 007F FE00 007F FE00 007F FE00"            /* ................ */
	$"007F FE00 007F FE00 00FF FF00 0FFF FFF0"            /* ................ */
	$"0FFF FFF0 0FFF FFF0 0FFF FFF0 0FFF FFF0"            /* ................ */
	$"0FFF FFC0 0FFF FFC0 0FFF FFC0 0FFF FFC0"            /* ............ */
	$"0000 3E00 0000 3E00 0000 3E00 FFFF FFFF"            /* ..>...>...>..... */
	$"FFFF F7FF FFFF E3FF 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (kDTPNotCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FFFF FFFF FFFF F000 0000"            /* ................ */
	$"0000 0000 000F 0000 0000 000F CF00 0000"            /* ............... */
	$"0000 0000 00F0 0000 0000 00FC CCF0 0000"            /* ............... */
	$"0000 0000 0F00 0000 0000 00FC CCF0 0000"            /* ............... */
	$"0000 0000 0F0F 0000 0FF0 00FF FFF0 0000"            /* ................ */
	$"0000 0000 0F0F 0000 F00F 00F0 0000 0000"            /* ................ */
	$"0000 0000 0F0F 000F 0000 F0F0 0000 0000"            /* ................ */
	$"0000 0000 0F0F 000F 00F0 F0F0 0000 0000"            /* ................ */
	$"0000 0000 0F0F 0000 F00F 00F0 0000 0000"            /* ................ */
	$"0000 0000 0F0F FF00 0FF0 F0F0 0000 0000"            /* ................ */
	$"0000 0000 0F00 0000 0000 00F0 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 FFFF FCCC CCCC CCCC CCCF FFFF 0000"            /* ......... */
	$"0000 FCCC FEEE EEEE EEEE EEEF CFEF 0000"            /* .............. */
	$"0000 FEEE FCCC CCCC CCCC CCCF EF0F 0000"            /* ......... */
	$"0000 FCCC FCCC CCCC CCCC CCCF CFCF 0000"            /* ...... */
	$"0000 FC88 FFFF FFFF FFFF FFFF CFEF 0000"            /* .............. */
	$"0000 FC33 CCCC CCCC CCCC CCCC CF00 0000"            /* ...3... */
	$"0000 FCCC CCCC CCCC CCCC CCCC CF00 0000"            /* ...... */
	$"0000 FCEC ECEC ECEC ECFF FFFC EF00 0000"            /* ................ */
	$"0000 EFFF FFFF FFFF FFFC CCFF FE00 0000"            /* ............... */
	$"0000 0000 0000 0000 00FC CCF0 0000 0000"            /* ............... */
	$"0000 0000 0000 0000 00FF FFE0 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FC FCE0 0000 0000"            /* ................ */
	$"CCDD DCDD DDDD EEEE EECC FCCE EEEE DDDC"            /* ............. */
	$"00CC CCCC CCCC CCCC CCCF 0FCC CCCC CCC0"            /* .. */
	$"CDDD DDDE EEEE EEEE EFF0 00FE EEEE DDDC"            /* ............... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl8' (kDTPNotCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FF F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5FF F6FF 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 FFF5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FF00 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FF00 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5F5 FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5FF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FEFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFE 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 FEFE FEFE FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FEFE FEFF 0000 0000"            /* +++++++......... */
	$"0000 0000 FE2B 2B2B FEFB FBFB FBFB FBFB"            /* .....+++........ */
	$"FBFB FBFB FBFB FBFE F6FE FBFF 0000 0000"            /* ................ */
	$"0000 0000 FEFB FBFB FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FBFE 00FF 0000 0000"            /* +++++++......... */
	$"0000 0000 FE2B 2B2B FE2B 2B2B 2B2B 2B2B"            /* .....+++.+++++++ */
	$"2B2B 2B2B 2B2B 2BFE F6FE 2BFF 0000 0000"            /* +++++++...+..... */
	$"0000 0000 FEF6 E3E3 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF F6FE FBFF 0000 0000"            /* ................ */
	$"0000 0000 FFF6 D8D8 F6F6 F6F6 F6F6 F6F6"            /* .............. */
	$"F6F6 F6F6 F6F6 F6F6 F6FE 0000 0000 0000"            /* ................ */
	$"0000 0000 FEF6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6FE 0000 0000 0000"            /* ................ */
	$"0000 0000 FEF6 FBF6 FBF6 FBF6 FBF6 FBF6"            /* ................ */
	$"FBF6 FFFF FFFF FFF6 FBFE 0000 0000 0000"            /* ................ */
	$"0000 0000 FBFE FEFE FEFE FEFE FEFE FEFE"            /* ................ */
	$"FEFE FEF6 F6F6 FEFE FEFB 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 FF2B 2B2B FF00 0000 0000 0000 0000"            /* ...+++.......... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 FFFF FFFF FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 FF2B FE2B FD00 0000 0000 0000 0000"            /* ...+.+.......... */
	$"F8F7 F9F9 FAF8 F9F9 F9FA FAFA FBFB FBFC"            /* ................ */
	$"FCFC 2B2B FE2B 2BFD FDFC FCFC FAFA F9F8"            /* ..++.++......... */
	$"F5F5 F6F6 F6F6 F6F6 F62B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2BFE 00FE 2B2B 2B2B 2B2B 2BF6 F6F5"            /* +++...+++++++... */
	$"F8F9 F9F9 FAFA FAFB FBFB FCFC FCFD FDFD"            /* ................ */
	$"FEFE FE00 0000 FEFE FDFD FCFC FAFA F9F8"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


/************** ImageWriter LQ Desktop Printer Icons - Current/Not Shared  representation **************/

data 'ICN#' (kDTPCurrentNotSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 03FF FFF8 07FF FFFC"            /* ................ */
	$"0FFF FFFE 1E00 0017 1C00 0027 1D00 00A7"            /* ...........'... */
	$"1C00 003F 1D20 60BF 1C20 9038 1D21 08B8"            /* ...?. `. 8.!. */
	$"1C21 0838 1D21 28B8 1C20 9038 1D3C 68B8"            /* .!.8.!(. 8.<h */
	$"1C00 0038 3D00 00B8 7C00 003E FFFF FFFF"            /* ...8=..|..>.... */
	$"F800 001F EFFF FFF7 F800 001F E800 0017"            /* ................ */
	$"FFFF FFF7 F000 0007 E000 001F FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFE 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 03FF FFF8 07FF FFFC"            /* ................ */
	$"0FFF FFFE 1FFF FFFF 1FFF FFFF 1FFF FFFF"            /* ................ */
	$"1FFF FFFF 1FFF FFFF 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 3FFF FFF8 7FFF FFFE FFFF FFFF"            /* ....?........... */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFE 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (kDTPCurrentNotSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"000F FFF0 0000 0000 0000 0000 000F CFFF"            /* ............... */
	$"000F FF00 0000 0000 0000 0000 00FC CFFF"            /* ............... */
	$"000F FF0E 0000 0000 0000 0000 E0FC CFFF"            /* ............... */
	$"000F FF00 0000 0000 0000 0000 00FF FFFF"            /* ................ */
	$"000F FF0E 00F0 0000 0FF0 0000 E0FF FFFF"            /* ................ */
	$"000F FF00 00F0 0000 F00F 0000 00FF F000"            /* ................ */
	$"000F FF0E 00F0 000F 0000 F000 E0FF F000"            /* ................ */
	$"000F FF00 00F0 000F 0000 F000 00FF F000"            /* ................ */
	$"000F FF0E 00F0 000F 00F0 F000 E0FF F000"            /* ................ */
	$"000F FF00 00F0 0000 F00F 0000 00FF F000"            /* ................ */
	$"000F FF0E 00FF FF00 0FF0 F000 E0FF F000"            /* ................ */
	$"000F FF00 0000 0000 0000 0000 00FF F000"            /* ................ */
	$"00FF FF0E 0000 0000 0000 0000 E0FF F000"            /* ................ */
	$"0FFF FF00 0000 0000 0000 0000 00FF FFF0"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FCCC CCCC CCCC CCCC CCCC CCCF FFFF"            /* ..... */
	$"FFFC FEEE EEEE EEEE EEEE EEEE EEEF CFFF"            /* ............... */
	$"FFFE FCCC CCCC CCCC CCCC CCCC CCCF EFFF"            /* ..... */
	$"FFFC FCCC CCCC CCCC CCCC CCCC CCCF CFFF"            /* .... */
	$"FFF8 FFFF FFFF FFFF FFFF FFFF FFFF CFFF"            /* ............... */
	$"FFF3 CCCC CCCC CCCC CCCC CCCC CCCC CFFF"            /* ... */
	$"FFFC CCCC CCCC CCCC CCCC CCCC CCCF FFFE"            /* .... */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl8' (kDTPCurrentNotSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 00FF FFFF FFF5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 2BFF FFFF"            /* ............+... */
	$"0000 00FF FFFF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF2B 2BFF FFFF"            /* ...........++... */
	$"0000 00FF FFFF F5FB F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FBF5 FF2B 2BFF FFFF"            /* ...........++... */
	$"0000 00FF FFFF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FFFF FFFF"            /* ................ */
	$"0000 00FF FFFF F5FB F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5F5 F5F5 FBF5 FFFF FFFF FFFF"            /* ................ */
	$"0000 00FF FFFF F5F5 F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 F5F5 F5F5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5FB F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 F5F5 FBF5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5F5 F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 F5F5 F5F5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5FB F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 F5F5 FBF5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5F5 F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 F5F5 F5F5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5FB F5F5 FFFF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 F5F5 FBF5 FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FF00 0000"            /* ................ */
	$"0000 FFFF FFFF F5FB F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FBF5 FFFF FF00 0000"            /* ................ */
	$"00FF FFFF FFFF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FFFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF FFFF"            /* +++++++++++..... */
	$"FFFF FF2B FFFC FCFC FCFC FCFC FCFC FCFC"            /* ...+............ */
	$"FCFC FCFC FCFC FCFC FCFC FCFF 2BFF FFFF"            /* ............+... */
	$"FFFF FFFC FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FCFF FFFF"            /* +++++++++++..... */
	$"FFFF FF2B FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+.+++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF 2BFF FFFF"            /* +++++++++++.+... */
	$"FFFF FFE3 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 2BFF FFFF"            /* ............+... */
	$"FFFF FFD8 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF"            /* +++++++++++++... */
	$"FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF FFFC"            /* +++++++++++..... */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


/************** ImageWriter LQ Desktop Printer Icons - Current/Shared  representation **************/

data 'ICN#' (kDTPCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 003F FFC0 007F FFE0"            /* .........?..... */
	$"00FF FFF0 01F0 0178 01E0 0238 01C0 0238"            /* .......x...8..8 */
	$"01D0 63F8 01D0 93F8 01D1 0BF8 01D1 2B80"            /* .c..Г.....+ */
	$"01D0 9380 01DC 6BC0 1FC0 03F8 3FFF FFFC"            /* .Г..k...?... */
	$"3F80 01FC 38FF FF7C 3F80 01DC 3880 015C"            /* ?..8..|?..8.\ */
	$"3BFF FF7C 3B00 007C 3800 0078 3FFF FFF0"            /* ;..|;..|8..x?... */
	$"3FFF E3F0 3FFF E3E0 0000 3E00 0000 2A00"            /* ?...?.....>...*. */
	$"BFFF C9FD 0000 1400 BFFF E3FD 0000 0000"            /* ............. */
	$"0000 0000 0000 0000 003F FFC0 007F FFE0"            /* .........?..... */
	$"00FF FFF0 01FF FFF8 01FF FFF8 01FF FFF8"            /* ................ */
	$"01FF FFF8 01FF FFF8 01FF FFF8 01FF FF80"            /* ............... */
	$"01FF FF80 01FF FFC0 1FFF FFF8 3FFF FFFC"            /* ..........?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFF8 3FFF FFF0"            /* ?...?...?...?... */
	$"3FFF FFF0 3FFF FFE0 0000 3E00 0000 2A00"            /* ?...?.....>...*. */
	$"BFFF C9FD 0000 1400 BFFF E3FD 0000 0000"            /* ............. */
};

data 'icl4' (kDTPCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0FFF FFFF FFFF FFFF FFF0 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 000F FFFF 0000 0000 000F CFFF F000"            /* ............... */
	$"0000 000F FFF0 0000 0000 00FC CCFF F000"            /* ............... */
	$"0000 000F FF00 0000 0000 00FC CCFF F000"            /* ............... */
	$"0000 000F FF0F 0000 0FF0 00FF FFFF F000"            /* ................ */
	$"0000 000F FF0F 0000 F00F 00FF FFFF F000"            /* ................ */
	$"0000 000F FF0F 000F 0000 F0FF FFFF F000"            /* ................ */
	$"0000 000F FF0F 000F 00F0 F0FF F000 0000"            /* ................ */
	$"0000 000F FF0F 0000 F00F 00FF F000 0000"            /* ................ */
	$"0000 000F FF0F FF00 0FF0 F0FF FF00 0000"            /* ................ */
	$"000F FFFF FF00 0000 0000 00FF FFFF F000"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"00FF FFFF FCCC CCCC CCCC CCCF FFFF FF00"            /* ......... */
	$"00FF FCCC FEEE EEEE EEEE EEEF CFEF FF00"            /* .............. */
	$"00FF FEEE FCCC CCCC CCCC CCCF EF0F FF00"            /* ......... */
	$"00FF FCCC FCCC CCCC CCCC CCCF CFCF FF00"            /* ...... */
	$"00FF FC88 FFFF FFFF FFFF FFFF CFFF FF00"            /* .............. */
	$"00FF FC33 CCCC CCCC CCCC CCCC CFFF FF00"            /* ...3... */
	$"00FF FCCC CCCC CCCC CCCC CCCC CFFF F000"            /* ...... */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFC CCFF FFFF 0000"            /* ............... */
	$"00FF FFFF FFFF FFFF FFFC CCFF FFF0 0000"            /* ............... */
	$"0000 0000 0000 0000 00FF FFF0 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FC FCE0 0000 0000"            /* ................ */
	$"CCDD DCDD DDDD EEEE EECC FCCE EEEE DDDC"            /* ............. */
	$"00CC CCCC CCCC CCCC CCCF 0FCC CCCC CCC0"            /* .. */
	$"CDDD DDDE EEEE EEEE EFF0 00FE EEEE DDDC"            /* ............... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl8' (kDTPCurrentSharedID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF FFFF F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5FF F6FF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF FFF5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5F5 FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 FFFF FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FFFF FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF F5FF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF FEFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFE FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 FFFF FFFE FEFE FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FEFE FEFF FFFF 0000"            /* +++++++......... */
	$"0000 FFFF FF2B 2B2B FEFB FBFB FBFB FBFB"            /* .....+++........ */
	$"FBFB FBFB FBFB FBFE F6FE FBFF FFFF 0000"            /* ................ */
	$"0000 FFFF FFFB FBFB FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FBFE 00FF FFFF 0000"            /* +++++++......... */
	$"0000 FFFF FF2B 2B2B FE2B 2B2B 2B2B 2B2B"            /* .....+++.+++++++ */
	$"2B2B 2B2B 2B2B 2BFE F6FE 2BFF FFFF 0000"            /* +++++++...+..... */
	$"0000 FFFF FFF6 E3E3 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF F6FF FFFF FFFF 0000"            /* ................ */
	$"0000 FFFF FFF6 D8D8 F6F6 F6F6 F6F6 F6F6"            /* .............. */
	$"F6F6 F6F6 F6F6 F6F6 F6FE FFFF FFFF 0000"            /* ................ */
	$"0000 FFFF FFF6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6FF FFFF FF00 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 FFFF FFFE FEFE FEFE FEFE FEFE FEFE"            /* ................ */
	$"FEFE FEF6 F6F6 FEFE FEFF FFFF 0000 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FF2B 2B2B FFFF FFFF FF00 0000 0000"            /* ...+++.......... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 FFFF FFFF FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 FF2B FE2B FD00 0000 0000 0000 0000"            /* ...+.+.......... */
	$"F8F7 F9F9 FAF8 F9F9 F9FA FAFA FBFB FBFC"            /* ................ */
	$"FCFC 2B2B FE2B 2BFD FDFC FCFC FAFA F9F8"            /* ..++.++......... */
	$"F5F5 F6F6 F6F6 F6F6 F62B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2BFE 00FE 2B2B 2B2B 2B2B 2BF6 F6F5"            /* +++...+++++++... */
	$"F8F9 F9F9 FAFA FAFB FBFB FCFC FCFD FDFD"            /* ................ */
	$"FEFE FE00 0000 FEFE FDFD FCFC FAFA F9F8"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

/************** ImageWriter LQ Desktop Printer Icons - not active representation **************/

data 'ICN#' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"6000 0006 F000 000F F800 001F 7DFF FFFE"            /* `...........}... */
	$"3E00 007C 1F00 00FA 0F80 01F2 0780 03FE"            /* >..|.......... */
	$"07A0 67E0 05A0 93A0 05A1 0BA0 0421 0A20"            /* .g.....!.  */
	$"0521 28A0 0420 9020 053C 68A0 0400 0020"            /* .!(.  .<h...  */
	$"0507 E0A0 040F F020 0FFF FFF0 F83E 7C1F"            /* ...... .....>|. */
	$"8FFF FFF5 F8F8 1F1D 89F0 0F95 8FFF FFF5"            /* ............ */
	$"A7C0 03E5 8F80 01F7 FFFF FFFC FF55 557C"            /* .........UU| */
	$"7FFF FFFE F800 001F F000 000F 6000 0006"            /* ............`... */
	$"6000 0006 F000 000F F800 001F 7DFF FFFE"            /* `...........}... */
	$"3FFF FFFC 1FFF FFFE 0FFF FFFE 07FF FFFE"            /* ?............... */
	$"07FF FFE0 07FF FFE0 07FF FFE0 07FF FFE0"            /* ................ */
	$"07FF FFE0 07FF FFE0 07FF FFE0 07FF FFE0"            /* ................ */
	$"07FF FFE0 07FF FFE0 0FFF FFF0 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFFC"            /* ................ */
	$"7FFF FFFE F800 001F F000 000F 6000 0006"            /* ............`... */
};

data 'icl4' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"0FF0 0000 0000 0000 0000 0000 0000 0FF0"            /* ................ */
	$"FFFF 0000 0000 0000 0000 0000 0000 FFFF"            /* ................ */
	$"FFFF F000 0000 0000 0000 0000 000F FFFF"            /* ................ */
	$"0FFF FF0F FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"00FF FFFC 0C0C 0C0C 0C0C 0C0C 0FFF FF00"            /* ................ */
	$"000F FFFF C0C0 C0C0 C0C0 C0C0 FFFF FCF0"            /* ........ */
	$"0000 FFFF FC0C 0C0C 0C0C 0C0F FFFF CCF0"            /* ............... */
	$"0000 0FFF F0C0 C0C0 C0C0 C0FF FFFF FFF0"            /* .......... */
	$"0000 0FFF FCFC 0C0C 0FFC 0FFF FFF0 0000"            /* ................ */
	$"0000 0FCF F0F0 C0C0 F0CF C0FF F0F0 0000"            /* ........... */
	$"0000 0F0E FCFC 0C0F 0C0C FCFF ECF0 0000"            /* ................ */
	$"0000 0FC0 C0F0 C0CF C0C0 F0F0 C0F0 0000"            /* ......... */
	$"0000 0F0E 0CFC 0C0F 0CFC FC0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0F0 C0C0 F0CF C0C0 C0F0 0000"            /* ........ */
	$"0000 0F0E 0CFF FF0C 0FFC FC0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 C0F0 0000"            /* ...... */
	$"0000 0F0E 0C0C 0FFF FFFC 0C0C ECF0 0000"            /* ................ */
	$"0000 0FC0 C0C0 FFFF FFFF C0C0 C0F0 0000"            /* .......... */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"FFFF FCCC CCFF FFFC CFFF FFCC CCCF FFFE"            /* .......... */
	$"FCCC FEEE EFFF FFEE EEFF FFFE EEEF CFEF"            /* .............. */
	$"FEEE FCCC FFFF FCCC CCCF FFFF CCCF EF0F"            /* .......... */
	$"FCCC FCCF FFFF CCCC CCCC FFFF FCCF CFCF"            /* ....... */
	$"FC88 FFFF FFFF FFFF FFFF FFFF FFFF CFDF"            /* .............. */
	$"FC33 CFFF FFCC CCCC CCCC CCFF FFFC CFEF"            /* .3...... */
	$"FCCC FFFF FCCC CCCC CCCC CCCF FFFF CFFE"            /* ....... */
	$"FDEF FFFF EDED EDED EDED EDED FFFF FF00"            /* ................ */
	$"FCFF FFFC ECEC ECEC ECEC ECEC EFFF FF00"            /* ................ */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"FFFF F000 0000 0000 0000 0000 000F FFFF"            /* ................ */
	$"FFFF 0000 0000 0000 0000 0000 0000 FFFF"            /* ................ */
	$"0FF0 0000 0000 0000 0000 0000 0000 0FF0"            /* ................ */
};

resource 'icl8' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"00FF FF00 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 00FF FF00"            /* ................ */
	$"FFFF FFFF 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FF FFFF FFFF"            /* ................ */
	$"00FF FFFF FFFF 00FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 FFFF FFFF FFF5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5FF FFFF FFFF 0000"            /* ................ */
	$"0000 00FF FFFF FFFF F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FFFF FFFF FF2B FF00"            /* .............+.. */
	$"0000 0000 FFFF FFFF FFF5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5FF FFFF FFFF 2B2B FF00"            /* ............++.. */
	$"0000 0000 00FF FFFF FFF5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 0000 00FF FFFF FFF5 FFF5 F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5FF FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FF FFF5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FFFF FFF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB FFF5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 FFFF FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 FFF5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFF5 F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 FFF5 F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 FFFF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5FB F5F5 F5F5 F5FF FFFF"            /* ................ */
	$"FFFF FFF5 F5F5 F5F5 FBF5 FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF F5F5 F5F5 F5F5 FFFF FFFF"            /* ................ */
	$"FFFF FFFF F5F5 F5F5 F5F5 FF00 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"FFFF FFFF FF2B 2B2B 2B2B FFFF FFFF FF2B"            /* .....+++++.....+ */
	$"2BFF FFFF FFFF 2B2B 2B2B 2BFF FFFF FFFC"            /* +.....+++++..... */
	$"FF2B 2B2B FFFC FCFC FCFF FFFF FFFF FCFC"            /* .+++............ */
	$"FCFC FFFF FFFF FFFC FCFC FCFF 2BFF FCFF"            /* ............+... */
	$"FFFC FCFC FF2B 2B2B FFFF FFFF FF2B 2B2B"            /* .....+++.....+++ */
	$"2B2B 2BFF FFFF FFFF 2B2B 2BFF FCFF F5FF"            /* +++.....+++..... */
	$"FF2B 2B2B FF2B 2BFF FFFF FFFF 2B2B 2B2B"            /* .+++.++.....++++ */
	$"2B2B 2B2B FFFF FFFF FF2B 2BFF 2BFF 2BFF"            /* ++++.....++.+.+. */
	$"FF2B E3E3 FFFF FFFF FFFF FFFF FFFF FFFF"            /* .+.............. */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 2BFF FAFF"            /* ............+... */
	$"FF2B D8D8 2BFF FFFF FFFF 2B2B 2B2B 2B2B"            /* .++.....++++++ */
	$"2B2B 2B2B 2B2B FFFF FFFF FF2B 2BFF FCFF"            /* ++++++.....++... */
	$"FF2B 2B2B FFFF FFFF FF2B 2B2B 2B2B 2B2B"            /* .+++.....+++++++ */
	$"2B2B 2B2B 2B2B 2BFF FFFF FFFF 2BFF FFFC"            /* +++++++.....+... */
	$"FFF9 FCFF FFFF FFFF FCF9 FCF9 FCF9 FCF9"            /* ................ */
	$"FCF9 FCF9 FCF9 FCF9 FFFF FFFF FFFF 0000"            /* ................ */
	$"FFF8 FFFF FFFF FFF8 FBF8 FBF8 FBF8 FBF8"            /* ................ */
	$"FBF8 FBF8 FBF8 FBF8 FBFF FFFF FFFF 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FF FFFF FFFF"            /* ................ */
	$"FFFF FFFF 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 FFFF FFFF"            /* ................ */
	$"00FF FF00 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 00FF FF00"            /* ................ */
};

data 'ics#' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"C003 FFFF 700E 344F 34AC 24A4 366C 2004"            /* ...p.4O4$6l . */
	$"3FFC FFFF EE75 BFFF B81D 7FFE E007 C003"            /* ?....u....... */
	$"C003 FFFF 7FFE 3FFF 3FFC 3FFC 3FFC 3FFC"            /* .....?.?.?.?.?. */
	$"3FFC FFFF FFFF FFFF FFFF 7FFE E007 C003"            /* ?.............. */
};

data 'ics4' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"0F00 0000 0000 00F0 FFFF FFFF FFFF FFFF"            /* ................ */
	$"0FFF 0000 0000 FFF0 00FF 0F00 0F00 FFFF"            /* ................ */
	$"00FF 0F00 F0F0 FF00 00F0 0F00 F0F0 0F00"            /* ................ */
	$"00FE 0FF0 0FF0 EF00 00F0 0000 0000 0F00"            /* ................ */
	$"00FF FFFF FFFF FF00 FFFE EFFF FFFE EFFF"            /* ................ */
	$"FEFC FFFC CFFF CFCF F8FF FFFF FFFF FFFF"            /* ............. */
	$"F3FF FCCC CCCF FFCF 0FFF FFFF FFFF FFF0"            /* ............ */
	$"FFF0 0000 0000 0FFF 0F00 0000 0000 00F0"            /* ................ */
};

resource 'ics8' (kDTPNotActiveID, sysheap, purgeable) 
{
	$"00FF 0000 0000 0000 0000 0000 0000 FF00"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"00FF FFFF F5F5 F5F5 F5F5 F5F5 FFFF FF00"            /* ................ */
	$"0000 FFFF F5FF F5F5 F5FF F5F5 FFFF FFFF"            /* ................ */
	$"0000 FFFF F5FF F5F5 FFF5 FFF5 FFFF 0000"            /* ................ */
	$"0000 FFF5 F5FF F5F5 FFF5 FFF5 F5FF 0000"            /* ................ */
	$"0000 FFFB F5FF FFF5 F5FF FFF5 FBFF 0000"            /* ................ */
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"FFFF FFFC FCFF FFFF FFFF FFFC FCFF FFFF"            /* ................ */
	$"FFFC FF2B FFFF FF2B 2BFF FFFF 2BFF 2BFF"            /* ...+...++...+.+. */
	$"FFE3 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFD8 FFFF FF2B 2B2B 2B2B 2BFF FFFF 2BFF"            /* ....++++++...+. */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"FFFF FF00 0000 0000 0000 0000 00FF FFFF"            /* ................ */
	$"00FF 0000 0000 0000 0000 0000 0000 FF00"            /* ................ */
};

/************** ImageWriter LQ Desktop Printer Icons - puzzle representation **************/

data 'ICN#' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"00FF FF00 0100 0080 0080 0100 7F80 01FE"            /* ............. */
	$"8000 0001 800F FF81 8010 0141 8020 0221"            /* .......A .! */
	$"8040 0221 8050 63E1 8050 9201 8051 0A01"            /* @.!Pc.P.Q.. */
	$"8051 2A01 8050 9201 805C 6A01 8040 0201"            /* Q*.P.\j.@.. */
	$"80FF FF01 8F80 01F1 88FF FF71 8F80 01D1"            /* .......q. */
	$"8880 0151 8BFF FF71 8B00 0041 8800 0041"            /* .Q..q..A..A */
	$"8AAA AAC1 8FFF FFC1 8000 0001 8000 0001"            /* ........ */
	$"80FF FF01 8080 0101 8040 0201 7FE0 07FE"            /* .....@...... */
	$"00FF FF00 01FF FF80 00FF FF00 7FFF FFFE"            /* ............... */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FF80 01FF FFC0 03FF 7FE0 07FE"            /* .............. */
};

data 'icl4' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"0000 0000 FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 000F 0000 0000 0000 0000 F000 0000"            /* ................ */
	$"0000 0000 F0C0 C0C0 C0C0 C0CF 0000 0000"            /* ......... */
	$"0FFF FFFF F00C 0C0C 0C0C 0C0F FFFF FFF0"            /* ................ */
	$"F000 0000 00C0 C0C0 C0C0 C0C0 0000 000F"            /* ......... */
	$"F00C 0C0C 0C0C FFFF FFFF FFFF FC0C 0C0F"            /* ................ */
	$"F0C0 C0C0 C0CF 0000 0000 000F CFC0 C0CF"            /* ....... */
	$"F00C 0C0C 0CF0 0000 0000 00FC CCFC 0C0F"            /* ............... */
	$"F0C0 C0C0 CF00 0000 0000 00FC CCF0 C0CF"            /* ......... */
	$"F00C 0C0C 0F0F 0000 0FF0 00FF FFFC 0C0F"            /* ................ */
	$"F0C0 C0C0 CF0F 0000 F00F 00F0 C0C0 C0CF"            /* ........ */
	$"F00C 0C0C 0F0F 000F 0000 F0FC 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 CF0F 000F 00F0 F0F0 C0C0 C0CF"            /* ........ */
	$"F00C 0C0C 0F0F 0000 F00F 00FC 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 CF0F FF00 0FF0 F0F0 C0C0 C0CF"            /* ........ */
	$"F00C 0C0C 0F00 0000 0000 00FC 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 FFFF FFFF FFFF FFFF C0C0 C0CF"            /* ......... */
	$"F00C FFFF FCCC CCCC CCCC CCCF FFFF 0C0F"            /* ......... */
	$"F0C0 FCCC FEEE EEEE EEEE EEEF CFEF C0CF"            /* ........... */
	$"F00C FEEE FCCC CCCC CCCC CCCF EF0F 0C0F"            /* ......... */
	$"F0C0 FCCC FCCC CCCC CCCC CCCF CFCF C0CF"            /* ... */
	$"F00C FC88 FFFF FFFF FFFF FFFF CFEF 0C0F"            /* .............. */
	$"F0C0 FC33 CCCC CCCC CCCC CCCC CFC0 C0CF"            /* ..3 */
	$"F00C FCCC CCCC CCCC CCCC CCCC CF0C 0C0F"            /* ...... */
	$"F0C0 FCEC ECEC ECEC ECEC ECEC EFC0 C0CF"            /* ............ */
	$"F00C EFFF FFFF FFFF FFFF FFFF FE0C 0C0F"            /* ................ */
	$"F0C0 C0C0 C0C0 C0C0 C0C0 C0C0 C0C0 C0CF"            /* . */
	$"F00C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 FFFF FFFF FFFF FFFF C0C0 C0CF"            /* ......... */
	$"F00C 0C0C F000 0000 0000 000F 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 CF00 0000 0000 00F0 C0C0 C0CF"            /* ........ */
	$"0FFF FFFF FFF0 0000 0000 0FFF FFFF FFF0"            /* ................ */
};

resource 'icl8' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"0000 0000 0000 0000 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FF00 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6FF 0000 0000 0000 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF FF00 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6FF FFFF FFFF FFFF FF00"            /* ................ */
	$"FF00 0000 0000 0000 0000 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 0000 0000 0000 00FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFF6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6FF F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5FF F6FF F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 FFF5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FFF6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 FFF6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF F5F5 F5F5"            /* ................ */
	$"F5FF FFF5 F5F5 FFFF FFFF FFF6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 F5F5 FFF5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF F5F5 F5FF"            /* ................ */
	$"F5F5 FFF5 FFF5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF F5F5 F5F5"            /* ................ */
	$"FFF5 F5FF F5F5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5FF FFFF F5F5"            /* ................ */
	$"F5FF FFF5 FFF5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 FEFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFE F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FEFE FEFE FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FEFE FEFF F6F6 F6FF"            /* +++++++......... */
	$"FF00 F6F6 FE2B 2B2B FEFB FBFB FBFB FBFB"            /* .....+++........ */
	$"FBFB FBFB FBFB FBFE F6FE FBFF F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FEFB FBFB FE2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2BFE FBFE 00FF F6F6 F6FF"            /* +++++++......... */
	$"FF00 F6F6 FE2B 2B2B FE2B 2B2B 2B2B 2B2B"            /* .....+++.+++++++ */
	$"2B2B 2B2B 2B2B 2BFE F6FE 2BFF F6F6 F6FF"            /* +++++++...+..... */
	$"FF00 F6F6 FEF6 E3E3 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF F6FE FBFF F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FFF6 D8D8 F6F6 F6F6 F6F6 F6F6"            /* .............. */
	$"F6F6 F6F6 F6F6 F6F6 F6FE F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FEF6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6FE F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FEF6 FBF6 FBF6 FBF6 FBF6 FBF6"            /* ................ */
	$"FBF6 FBF6 FBF6 FBF6 FBFE F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 FBFE FEFE FEFE FEFE FEFE FEFE"            /* ................ */
	$"FEFE FEFE FEFE FEFE FEFB F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF00 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FF00"            /* ................ */
};

data 'ics#' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"0FF0 7C3E 8001 8FF9 900D 944D 94A9 94A9"            /* ..|>..M */
	$"9669 9009 BFF9 A00D BFF9 8001 8FF1 7C3E"            /* iƿ.¿...|> */
	$"0FF0 7FFE FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 7C3E"            /* ..............|> */
};

data 'ics4' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"0000 FFFF FFFF 0000 0FFF FF0C 0CFF FFF0"            /* ................ */
	$"F0C0 C0C0 C0C0 C0CF FC0C FFFF FFFF FC0F"            /* ......... */
	$"F0CF 0000 0000 FFCF FC0F 0F00 0F00 FF0F"            /* .............. */
	$"F0CF 0F00 F0F0 F0CF FC0F 0F00 F0F0 FC0F"            /* .............. */
	$"F0CF 0FF0 0FF0 F0CF FC0F 0000 0000 FC0F"            /* .............. */
	$"F0FF FFFF FFFF F0CF FCF3 8CCC CCCC FF0F"            /* ........... */
	$"F0FF FFFF FFFF F0CF FC0C 0C0C 0C0C 0C0F"            /* ............... */
	$"F0C0 FFFF FFFF C0CF 0FFF FF00 00FF FFF0"            /* ............. */
};

resource 'ics8' (kDTPPuzzleID, sysheap, purgeable) 
{
	$"0000 0000 FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"00FF FFFF FFFF F6F6 F6F6 FFFF FFFF FF00"            /* ................ */
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FFF6 F6F6 FFFF FFFF FFFF FFFF FFF6 F6FF"            /* ................ */
	$"FFF6 F6FF F5F5 F5F5 F5F5 F5F5 FFFF F6FF"            /* ................ */
	$"FFF6 F6FF F5FF F5F5 F5FF F5F5 FFFF F6FF"            /* ................ */
	$"FFF6 F6FF F5FF F5F5 FFF5 FFF5 FFF6 F6FF"            /* ................ */
	$"FFF6 F6FF F5FF F5F5 FFF5 FFF5 FFF6 F6FF"            /* ................ */
	$"FFF6 F6FF F5FF FFF5 F5FF FFF5 FFF6 F6FF"            /* ................ */
	$"FFF6 F6FF F5F5 F5F5 F5F5 F5F5 FFF6 F6FF"            /* ................ */
	$"FFF6 FFFF FFFF FFFF FFFF FFFF FFF6 F6FF"            /* ................ */
	$"FFF6 FFD8 E32B 2B2B 2B2B 2B2B FFFF F6FF"            /* ....+++++++.... */
	$"FFF6 FFFF FFFF FFFF FFFF FFFF FFF6 F6FF"            /* ................ */
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FFF6 F6F6 FFFF FFFF FFFF FFFF F6F6 F6FF"            /* ................ */
	$"00FF FFFF FFFF 0000 0000 FFFF FFFF FF00"            /* ................ */
};
