/* ------------------------------------------------------------------------------
FILENAME
	UniversalMessageResources.r

DESCRIPTION
	This module contains the ImageWriter LQ constants, types, and resources that
	are specific to supporting the New (QuickDraw GX) API.
			
	Note: all resources should be designated to load into the system heap.

COPYRIGHT
	 Copyright Apple Computer, Inc. 1992-1994
	 All rights reserved. 
	
	12/20/93 - dmh - Sync'd with the shipping 1.0b3 GX driver.
	 8/28/94 - dmh - Sync'd with the shipping 1.0.1 GX driver.

-------------------------------------------------------------------------------- */

// System 7.0 Compatible
#define SystemSevenOrLater		1

// Include System Resource Definitions
#include "Types.r"
#include "SysTypes.r"
#include "BalloonTypes.r"

// Include the ImageWriter LQ driver constants that are used in the resources 
#include "Resources.h"

// Include the public QuickDraw GX printing files 
#include "PrintingResTypes.r"


/*********************************************************************************
 *        						RESOURCES			 							 					*
 *********************************************************************************/

/*************************** Universal Imaging Message Override Resource **************************/
// This overrideType resource tells the Printing Manager which new Universal Imaging 
// Messages the driver overrides. 

resource gxOverrideType (gxDriverUniversalOverrideID, sysheap, purgeable)
{
	{
		gxInitialize,				kNewAPISegmentID, kFirstMsgJumpTableOffset,
		gxShutDown, 				kNewAPISegmentID, kFirstMsgJumpTableOffset + 4,
		gxJobDefaultFormatDialog,	kNewAPISegmentID, kFirstMsgJumpTableOffset + 8,
		gxJobPrintDialog, 			kNewAPISegmentID, kFirstMsgJumpTableOffset + 12,
		gxJobFormatModeQuery, 		kNewAPISegmentID, kFirstMsgJumpTableOffset + 16,
		gxOpenConnection,			kNewAPISegmentID, kFirstMsgJumpTableOffset + 20,
		gxCleanupOpenConnection,	kNewAPISegmentID, kFirstMsgJumpTableOffset + 24,
		gxStartSendPage, 			kNewAPISegmentID, kFirstMsgJumpTableOffset + 28,
		gxImagePage,		 		kNewAPISegmentID, kFirstMsgJumpTableOffset + 32,
		gxRenderPage,		 		kNewAPISegmentID, kFirstMsgJumpTableOffset + 36,
		gxDefaultPrinter, 			kNewAPISegmentID, kFirstMsgJumpTableOffset + 40,
		gxDefaultFormat, 			kNewAPISegmentID, kFirstMsgJumpTableOffset + 44,
		gxDefaultJob, 				kNewAPISegmentID, kFirstMsgJumpTableOffset + 48,
		gxSetupImageData,			kNewAPISegmentID, kFirstMsgJumpTableOffset + 52,
		gxFetchTaggedData,			kNewAPISegmentID, kFirstMsgJumpTableOffset + 56,
		gxDefaultDesktopPrinter,	kNewAPISegmentID, kFirstMsgJumpTableOffset + 60,
		gxGetDTPMenuList,			kNewAPISegmentID, kFirstMsgJumpTableOffset + 64,
		gxDTPMenuSelect,			kNewAPISegmentID, kFirstMsgJumpTableOffset + 68,
	};
};


/*************************** Raster Imaging Message Override Resource **************************/
// This overrideType resource tells the Printing Manager which Raster Imaging Messages the driver 
// overrides. 

resource gxOverrideType (gxDriverImagingOverrideID, sysheap, purgeable)
{
	{
		gxRasterPackageBitmap, 		kNewAPISegmentID, kFirstMsgJumpTableOffset + 72,
		gxRasterLineFeed, 			kNewAPISegmentID, kFirstMsgJumpTableOffset + 76,
	};
};


/*************************** Type of Imaging System Supported by the Driver **************************/
// This imagingSystemResType resource tells the Printing Manager the type of imaging system this 
// driver uses.

resource gxImagingSystemSelectorType (gxImagingSystemSelectorID, sysheap, purgeable)
{
	gxRasterPrinterType		// LaserWriter SC uses the raster imaging system 
};


/*************************** Customizing Behavior of Raster Imaging Messages ***************************/
// For most raster devices, the driver should include a resource of type, rasterPrefsType.  This 
// resource allows the driver to specify the imaging options and format page scaling.   

resource gxRasterPrefsType (gxRasterPrefsID, sysheap, purgeable)
{
	gxDefaultRaster,			// default options are fine
	
	0x00D80000,	0x00D80000,		// 216 x 216 dpi device
	24,							// min band size
	0,							// max band size (0 = full page)
	0x00008000,					// RAM percentage (50%)
	100*1024,					// RAM slop (100K)
	1,							// 1 bit per plane device
	{
		gxDefaultOffscreen,									// YELLOW plane.  Use default halftoning.
		0x000F0000,											// Angle = 15 degrees
		0x002D0000,											// Freq = 45
		gxRoundDot,											// RoundDot dithering
		gxComponent3Tint,									// Extract yellow and dither it
		gxRGBSpace, gxNoProfile, 0, 0, 0, 0,				// DotColor == black
		gxRGBSpace, gxNoProfile, 0xFFFF, 0xFFFF, 0xFFFF, 0,	// Background color == white
		gxCMYKSpace,										// Convert to gxCMYKSpace before halftoning.
		gxNoSpace,											// No explicit color space
		gxNoSet,											// No color set
		gxNoProfile,										// No profile specified

		gxDefaultOffscreen,									// MAGENTA plane.  Use default halftoning.
		0x00000000,											// Angle = 0 degrees
		0x002D0000,											// Freq = 45
		gxRoundDot,											// RoundDot dithering
		gxComponent2Tint,									// extract magenta and dither it
		gxRGBSpace, gxNoProfile, 0, 0, 0, 0,				// dotColor == black
		gxRGBSpace, gxNoProfile, 0xFFFF, 0xFFFF, 0xFFFF, 0,	// background color == white
		gxCMYKSpace,										// Convert to gxCMYKSpace before halftoning.
		gxNoSpace,											// No explicit color space
		gxNoSet,											// No color set
		gxNoProfile,										// No profile specified

		gxDefaultOffscreen,									// CYAN plane.  Use default halftoning.
		0x003C0000,											// Angle = 60 degrees
		0x002D0000,											// Freq = 45
		gxRoundDot,											// RoundDot dithering
		gxComponent1Tint,									// Extract cyan and dither it
		gxRGBSpace, gxNoProfile, 0, 0, 0, 0,				// DotColor == black
		gxRGBSpace, gxNoProfile, 0xFFFF, 0xFFFF, 0xFFFF, 0,	// Background color == white
		gxCMYKSpace,										// Convert to gxCMYKSpace before halftoning.
		gxNoSpace,											// No explicit color space
		gxNoSet,											// No color set
		gxNoProfile,										// No profile specified

		gxDefaultOffscreen,									// BLACK plane.  Use default halftoning.
		0x002D0000,											// Angle = 45 degrees
		0x002D0000,											// Freq = 45
		gxRoundDot,											// RoundDot dithering
		gxComponent4Tint,									// Extract black and dither it
		gxRGBSpace, gxNoProfile, 0, 0, 0, 0,				// DotColor == black
		gxRGBSpace, gxNoProfile, 0xFFFF, 0xFFFF, 0xFFFF, 0,	// Background color == white
		gxCMYKSpace,										// Convert to gxCMYKSpace before halftoning.
		gxNoSpace,											// No explicit color space
		gxNoSet,											// No color set
		gxNoProfile											// No profile specified
	};
};

// The rasterPackType resource allows us to control the packaging that takes place within the
// raster generic driver's RasterDataIn proc.  Drivers which do not use the Raster 
// generic RasterDataIn proc or override it entirely themselves need not have this resource.

resource gxRasterPackType (gxRasterPackID, sysheap, purgeable)
{
	kBufferSize,		// packing buffer size - for the ImageWriter LQ 
							// this is the # of bytes in our largest single packaged line
	
	4,						// we are a CMYK device (so colorsPasses == 4)
	24,					// we have a 24 pixel high head
	1,						// it takes one pass to achive this 24 pixels
	0,						// number of pixel difference between passes; N/A since we do it in one pass
	gxInterlaceColor,	// avoid ribbon contamination
};

// The rasterPackOptionsType resource controls the remaining 2 raster packaging messages: RasterLineFeed,
// and RasterPackageBitmap.  If you allow the generic driver to implement these messages for
// you, then you MUST have a resource of this type. 

resource gxRasterPackOptionsType (gxRasterPackOptionsID, sysheap, purgeable)
{
	gxPrintingDriverBaseID,			//	Resource ID of 'wstr' resource containing the start page string to send to printer
	gxPrintingDriverBaseID + 4,	//	Resource ID of 'wstr' resource containing the form feed string to send to printer
	
	// forward line feed characteristics
	99,							// max line feed amount is 99
	gxRasterNumToASCII,		// express line feed as ASCII
	2,								// minimum width of ASCII number is 2
	"0",							// pad ASCII number with leading zeros
	"\0X1BT",					// <esc>T == set line feed size
	"\0X1Bf\0X0A",				// <esc>f<lf> == direction forward, do line feed
	
	// reverse line feed characteristics
	99,							// max line feed amount is 99
	gxRasterNumToASCII,		// express line feed as ASCII
	2,								// minimum width of ASCII number is 2
	"0",							// pad ASCII number with leading zeros
	"\0X1BT",					// <esc>T == set line feed size
	"\0X1Br\0X0A",				// <esc>r<lf> == direction reverse, do line feed
};

// These 'wstr' resources are the start page and form feed strings that are referenced in the rasterPackOptionsType
// resource

resource 'wstr' (kHighResUniDirID, sysheap, purgeable)
{
	"\0X1B>" "\0X1Be"				// Start page string for high resolution: unidirectional, 216 dpi == ESC > ESC e
};

resource 'wstr' (kHighResBiDirID, sysheap, purgeable)
{
	"\0X1B<" "\0X1Be"				// Start page string for high resolution: bidirectional, 216 dpi == ESC < ESC e
};

resource 'wstr' (kLowResUniDirID, sysheap, purgeable)
{
	"\0X1B>" "\0X1Bn"	"\0X1B!"	// Start page string for standard resolution: unidirectional, 72 dpi, boldface  == ESC > ESC e ESC !
};

resource 'wstr' (kLowResBiDirID, sysheap, purgeable)
{
	"\0X1B<" "\0X1Bn"	"\0X1B!"	// Start page string for standard resolution: bidirectional, 72 dpi, boldface == ESC < ESC n ESC !
};

resource 'wstr' (gxPrintingDriverBaseID + 4, sysheap, purgeable) 
{
	"\0X0C"	"\0X1B\0X22"		// End page string:   a control-L for the IW LQ's form feed and turn off boldface if needed (ESC ")
};


/*************************** I/O Related Resources ***************************/

// This universalIOPrefsType resource controls the behavior of the standard buffering and IO 
// within the Universal Driver. 

resource gxUniversalIOPrefsType (gxUniversalIOPrefsID, sysheap, purgeable)
{
		standardIO,
		4,					// Universal Driver will not allocate any buffers 
		kBufferSize,	// size of the buffers allocated (at least as big as one scan line) 
		10,				// number of I/O request blocks to allocate for the Universal Driver's I/O 
		1200,				// 1200 tick timeout for open/close 
		1200,				// 1200 tick timeout for reading and writing 
};
	
// The following resources are strings for capturing PAP ImageWriter LQ's

resource gxCaptureType (gxCapturedAppleTalkType, sysheap, purgeable)
{
	"\0D011LQShared"
};
resource gxCaptureType (gxUncapturedAppleTalkType, sysheap, purgeable)
{
	"\0D011LQ"
};

resource gxCaptureType (gxCaptureStringID, sysheap, purgeable)
{
	"\0X1B\0X62NAMELENPRINTERNAMETYPELENPRINTERTYPE\0X01*"
};

resource gxCaptureType (gxReleaseStringID, sysheap, purgeable)
{
	"\0X1B\0X62NAMELENPRINTERNAMETYPELENPRINTERTYPE\0X01*"
};


/*************************** Status Dialog Related Resources ***************************/
// The 'stat' resources provide the Printing Manager the status messages that need to be displayed at
// any given time during the printing process. The driver forces statuses to be displayed by calling 
// either ReportStatus or AlertTheUser, depending upon whether the user needs to make some decision 
// about the printing process (e.g. paper tray not properly loaded. Note that though the statID field
// of the 'stat' resource is for the clients use (us), PrinterShare requires that any 'stat' list
// entry that has the same status type (e.g. informationalStatus) must have a unique statID.  The reason
// is that PrinterShare uses the (status type, statID) pair in comparisons to see if the status has
// changed.

resource 'stat' (kDriverStatusID, sysheap, purgeable) 		// Driver status informational messages only 
{
	kDrvrCreatorType,
	{
		printerReady, 	1,		kNoAlertCoolID,	"Sending data to the printer";
	}
};


/*************************** Paper Type Definitions for the New Printing Architecture **************************/
// These paper type definitions represent the new settings for the ImageWriter LQ's paper 
// sizes. 

resource 'ptyp' (kNewPaperTypesID + 1, sysheap, purgeable)			// US Letter 
{
	"US Letter",
	
	// page rectangle 
	0x00000000,				// 8.0 x 10.33
	0x00000000,				
	0x02400000,				
	0x02E7C298,				

	// paper rectangle 
	0xFFEE0000,				// 8.5 x 11.0
	0xFFE7E14C,				
	0x02520000,				
	0x02FFE14C,				
	
	usLetterBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	isDefaultPaperType,
	{}
};

resource 'ptyp' (kNewPaperTypesID + 2, sysheap, purgeable)			// US Legal 
{
	"US Legal",
	
	// page rectangle 
	0x00000000,				// 8.0 x 13.33
	0x00000000,				
	0x02400000,					
	0x03BFC298,				

	// paper rectangle 
	0xFFEE0000,				// 8.5 x 14.0
	0xFFE7E14C,				
	0x02520000,				
	0x03D7E14C,				
	
	usLegalBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kNewPaperTypesID + 3, sysheap, purgeable)			// Computer Paper 
{
	"Computer Paper",
	
	// page rectangle 
	0x00000000,				// 13.33 x 10.33 
	0x00000000,
	0x03BFC298,
	0x02E7C298,

	// paper rectangle 
	0xFFE7E14C,				//	14.0 x 11.0
	0xFFE7E14C,
	0x03D7E14C,
	0x02FFE14C,
	
	unknownBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kNewPaperTypesID + 4, sysheap, purgeable)			// A4 Letter 
{
	"A4 Letter",
	
	// page rectangle 
	0x00000000,				// 8.0 x 11.0 
	0x00000000,				
	0x02400000,				
	0x03180000,				

	// paper rectangle 
	0xFFF70000,				// 8.25 x 11.67
	0xFFE7E14C,				
	0x02490000,				
	0x03301EB4,				
	
	a4LetterBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kNewPaperTypesID + 5, sysheap, purgeable)			// International Fanfold 
{
	"International Fanfold",
	
	// page rectangle 
	0x00000000,					// 8.0 x 11.33 
	0x00000000,					
	0x02400000,					
	0x032FC298,					
	
	// paper rectangle 
	0xFFF70000,					// 8.25 x 12.0 
	0xFFE7E14C,					
	0x02490000,					
	0x0347E14C,					
	
	unknownBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	notDefaultPaperType,
	{}
};

resource 'ptyp' (kNewPaperTypesID + 6, sysheap, purgeable)			// Envelope (#10) 
{
	"Envelope (#10)",
	
	// page rectangle 
	0x00000000,					// 9.3333 x 3.3333 
	0x00000000,					
	0x029FFF58,					
	0x00EFFF58,					
	
	// paper rectangle 
	0xFFF9FFAC,					// 9.5 x 4.125 
	0xFFE37FAC,					
	0x02A5FFAC,					
	0x010C7FAC,					
	
	unknownBase,
	kDrvrCreatorType,

	inch,
	newStylePaperType,
	notDefaultPaperType,
	{}
};


/*************************** "LQ Options" Job Print Dialog Panel Resources **************************/
// The following resources describe a dialog panel, LQ Options", that is always added by the LW driver 
// to the Print Job dialog.  It currently contains one option, which is to select bidirectional or
// unidirectional printing.

// The 'ppnl' resource provides a description of the panel we want to have displayed by the Printing Manager

resource 'ppnl'  (kLQOptionsPanl, sysheap, purgeable)
{
		"LQ Options", 		//	Name that appears below the panel's icon
		smRoman, 			//	script to use
		kDriverIconID, 	//	Resource ID of the panel's icon (an 'iclX' resource)
		kLQOptionsDITL;	//	Resource ID of the 'DITL' that describes the dialog panel items
};

// The 'DITL' resource describes the panel's dialog items

resource 'DITL' (kLQOptionsDITL, sysheap, purgeable) 
{
	{
		/* [1] */	{10, 10, 26, 190}, StaticText {disabled, "Options:"},
				
		/* [2] */	{33, 20, 49, 99}, StaticText {disabled, "Head Scan:"},
		/* [3] */	{56, 50, 72, 218}, RadioButton {enabled, "Bidirectional"},
		/* [4] */	{79, 50, 95, 218}, RadioButton {enabled, "Unidirectional"}
	}
};

// The 'xdtl' resource tells the Printing Manager the type of items that are logically grouped in 
// the dialog panel and specifies the Job collection item into which the dialog item settings
// should be stored.

resource 'xdtl' (kLQOptionsXdtl, sysheap, purgeable)
{
	{	
		RadioButtons	{ kDrvrCreatorType, kHeadMotionItemIndex,  0, {3, 4} }
	};
};

resource 'hdlg' (kLQOptionsPanl, purgeable, sysHeap) 
{
	HelpMgrVersion,
	0,
	hmDefaultOptions,
	0,
	3,		// hang left
	
	// missing items
	HMSkipItem {},

	{
	HMSkipItem {},
	HMSkipItem {},

	HMStringResItem{
		{6,6},
		{0,0,0,0},
		kHelpID, 1, 0, 0, kHelpID, 1, 0, 0, 
		};

	HMStringResItem{
		{6,6},
		{0,0,0,0},
		kHelpID, 2, 0, 0, kHelpID, 2, 0, 0, 
		};
		
	}
};

resource 'STR#' (kHelpID, purgeable, sysHeap)
{
	{
	"Checking this option causes your printout to print faster, but with less quality.";
	"Checking this option causes your printout to print slower, but with higher quality.";
	};
};


/*************************** Default Input Tray Related Resources **************************/
// The following resources describe the default input tray for the LQ printer.  These
// resources are accessed by the Printing Manager when a deskptop printer is created.  They
// define the default paper input slot for the printer.


// The trayNameDataType specifies the human readable name of the default input tray

resource gxTrayNameDataType (kDefaultTrayNameID, sysheap, purgeable)
{
	"Paper Feed Slot";
};


// trayCountDataType specifies the default number of paper feed trays. Note that the
// Printing Manager requires that this resource have resource ID trayCountDataID.

resource gxTrayCountDataType (kDefaultTrayRsrcID, sysheap, purgeable)
{
	1;
};


/*************************** LQ Cut Sheet Feeder Related Resources **************************/
// The following resources describe the default number of sheet feeder trays for an LQ with a
// feeder attached and the human readable names of the trays.


// trayNameDataType specify the human readable names of the trays

resource gxTrayNameDataType (kDefaultSheetFdrTray1NameID, sysheap, purgeable)
{
	"Tray #1";
};

resource gxTrayNameDataType (kDefaultSheetFdrTray2NameID, sysheap, purgeable)
{
	"Tray #2";
};

resource gxTrayNameDataType (kDefaultSheetFdrTray3NameID, sysheap, purgeable)
{
	"Tray #3";
};


// trayCountDataType specifies the number of trays. Note that the
// Printing Manager requires that this resource have resource ID trayCountDataID.

resource gxTrayCountDataType (kDefaultSheetFeederRsrcID, sysheap, purgeable)
{
	3;
};


/*************************** LQ Cut Sheet Feeder Dialog Setup Related Resources **************************/
// The following resources describe the dialog that is displayed when the user attempts to configure
// the paper that's contained in the printer's sheet feeder.  


// These DITL and DLOG resources describe the sheetfeeder dialog

resource 'DITL' (kSheetFeederDITL, sysheap, purgeable)
{
	{
		/* [1] */	{158, 380, 178, 440}, Button {enabled, "OK"},
		/* [2] */	{158, 304, 178, 364}, Button {enabled, "Cancel"},
		/* [3] */	{10, 30, 26, 370}, StaticText {disabled, "Please specify the paper in the LQ printer:"},
		/* [4] */	{39, 247, 59, 440}, Control {enabled, kTray1Control},		// Tray #1 pop-up
		/* [5] */	{64, 247, 84, 440}, Control {enabled, kTray2Control},		//	Tray #2 pop-up
		/* [6] */	{87, 247, 110, 440}, Control {enabled, kTray3Control},	//	Tray #3 pop-up
		/* [7] */	{47, 62, 177, 239}, UserItem {disabled}						//	Picture of printer with sheetfeeder
	}
};

resource 'DLOG' (kSheetFeederDLOG, sysheap, purgeable)
{
	{34, 14, 225, 476},
	dBoxProc,
	invisible,
	noGoAway,
	0x0,
	kSheetFeederDITL,
	"LQ Setup",
	alertPositionMainScreen
};


// This resource is needed for proper use of color in the Sheetfeeder dialog

resource 'dctb' (kSheetFeederDLOG, sysheap, purgeable)
{
	{	/* array ColorSpec: 0 elements */
	}
};


// These MENU resources describe the pop-up menus that are included in the sheetfeeder dialog

resource 'MENU' (kTray1Menu, sysheap, purgeable)
{
	kTray1Menu,
	textMenuProc,
	allEnabled,
	enabled,
	"Tray #1",
	{	/* array: 0 elements */
	}
};

resource 'MENU' (kTray2Menu, sysheap, purgeable)
{
	kTray2Menu,
	textMenuProc,
	allEnabled,
	enabled,
	"Tray #2",
	{	/* array: 0 elements */
	}
};

resource 'MENU' (kTray3Menu, sysheap, purgeable)
{
	kTray3Menu,
	textMenuProc,
	allEnabled,
	enabled,
	"Tray #3",
	{	/* array: 0 elements */
	}
};


// These CNTL resources describe the dialog controls that reference the pop-up menus in the sheetfeeder dialog

resource 'CNTL' (kTray1Control, sysheap, purgeable)
{
	{39, 247, 59, 440},
	0,
	visible,
	65,
	kTray1Menu,
	1008,
	0,
	"Tray #1:"
};

resource 'CNTL' (kTray2Control, sysheap, purgeable)
{
	{64, 247, 84, 440},
	0,
	visible,
	65,
	kTray2Menu,
	1008,
	0,
	"Tray #2:"
};

resource 'CNTL' (kTray3Control, sysheap, purgeable)
{
	{87, 247, 110, 440},
	0,
	visible,
	65,
	kTray3Menu,
	1008,
	0,
	"Tray #3:"
};


// These PICT resources are displayed in the sheetfeeder dialog and contain images of a 1, 2, and 3 tray LQ printer

resource 'PICT' (kThreeTrayPICT, sysheap, purgeable)				// Three tray LQ sheetfeeder
{
	1212,
	{0, 0, 130, 177},
	$"0011 02FF 0C00 FFFF FFFF FFFF 0000 FFFF"
	$"0000 00B0 0000 0081 0000 0000 0000 00A1"
	$"0064 0008 6450 726F 0000 0001 00A0 0082"
	$"001E 001A BFFF BFFF BFFF 0001 000A FFFF"
	$"FFFF 0081 00B0 0031 0060 0029 0067 009C"
	$"001A 0000 0000 0000 0038 001A BFFF BFFF"
	$"BFFF 0031 0065 0001 0081 009C 001A 0000"
	$"0000 0000 0038 001A BFFF BFFF BFFF 0051"
	$"0060 0020 0071 0031 001A 0000 0000 0000"
	$"0058 001A BFFF BFFF BFFF 0061 0060 0021"
	$"006B 0032 010E 005A 001A 0000 0000 0000"
	$"0068 010E 005A 00A0 00A0 00A1 00A4 0002"
	$"0750 0001 000A 0000 0000 0000 0000 0022"
	$"0060 003A 0000 0023 0DEA 0023 0000 0023"
	$"0900 0023 0000 0023 F516 0023 0000 0023"
	$"F500 0023 0000 001A BFFF BFFF BFFF 0084"
	$"000A 0000 0000 0000 0000 00A0 00A3 0001"
	$"000A FFFF FFFF 0081 00B0 0081 00C0 004A"
	$"003A 0060 0050 004A 0047 0050 7FFF 004B"
	$"0046 0047 004F 0050 7FFF 004D 0045 0046"
	$"004E 004F 7FFF 004E 0044 0045 7FFF 004F"
	$"004D 004E 7FFF 0050 0043 0044 7FFF 0051"
	$"004C 004D 7FFF 0052 0042 0043 7FFF 0053"
	$"0041 0042 004B 004C 7FFF 0055 0040 0041"
	$"004A 004B 7FFF 0057 003F 0040 0049 004A"
	$"7FFF 0058 003E 003F 7FFF 0059 0048 0049"
	$"7FFF 005A 003D 003E 7FFF 005B 0047 0048"
	$"7FFF 005C 003C 003D 7FFF 005D 003B 003C"
	$"0046 0047 7FFF 005F 003A 003B 0045 0046"
	$"7FFF 0060 003A 0045 7FFF 7FFF 001A 0000"
	$"0000 0000 0023 0DEA 0023 0900 0023 F516"
	$"0023 F500 00A0 00A1 00A0 00A0 00A1 00A4"
	$"0002 0750 0001 000A 0000 0000 0000 0000"
	$"0022 0060 0057 0000 0023 0DEA 0023 0000"
	$"0023 0900 0023 0000 0023 F516 0023 0000"
	$"0023 F500 0023 0000 001A BFFF BFFF BFFF"
	$"0084 000A 0000 0000 0000 0000 00A0 00A3"
	$"0001 000A FFFF FFFF 0081 00B0 0081 00C0"
	$"004A 0057 0060 006D 004A 0064 006D 7FFF"
	$"004B 0063 0064 006C 006D 7FFF 004D 0062"
	$"0063 006B 006C 7FFF 004E 0061 0062 7FFF"
	$"004F 006A 006B 7FFF 0050 0060 0061 7FFF"
	$"0051 0069 006A 7FFF 0052 005F 0060 7FFF"
	$"0053 005E 005F 0068 0069 7FFF 0055 005D"
	$"005E 0067 0068 7FFF 0057 005C 005D 0066"
	$"0067 7FFF 0058 005B 005C 7FFF 0059 0065"
	$"0066 7FFF 005A 005A 005B 7FFF 005B 0064"
	$"0065 7FFF 005C 0059 005A 7FFF 005D 0058"
	$"0059 0063 0064 7FFF 005F 0057 0058 0062"
	$"0063 7FFF 0060 0057 0062 7FFF 7FFF 001A"
	$"0000 0000 0000 0023 0DEA 0023 0900 0023"
	$"F516 0023 F500 00A0 00A1 00A0 00A0 00A1"
	$"00A4 0002 0750 0001 000A 0000 0000 0000"
	$"0000 0022 0060 0075 0000 0023 0DEA 0023"
	$"0000 0023 0900 0023 0000 0023 F516 0023"
	$"0000 0023 F500 0023 0000 001A BFFF BFFF"
	$"BFFF 0084 000A 0000 0000 0000 0000 00A0"
	$"00A3 0001 000A FFFF FFFF 0081 00B0 0081"
	$"00C0 004A 0075 0060 008B 004A 0082 008B"
	$"7FFF 004B 0081 0082 008A 008B 7FFF 004D"
	$"0080 0081 0089 008A 7FFF 004E 007F 0080"
	$"7FFF 004F 0088 0089 7FFF 0050 007E 007F"
	$"7FFF 0051 0087 0088 7FFF 0052 007D 007E"
	$"7FFF 0053 007C 007D 0086 0087 7FFF 0055"
	$"007B 007C 0085 0086 7FFF 0057 007A 007B"
	$"0084 0085 7FFF 0058 0079 007A 7FFF 0059"
	$"0083 0084 7FFF 005A 0078 0079 7FFF 005B"
	$"0082 0083 7FFF 005C 0077 0078 7FFF 005D"
	$"0076 0077 0081 0082 7FFF 005F 0075 0076"
	$"0080 0081 7FFF 0060 0075 0080 7FFF 7FFF"
	$"001A 0000 0000 0000 0023 0DEA 0023 0900"
	$"0023 F516 0023 F500 00A0 00A1 0022 004B"
	$"008A 0CE7 0022 004A 006D 17CF 0022 004A"
	$"0050 23B7 0022 0032 0096 1800 0022 0019"
	$"0086 2900 0022 0001 0073 3C00 00A0 0083"
	$"00FF"
};

resource 'PICT' (kTwoTrayPICT, sysheap, purgeable)				// Two tray LQ sheetfeeder
{
	874,
	{0, 0, 130, 177},
	$"0011 02FF 0C00 FFFF FFFF FFFF 0000 FFFF"
	$"0000 00B0 0000 0081 0000 0000 0000 00A1"
	$"0064 0008 6450 726F 0000 0001 00A0 0082"
	$"001E 001A BFFF BFFF BFFF 0001 000A FFFF"
	$"FFFF 0081 00B0 0031 0060 0029 0067 009C"
	$"001A 0000 0000 0000 0038 001A BFFF BFFF"
	$"BFFF 0031 0065 0001 0081 009C 001A 0000"
	$"0000 0000 0038 001A BFFF BFFF BFFF 0051"
	$"0060 0020 0071 0031 001A 0000 0000 0000"
	$"0058 001A BFFF BFFF BFFF 0061 0060 0021"
	$"006B 0032 010E 005A 001A 0000 0000 0000"
	$"0068 010E 005A 00A0 00A0 00A1 00A4 0002"
	$"0750 0001 000A 0000 0000 0000 0000 0022"
	$"0060 003A 0000 0023 0DEA 0023 0000 0023"
	$"0900 0023 0000 0023 F516 0023 0000 0023"
	$"F500 0023 0000 001A BFFF BFFF BFFF 0084"
	$"000A 0000 0000 0000 0000 00A0 00A3 0001"
	$"000A FFFF FFFF 0081 00B0 0081 00C0 004A"
	$"003A 0060 0050 004A 0047 0050 7FFF 004B"
	$"0046 0047 004F 0050 7FFF 004D 0045 0046"
	$"004E 004F 7FFF 004E 0044 0045 7FFF 004F"
	$"004D 004E 7FFF 0050 0043 0044 7FFF 0051"
	$"004C 004D 7FFF 0052 0042 0043 7FFF 0053"
	$"0041 0042 004B 004C 7FFF 0055 0040 0041"
	$"004A 004B 7FFF 0057 003F 0040 0049 004A"
	$"7FFF 0058 003E 003F 7FFF 0059 0048 0049"
	$"7FFF 005A 003D 003E 7FFF 005B 0047 0048"
	$"7FFF 005C 003C 003D 7FFF 005D 003B 003C"
	$"0046 0047 7FFF 005F 003A 003B 0045 0046"
	$"7FFF 0060 003A 0045 7FFF 7FFF 001A 0000"
	$"0000 0000 0023 0DEA 0023 0900 0023 F516"
	$"0023 F500 00A0 00A1 00A0 00A0 00A1 00A4"
	$"0002 0750 0001 000A 0000 0000 0000 0000"
	$"0022 0060 0057 0000 0023 0DEA 0023 0000"
	$"0023 0900 0023 0000 0023 F516 0023 0000"
	$"0023 F500 0023 0000 001A BFFF BFFF BFFF"
	$"0084 000A 0000 0000 0000 0000 00A0 00A3"
	$"0001 000A FFFF FFFF 0081 00B0 0081 00C0"
	$"004A 0057 0060 006D 004A 0064 006D 7FFF"
	$"004B 0063 0064 006C 006D 7FFF 004D 0062"
	$"0063 006B 006C 7FFF 004E 0061 0062 7FFF"
	$"004F 006A 006B 7FFF 0050 0060 0061 7FFF"
	$"0051 0069 006A 7FFF 0052 005F 0060 7FFF"
	$"0053 005E 005F 0068 0069 7FFF 0055 005D"
	$"005E 0067 0068 7FFF 0057 005C 005D 0066"
	$"0067 7FFF 0058 005B 005C 7FFF 0059 0065"
	$"0066 7FFF 005A 005A 005B 7FFF 005B 0064"
	$"0065 7FFF 005C 0059 005A 7FFF 005D 0058"
	$"0059 0063 0064 7FFF 005F 0057 0058 0062"
	$"0063 7FFF 0060 0057 0062 7FFF 7FFF 001A"
	$"0000 0000 0000 0023 0DEA 0023 0900 0023"
	$"F516 0023 F500 00A0 00A1 0022 004A 006D"
	$"17CF 0022 004A 0050 23B7 0022 0019 0086"
	$"2900 0022 0001 0073 3C00 00A0 0083 00FF"
};

resource 'PICT' (kOneTrayPICT, sysheap, purgeable)				// One tray LQ sheetfeeder
{
	532,
	{0, 0, 130, 177},
	$"0011 02FF 0C00 FFFF FFFF FFFF 0000 FFFF"
	$"0000 00B0 0000 0081 0000 0000 0000 00A1"
	$"0064 0008 6450 726F 0000 0001 00A0 0082"
	$"001E 001A BFFF BFFF BFFF 0001 000A FFFF"
	$"FFFF 0081 00B0 0031 0060 0029 0067 009C"
	$"001A 0000 0000 0000 0038 001A BFFF BFFF"
	$"BFFF 0031 0065 0001 0081 009C 001A 0000"
	$"0000 0000 0038 001A BFFF BFFF BFFF 0051"
	$"0060 0020 0071 0031 001A 0000 0000 0000"
	$"0058 001A BFFF BFFF BFFF 0061 0060 0021"
	$"006B 0032 010E 005A 001A 0000 0000 0000"
	$"0068 010E 005A 00A0 00A0 00A1 00A4 0002"
	$"0750 0001 000A 0000 0000 0000 0000 0022"
	$"0060 003A 0000 0023 0DEA 0023 0000 0023"
	$"0900 0023 0000 0023 F516 0023 0000 0023"
	$"F500 0023 0000 001A BFFF BFFF BFFF 0084"
	$"000A 0000 0000 0000 0000 00A0 00A3 0001"
	$"000A FFFF FFFF 0081 00B0 0081 00C0 004A"
	$"003A 0060 0050 004A 0047 0050 7FFF 004B"
	$"0046 0047 004F 0050 7FFF 004D 0045 0046"
	$"004E 004F 7FFF 004E 0044 0045 7FFF 004F"
	$"004D 004E 7FFF 0050 0043 0044 7FFF 0051"
	$"004C 004D 7FFF 0052 0042 0043 7FFF 0053"
	$"0041 0042 004B 004C 7FFF 0055 0040 0041"
	$"004A 004B 7FFF 0057 003F 0040 0049 004A"
	$"7FFF 0058 003E 003F 7FFF 0059 0048 0049"
	$"7FFF 005A 003D 003E 7FFF 005B 0047 0048"
	$"7FFF 005C 003C 003D 7FFF 005D 003B 003C"
	$"0046 0047 7FFF 005F 003A 003B 0045 0046"
	$"7FFF 0060 003A 0045 7FFF 7FFF 001A 0000"
	$"0000 0000 0023 0DEA 0023 0900 0023 F516"
	$"0023 F500 00A0 00A1 0022 004A 0050 23B7"
	$"0023 3C00 00A0 0083 00FF"
};


/*************************** Draft Mode Printing Resources **************************/
// The idft resource describes all of the characters that can be output to the LQ in draft
// mode.  For any of the possible characters, the table lists the one or two character
// sequence that needs to be printed in order to generate the target character.  In the event
// two characters must be printed in order to generate the target character, the second character
// is overstruck on the first character.

type 'idft' {
	array charArray {
	unsigned bitstring[1] noBack = 0, Back = 1;			//	Back => must overstrike first character with the second
	unsigned bitstring[3] = 0;
	unsigned bitstring[4]	American =	kAmerican, 		// Character sets supported
									British	=	kBritish, 
									Danish	=	kDanish, 
									French	=	kFrench, 
									German	=	kGerman, 
									Italian	=	kItalian, 
									Swedish	=	kSwedish, 
									Spanish	=	kSpanish;	
	unsigned hex byte noChar = $00;							//	The actual character to print
	};
};

// Note: to properly see the following characters, this file should be viewed in Courier

resource 'idft' (gxPrintingDriverBaseID, sysheap, purgeable)
{
	{
	noBack,		American,	$20;	noBack,		American,	noChar;		// space
	noBack,		American,	$21;	noBack,		American,	noChar;		// !
	noBack,		American,	$22;	noBack,		American,	noChar;		// "
	noBack,		American,	$23;	noBack,		American,	noChar;		// #
	noBack,		American,	$24;	noBack,		American,	noChar;		// $
	noBack,		American,	$25;	noBack,		American,	noChar;		// %
	noBack,		American,	$26;	noBack,		American,	noChar;		// &
	noBack,		American,	$27;	noBack,		American,	noChar;		// '
	noBack,		American,	$28;	noBack,		American,	noChar;		// (
	noBack,		American,	$29;	noBack,		American,	noChar;		// )
	noBack,		American,	$2A;	noBack,		American,	noChar;		// *
	noBack,		American,	$2B;	noBack,		American,	noChar;		// +
	noBack,		American,	$2C;	noBack,		American,	noChar;		// ,
	noBack,		American,	$2D;	noBack,		American,	noChar;		// -
	noBack,		American,	$2E;	noBack,		American,	noChar;		// .
	noBack,		American,	$2F;	noBack,		American,	noChar;		// /
	
	noBack,		American,	$30;	noBack,		American,	noChar;		// 0
	noBack,		American,	$31;	noBack,		American,	noChar;		// 1
	noBack,		American,	$32;	noBack,		American,	noChar;		// 2
	noBack,		American,	$33;	noBack,		American,	noChar;		// 3
	noBack,		American,	$34;	noBack,		American,	noChar;		// 4
	noBack,		American,	$35;	noBack,		American,	noChar;		// 5
	noBack,		American,	$36;	noBack,		American,	noChar;		// 6
	noBack,		American,	$37;	noBack,		American,	noChar;		// 7
	noBack,		American,	$38;	noBack,		American,	noChar;		// 8
	noBack,		American,	$39;	noBack,		American,	noChar;		// 9
	noBack,		American,	$3A;	noBack,		American,	noChar;		// :
	noBack,		American,	$3B;	noBack,		American,	noChar;		// ;
	noBack,		American,	$3C;	noBack,		American,	noChar;		// <
	noBack,		American,	$3D;	noBack,		American,	noChar;		// =
	noBack,		American,	$3E;	noBack,		American,	noChar;		// >
	noBack,		American,	$3F;	noBack,		American,	noChar;		// ?
	
	noBack,		American,	$40;	noBack,		American,	noChar;		// @
	noBack,		American,	$41;	noBack,		American,	noChar;		// A
	noBack,		American,	$42;	noBack,		American,	noChar;		// B
	noBack,		American,	$43;	noBack,		American,	noChar;		// C
	noBack,		American,	$44;	noBack,		American,	noChar;		// D
	noBack,		American,	$45;	noBack,		American,	noChar;		// E
	noBack,		American,	$46;	noBack,		American,	noChar;		// F
	noBack,		American,	$47;	noBack,		American,	noChar;		// G
	noBack,		American,	$48;	noBack,		American,	noChar;		// H
	noBack,		American,	$49;	noBack,		American,	noChar;		// I
	noBack,		American,	$4A;	noBack,		American,	noChar;		// J
	noBack,		American,	$4B;	noBack,		American,	noChar;		// K
	noBack,		American,	$4C;	noBack,		American,	noChar;		// L
	noBack,		American,	$4D;	noBack,		American,	noChar;		// M
	noBack,		American,	$4E;	noBack,		American,	noChar;		// N
	noBack,		American,	$4F;	noBack,		American,	noChar;		// O
	noBack,		American,	$50;	noBack,		American,	noChar;		// P
	noBack,		American,	$51;	noBack,		American,	noChar;		// Q
	noBack,		American,	$52;	noBack,		American,	noChar;		// R
	noBack,		American,	$53;	noBack,		American,	noChar;		// S
	noBack,		American,	$54;	noBack,		American,	noChar;		// T
	noBack,		American,	$55;	noBack,		American,	noChar;		// U
	noBack,		American,	$56;	noBack,		American,	noChar;		// V
	noBack,		American,	$57;	noBack,		American,	noChar;		// W
	noBack,		American,	$58;	noBack,		American,	noChar;		// X
	noBack,		American,	$59;	noBack,		American,	noChar;		// Y
	noBack,		American,	$5A;	noBack,		American,	noChar;		// Z
	
	noBack,		American,	$5B;	noBack,		American,	noChar;		// [
	noBack,		American,	$5C;	noBack,		American,	noChar;		// \
	noBack,		American,	$5D;	noBack,		American,	noChar;		// ]
	noBack,		American,	$5E;	noBack,		American,	noChar;		// ^
	noBack,		American,	$5F;	noBack,		American,	noChar;		// _
	noBack,		American,	$60;	noBack,		American,	noChar;		// `
	
	noBack,		American,	$61;	noBack,		American,	noChar;		// a
	noBack,		American,	$62;	noBack,		American,	noChar;		// b
	noBack,		American,	$63;	noBack,		American,	noChar;		// c
	noBack,		American,	$64;	noBack,		American,	noChar;		// d
	noBack,		American,	$65;	noBack,		American,	noChar;		// e
	noBack,		American,	$66;	noBack,		American,	noChar;		// f
	noBack,		American,	$67;	noBack,		American,	noChar;		// g
	noBack,		American,	$68;	noBack,		American,	noChar;		// h
	noBack,		American,	$69;	noBack,		American,	noChar;		// i
	noBack,		American,	$6A;	noBack,		American,	noChar;		// j
	noBack,		American,	$6B;	noBack,		American,	noChar;		// k
	noBack,		American,	$6C;	noBack,		American,	noChar;		// l
	noBack,		American,	$6D;	noBack,		American,	noChar;		// m
	noBack,		American,	$6E;	noBack,		American,	noChar;		// n
	noBack,		American,	$6F;	noBack,		American,	noChar;		// o
	noBack,		American,	$70;	noBack,		American,	noChar;		// p
	noBack,		American,	$71;	noBack,		American,	noChar;		// q
	noBack,		American,	$72;	noBack,		American,	noChar;		// r
	noBack,		American,	$73;	noBack,		American,	noChar;		// s
	noBack,		American,	$74;	noBack,		American,	noChar;		// t
	noBack,		American,	$75;	noBack,		American,	noChar;		// u
	noBack,		American,	$76;	noBack,		American,	noChar;		// v
	noBack,		American,	$77;	noBack,		American,	noChar;		// w
	noBack,		American,	$78;	noBack,		American,	noChar;		// x
	noBack,		American,	$79;	noBack,		American,	noChar;		// y
	noBack,		American,	$7A;	noBack,		American,	noChar;		// z
	
	noBack,		American,	$7B;	noBack,		American,	noChar;		// {
	noBack,		American,	$7C;	noBack,		American,	noChar;		// |
	noBack,		American,	$7D;	noBack,		American,	noChar;		// }
	noBack,		American,	$7E;	noBack,		American,	noChar;		// ~
	noBack,		American,	$20;	noBack,		American,	noChar;		// undefined
	
	// $80 col
	noBack,		Swedish,		$5B;	noBack,		American,	noChar;		// 
	noBack,		Swedish,		$5D;	noBack,		American,	noChar;		// 
	noBack,		American,	$43;	Back,			American,	$2C;			// 
	noBack,		American,	$45;	Back,			American,	$27;			// 
	noBack,		Spanish,		$5C;	noBack,		American,	noChar;		// 
	noBack,		Swedish,		$5C;	noBack,		American,	noChar;		// 
	noBack,		German,		$5D;	noBack,		American,	noChar;		// 
	noBack,		American,	$61;	Back,			American,	$27;			// 
	noBack,		Italian,		$7B;	noBack,		American,	noChar;		// 
	noBack,		American,	$61;	Back,			American,	$5E;			// 
	noBack,		German,		$7B;	noBack,		American,	noChar;		// 
	noBack,		American,	$61;	Back,			American,	$7E;			// 
	noBack,		Danish,		$7D;	noBack,		American,	noChar;		// 
	noBack,		French,		$5C;	noBack,		American,	noChar;		// 
	noBack,		French,		$7B;	noBack,		American,	noChar;		// 
	noBack,		French,		$7D;	noBack,		American,	noChar;		// 

	// $90 col
	noBack,		American,	$65;	Back,			American,	$5E;			// 
	noBack,		American,	$22;	Back,			American,	$65;			// 
	noBack,		American,	$69;	Back,			American,	$27;			// 
	noBack,		Italian,		$7E;	noBack,		American,	noChar;		// 
	noBack,		American,	$69;	Back,			American,	$5E;			// 
	noBack,		American,	$22;	Back,			American,	$69;			// 
	noBack,		Spanish,		$7C;	noBack,		American,	noChar;		// 
	noBack,		American,	$6F;	Back,			American,	$27;			// 
	noBack,		Italian,		$7C;	noBack,		American,	noChar;		// 
	noBack,		American,	$6F;	Back,			American,	$5E;			// 
	noBack,		Swedish,		$7C;	noBack,		American,	noChar;		// 
	noBack,		American,	$6F;	Back,			American,	$7E;			// 
	noBack,		American,	$75;	Back,			American,	$27;			// 
	noBack,		French,		$7C;	noBack,		American,	noChar;		// 
	noBack,		American,	$75;	Back,			American,	$5E;			// 
	noBack,		German,		$7D;	noBack,		American,	noChar;		// 
		
	// $A0 col
	noBack,		American,	$2B;	Back,			American,	$7C;			// 
	noBack,		American,	$2A;	noBack,		American,	noChar;		// 
	noBack,		American,	$63;	Back,			American,	$7C;			// 
	noBack,		British,		$23;	noBack,		American,	noChar;		// 
	noBack,		German,		$40;	noBack,		American,	noChar;		// 
	noBack,		French,		$5B;	noBack,		American,	noChar;		// 
	noBack,		American,	$50;	noBack,		American,	noChar;		// 
	noBack,		German,		$7E;	noBack,		American,	noChar;		// 
	noBack,		American,	$4F;	Back,			American,	$72;			// 
	noBack,		American,	$4F;	Back,			American,	$63;			// 
	noBack,		American,	$74;	noBack,		American,	$6D;			// 
	noBack,		American,	$27;	noBack,		American,	noChar;		// 
	noBack,		French,		$7E;	noBack,		American,	noChar;		// 
	noBack,		American,	$3D;	Back,			American,	$2F;			// 
	noBack,		Danish,		$5B;	noBack,		American,	noChar;		// 
	noBack,		Danish,		$5C;	noBack,		American,	noChar;		// 
	
	// $B0 col
	noBack,		American,	$4F;	Back,			American,	$7C;			// 
	noBack,		American,	$2B;	Back,			American,	$5F;			// 
	noBack,		American,	$3C;	Back,			American,	$5F;			// 
	noBack,		American,	$3E;	Back,			American,	$5F;			// 
	noBack,		American,	$59;	Back,			American,	$3D;			// 
	noBack,		American,	$75;	noBack,		American,	noChar;		// 
	noBack,		American,	$40;	noBack,		American,	noChar;		// 
	noBack,		American,	$DC;	Back,			American,	$3E;			// 
	noBack,		American,	$6E;	noBack,		American,	noChar;		// 
	noBack,		American,	$6E;	noBack,		American,	noChar;		// 
	noBack,		American,	$2F;	noBack,		American,	noChar;		// 
	noBack,		American,	$61;	Back,			American,	$5F;			// 
	noBack,		American,	$6F;	Back,			American,	$5F;			// 
	noBack,		American,	$5A;	noBack,		American,	noChar;		// 
	noBack,		Danish,		$7B;	noBack,		American,	noChar;		// 
	noBack,		Danish,		$7C;	noBack,		American,	noChar;		// 

	// $C0 col
	noBack,		Spanish,		$5D;	noBack,		American,	noChar;		// 
	noBack,		Spanish,		$5B;	noBack,		American,	noChar;		// 
	noBack,		American,	$CC;	Back,			American,	$DA;			// 
	noBack,		American,	$C5;	noBack,		American,	noChar;		// 
	noBack,		American,	$53;	noBack,		American,	noChar;		// 
	noBack,		American,	$3D;	noBack,		American,	noChar;		// 
	noBack,		American,	$5E;	Back,			American,	$2D;			// 
	noBack,		American,	$C8;	noBack,		American,	noChar;		// 
	noBack,		American,	$D5;	noBack,		American,	noChar;		// 
	noBack,		American,	$C9;	noBack,		American,	noChar;		// 
	noBack,		American,	$20;	noBack,		American,	noChar;		// non-breaking space
	noBack,		American,	$41;	Back,			American,	$60;			// 
	noBack,		American,	$41;	Back,			American,	$7E;			// 
	noBack,		American,	$4F;	Back,			American,	$7E;			// 
	noBack,		American,	$6F;	noBack,		American,	$65;			// 
	noBack,		American,	$4F;	noBack,		American,	$45;			// 
	
	// $D0 col
	noBack,		American,	$2D;	noBack,		American,	noChar;		// 
	noBack,		American,	$D3;	noBack,		American,	noChar;		// 
	noBack,		American,	$22;	noBack,		American,	noChar;		// 
	noBack,		American,	$22;	noBack,		American,	noChar;		// 
	noBack,		American,	$27;	noBack,		American,	noChar;		// 
	noBack,		American,	$60;	noBack,		American,	noChar;		// 
	noBack,		American,	$2B;	noBack,		American,	noChar;		// 
	noBack,		American,	$DB;	noBack,		American,	noChar;		// 
	noBack,		American,	$79;	Back,			American,	$22;			// 
	noBack,		American,	$59;	Back,			American,	$22;			// 
	noBack,		American,	$2F;	noBack,		American,	noChar;		// /
	noBack,		American,	$DD;	noBack,		American,	noChar;		// 
	noBack,		American,	$3C;	noBack,		American,	noChar;		// 
	noBack,		American,	$3E;	noBack,		American,	noChar;		// 
	noBack,		American,	$66;	noBack,		American,	$69;			// 
	noBack,		American,	$66;	noBack,		American,	$6C;			// 
	
	// $E0 col
	noBack,		American,	$3D;	Back,			American,	$7C;			// 
	noBack,		American,	$2E;	noBack,		American,	noChar;		// 
	noBack,		American,	$2C;	noBack,		American,	noChar;		// 
	noBack,		American,	$2C;	noBack,		American,	noChar;		// 
	noBack,		American,	$25;	noBack,		American,	noChar;		// 
	noBack,		Danish,		$5D;	noBack,		American,	noChar;		// 
	noBack,		American,	$45;	Back,			American,	$5E;			// 
	noBack,		American,	$41;	Back,			American,	$27;			// 
	noBack,		American,	$45;	Back,			American,	$22;			// 
	noBack,		American,	$45;	Back,			American,	$60;			// 
	noBack,		American,	$49;	Back,			American,	$27;			// 
	noBack,		American,	$49;	Back,			American,	$5E;			// 
	noBack,		American,	$49;	Back,			American,	$22;			// 
	noBack,		American,	$49;	Back,			American,	$60;			// 
	noBack,		American,	$4F;	Back,			American,	$27;			// 
	noBack,		American,	$4F;	Back,			American,	$5E;			// 
	
	// $F0 col
	noBack,		American,	$C0;	noBack,		American,	noChar;		// 
	noBack,		American,	$4F;	Back,			American,	$60;			// 
	noBack,		American,	$55;	Back,			American,	$27;			// 
	noBack,		American,	$55;	Back,			American,	$5E;			// 
	noBack,		American,	$55;	Back,			American,	$60;			// 
	noBack,		American,	$69;	noBack,		American,	noChar;		// i
	noBack,		American,	$5E;	noBack,		American,	noChar;		// ^
	noBack,		Danish,		$7E;	noBack,		American,	noChar;		// 
	noBack,		American,	$2D;	noBack,		American,	noChar;		// 
	noBack,		American,	$2D;	noBack,		American,	noChar;		// 
	noBack,		American,	$2E;	noBack,		American,	noChar;		// 
	noBack,		American,	$2E;	noBack,		American,	noChar;		// 
	noBack,		American,	$2C;	noBack,		American,	noChar;		// 
	noBack,		American,	$22;	noBack,		American,	noChar;		// 
	noBack,		American,	$2C;	noBack,		American,	noChar;		// 
	noBack,		American,	$5E;	noBack,		American,	noChar;		// 
	};
};


// This 'STR#' contains a list of all of the native mode fonts that are supported.  Note the fonts
// listed here MUST exist in the target system.

resource 'STR#' (kFormatModeFontsID, sysheap, purgeable) 
{
	{
		"Monaco"
	}
};


// This 'STR#' contains a list of all of the native mode styles that are supported (the indices into the
// list are well known so don't reorder them.

resource 'STR#' (kFormatModeStylesID, sysheap, purgeable) 
{
	{
		"Bold",			//	kBoldStyle
		"Underline"		//	kUnderlineStyle
	}
};


// This 'STR#' contains a list of all of the qualities that are supported.

resource 'STR#' (kQualityID, sysheap, purgeable) 
{
	{
		"Best",
		"Rough"
	}
};
