/* ------------------------------------------------------------------------------
FILENAME
	ChooserSupport.r

DESCRIPTION
	This module contains the LaserWriter SC constants, types, and resources that
	are needed in order for the driver to work with the Chooser.
			
	Note: all resources should be designated to load into the system heap.

COPYRIGHT
	 Copyright Apple Computer, Inc. 1992
	 All rights reserved. 
	
-------------------------------------------------------------------------------- */

// System 7.0 Compatible
#define SystemSevenOrLater		1

// Include System Resource Definitions
#include "Types.r"
#include "SysTypes.r"

// Include the LaserWriter SC driver constants that are used in the resources 
#include "LaserSCResources.h"

// Include the public QuickDraw GX printing files 
#include "PrintingResTypes.r"

// Include the LaserWriterSC Driver's LDEF and PACK Code Segments ===== */

include "LWSC_PACK";
include "LWSC_LDEF";


/*********************************************************************************************
	 THINGS TO CONTROL THE DEFAULT CHOOSING MECHANSIM
*********************************************************************************************/

// The 'look' resource is used by the driver's PACK to know how to communicate 
// to the device.  This resource contains the default settings, as the actual value 
// can be found in the desktop printer. 

resource 'look' (kLookRsrcID, sysheap) 
{
	1,									// use the first in our list by default
	{
		"SCSI",			kSCSICommRsrcID,				iconCells,								"";
		"Servers",		kPrinterShareCommRsrcID,	isAppleTalk+isPrinterShare,		"LaserWriterSCIS";
	};
};


// This 'comm' resource defines the default communication settings when using this 
// driver with PrinterShare. 

resource 'comm' (kPrinterShareCommRsrcID)
{
	PrinterShare
	{
		"",
		0
	};
};


// This 'comm' resource defines the default communication settings when using this 
// driver with direct SCSI communications. 

resource 'comm' (kSCSICommRsrcID)
{
	SCSI
	{
		0,										// release device routine 
		0,										// io attibutes 
		0,										// status byte 
		0,										// scsi bus number 
		0,										// scsi ID 
		0,										// chunk level 
		0,										// acquire routine (use default)  
		2,										// deviceType to look for 
		27,									// minimum length of additional response data 
		8,										// bytes from start for search 
		"APPLE   PERSONAL LASER  ",	// search string 
	};
};
	

/*********************************************************************************************
	STANDARD CHOOSER PACK STUFF
*********************************************************************************************/

// NBP Lookup type (maxed out so resource file won't need updating)
resource 'STR ' (-4096)
{
	"XXXXXXXXXXXXXXXXXXXXXX";
};

// NBP timeout value
type 'GNRL'
{
	byte;	// timeout
	byte;	// retries
};

resource 'GNRL' (-4096)
{
	11,
	5
};

// title string (we'll put a control here, so we don't want a title)
resource 'STR ' (-4091)
{
	"";
};

// "left" button title
resource 'STR ' (-4093)
{
	"Create";
};

// rectangle list
resource 'nrct' (-4096) {
	{
	{112, 251, 132, 311};			// left button
	{0,0,0,0};							// right button
	{-101, 180, -101+20, 400};		// on button (location of device list - popup is placed here)
	{0,0,0,0};							// off button
	{0,0,0,0};							// button label
	};
};

// Menu used to select between direct connect, AppleTalk, and Servers
resource 'MENU' (-4096)
{
	-4096,
	textMenuProc,
	0xFFFFFFFF,	
	enabled,
	"",
	{
	}
};

// Pop-up control used to select between direct connect printers and those being shared on the network
resource 'CNTL' (-4096, purgeable)
{
	{0, 0, 20, 213},							// zero based control location
	0,												// Title options 0 = Left justified
	visible,										// Should we display the control?
	95,											// Title Width
	-4096,										// 'MENU' to display
	popupMenuCDEFproc+popupFixedWidth,	// CDEF = CDEFID * 16 + varCode
	0, 											// refCon = ResType to append = None
	"Connect via:"								// Control title
};

resource 'DITL' (-4096) 
{
	{
		{3, 238, 23, 238 + 213}, 
			Control {enabled, -4096},
	};
};


resource 'DITL' (-4095) {
	{	/* array DITLarray: 2 elements */
		/* [1] */
		{143, 310, 163, 368},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{23, 87, 119, 377},
		StaticText {
			disabled,
			"This printer driver could not be used.\n\n"
			"Quitting one or more applications and then "
			"trying again may allow you to use this "
			"printer driver."
		}
	}
};

resource 'ALRT' (-4095) {
	{30, 30, 30+175, 30+380},
	-4095,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	alertPositionParentWindowScreen
};

//-----------------------------------------------------------------------------------
// CHOOSER PACK HELP RESOURCES
//-----------------------------------------------------------------------------------


/*	Any Chooser package can get balloons on all items that are normally 
	added to the Chooser dialog by containing a STR# resource of 
	resource ID = PackResID (-5694) and following the convention below:
		
		resource 'STR#' (-5694, purgeable) {
		  {		"kEnabledLeftButton";	// message for button (or control) that is Enabled but not checked
				"kDisabledLeftButton";	// message for the control that is Disabled
				"kCheckedLeftButton";	// message for the control that is Checked (ie CtrlValue>0)
				"kOtherLeftButton";		// message for the control that is Other (ie CtrlValue>1)
				"kEnabledRightButton";
				"kDisabledRightButton";
				"kCheckedRightButton";
				"kOtherRightButton";
				"kEnabledOnButton";
				"kDisabledOnButton";
				"kCheckedOnButton";
				"kOtherOnButton";
				"kEnabledOffButton";
				"kDisabledOffButton";
				"kCheckedOffButton";
				"kOtherOffButton";
				"kEnabledOnOffTitle";
				"kDisabledOnOffTitle";
				"kCheckedOnOffTitle";
				"kOtherOnOffTitle";
		  }
		};
		
	This is a horrible Chooser hack for 7.0 - but we'll follow along in GX.
*/

resource 'STR#' (-5694, purgeable) {
  {		
  
  		"Click here to create a desktop printer for the selected device."; // message for button (or control) that is Enabled but not checked
		"You have not selected a device to create, or there is not enough memory to create a desktop printer at this time.";	// message for the control that is Disabled
		"";	// message for the control that is Checked (ie CtrlValue>0)
		"";	// message for the control that is Other (ie CtrlValue>1)
		"";	// kEnabledRightButton
		"";	// kDisabledRightButton
		"";	// kCheckedRightButton
		"";	// kOtherRightButton
		"Use this popup menu to select the type of connection for the desktop printer you are creating.";
		"";	// kDisabledOnButton
		"";	// kCheckedOnButton 
		"";	// kOtherOnButton
		"";	// kEnabledOffButton
		"";	// kDisabledOffButton
		"";	// kCheckedOffButton
		"";	// kOtherOffButton
		"";	// kEnabledOnOffTitle
		"";	// kDisabledOnOffTitle
		"";	// kCheckedOnOffTitle
		"";	// kOtherOnOffTitle
  }
};

