/* ------------------------------------------------------------------------------
FILENAME
	LaserSCResources.r

DESCRIPTION
	This module contains the standard LaserWriter SC constants, types, and resources 
	that are common to most drivers.  They include the appropriate bundle and
	icon resources.
	
	Note: All driver resources should be designated to be loaded into the system
	heap.
		
COPYRIGHT
	 Copyright Apple Computer, Inc. 1988-1994
	 All rights reserved. 
	
-------------------------------------------------------------------------------- */

// System 7.0 Compatible
#define SystemSevenOrLater		1

// Include System Resource Definitions
#include "Types.r"
#include "SysTypes.r"

// Include the LaserWriter SC driver constants that are used in the resources 
#include "LaserSCResources.h"

// Include the public QuickDraw GX printing files 
#include "PrintingResTypes.r"


// Include the LaserWriterSC Driver's Code Segments ===== */

include "LWSC_OldAPISeg";
include "LWSC_UnivSeg";


/**********************************************************************************
 *        						CONSTANTS		 									 				 *
 *********************************************************************************/

#define	kDriverIconID				(gxPrintingDriverBaseID)			// Resource ID of the driver file's FREF, BNDL, and icons 
#define	kDTPIconID					(gxPrintingDriverBaseID + 1)		// Resource ID of the desktop printer file's FREF and icons 
#define	kDTPCurrentNotSharedID	(gxPrintingDriverBaseID + 2)		// Resource ID of DTP icon for current/not shared representation 
#define	kDTPNotCurrentSharedID	(gxPrintingDriverBaseID + 3)		// Resource ID of DTP icon for not current/shared representation 
#define	kDTPCurrentSharedID		(gxPrintingDriverBaseID + 4)		// Resource ID of DTP icon for current/shared representation 
#define	kDTPNotActiveID			(gxPrintingDriverBaseID + 5)		// Resource ID of DTP icon for not active representation 
#define	kDTPNoGXID					(gxPrintingDriverBaseID + 6)		// Resource ID of DTP icon for no GX representation 
#define	kDTPPuzzleID				(gxPrintingDriverBaseID + 7)		// Resource ID of DTP icon for puzzle representation 


/**********************************************************************************
 *        						TYPES				 									 				 *
 *********************************************************************************/

// File type resource for use with the FREF below 
type kDrvrCreatorType
{
	pstring;
};


/**********************************************************************************
 *        						RESOURCES			 							 					 *
 *********************************************************************************/

resource gxRasterPrefsType (gxRasterPrefsID, sysHeap)
{
	gxDefaultRaster,	// default raster options are fine
	
	0x012C0000,	0x012C0000,	// 300X300 dpi device
	75,				// min band size (1/4")
	0,				// max band size (0 is full page)
	0x00008000,		// RAM percentage (50%)
	100*1024,		// RAM slop (100K)
	1,				// 1 bit device
	{
	// flags for this plane
	gxDefaultOffscreen,
	
	// halftone for this plane
	0x002D0000,		// angle = 45 degrees
	0x003C0000,		// freq = 60
	gxRoundDot,		// roundDot dithering
	gxLuminanceTint,// extract luminance and dither it
	
	gxRGBSpace, gxNoProfile, 0, 0, 0, 0, 					// dotColor == black
	gxRGBSpace, gxNoProfile, 0xFFFF, 0xFFFF, 0xFFFF, 0,	// background color == white
	
	gxRGBSpace,		// tint is in gxRGBSpace
	
	// color info about this plane
	gxNoSpace,
	gxNoSet,
	gxNoProfile
	};
};

resource kDrvrCreatorType (0, sysheap)
{
	kDriverName " Driver"
};

// Version of GX required  (1.1 because we use gxSetupPageImageData.)
resource 'vers' (gxPrintingDriverBaseID, purgeable) {
	0x01, 0x10, release, 0x00,
	verUS,
	"1.1",
	"1.1, Copyright \251 Apple Computer, Inc. 1989-1995"
};

// Normal 'vers' resources so we can tell what version we've got.


resource 'vers' (1, sysheap, purgeable) {
	0x01, 0x10, alpha, 0x04,
	verUS,
	"1.1a4",
	"1.1a4,  Apple Computer, Inc. 1989-1995"
};


resource 'vers' (2, sysheap, purgeable) {
	0x01, 0x10, alpha, 0x04,
	verUS,
	"1.1a4",
	"Sample Printer Driver"
};


// The BNDL resource references icons for both the driver file and desktop printer file 
// representations. 
resource 'BNDL' (kDriverIconID, purgeable, sysHeap) 
{
	kDrvrCreatorType,
	0,
	{ 
		'ICN#', { 0, kDTPIconID; 1, kDTPNotCurrentSharedID; 2, kDTPCurrentNotSharedID; 3, kDTPCurrentSharedID; 4, kDTPNotActiveID; 5, kDTPNoGXID; 6, kDTPPuzzleID},
		'FREF', { 0, kDTPIconID; 1, kDTPNotCurrentSharedID; 2, kDTPCurrentNotSharedID; 3, kDTPCurrentSharedID; 4, kDTPNotActiveID; 5, kDTPNoGXID; 6, kDTPPuzzleID; 0, kDriverIconID}
	}
};

// The FREF for the LaserWriter SC driver file 
resource 'FREF' (kDriverIconID, purgeable, sysHeap) { kDrvrFileType, 0, "" };

// The FREFs for the LaserWriter SC desktop printer file 
resource 'FREF' (kDTPIconID,					purgeable, sysHeap) { 'dpnn', 0, "" };
resource 'FREF' (kDTPNotCurrentSharedID,	purgeable, sysHeap) { 'dpns', 1, "" };
resource 'FREF' (kDTPCurrentNotSharedID,	purgeable, sysHeap) { 'dpcn', 2, "" };
resource 'FREF' (kDTPCurrentSharedID,		purgeable, sysHeap) { 'dpcs', 3, "" };
resource 'FREF' (kDTPNotActiveID,			purgeable, sysHeap) { 'dpna', 4, "" };
resource 'FREF' (kDTPNoGXID,					purgeable, sysHeap) { 'dvcf', 4, "" };
resource 'FREF' (kDTPPuzzleID,				purgeable, sysHeap) { 'dppz', 6, "" };

/************** LaserWriter SC Driver Icons **************/
/************** LaserWriter SC Desktop Printer Icons - notCurrent/notShared  representation **************/

data 'ICN#' (kDTPIconID, purgeable, sysheap) 
{
	$"1FFF FFF8 2249 2484 2249 2484 2249 2484"            /* ...."I$"I$"I$ */
	$"2249 2484 2249 2484 2249 2484 2249 2484"            /* "I$"I$"I$"I$ */
	$"2249 2484 2249 2484 2249 2484 2249 2484"            /* "I$"I$"I$"I$ */
	$"2249 2484 2249 2484 2249 2484 2249 2484"            /* "I$"I$"I$"I$ */
	$"2249 2484 2249 2484 22FF FF84 2280 0084"            /* "I$"I$"..". */
	$"2280 0084 2280 00B4 3FFF FFB4 2000 0084"            /* ".".?.. .. */
	$"2000 00B4 2000 00B4 2000 0084 2000 00B4"            /*  .. .. .. .. */
	$"1FFF FFB4 0200 0004 03FF FFF8 0000 0000"            /* ............... */
	$"1FFF FFF8 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ....?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"1FFF FFFC 03FF FFFC 03FF FFF8 0000 0000"            /* ................ */
};

resource 'icl8' (kDTPIconID, purgeable, sysheap) 
{
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ...+++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* .+..+..+..+++... */
	$"0000 FF2B 2B2B FDF9 FCFD FDFD FDFD FDFD"            /* ...+++.......... */
	$"FDFD FDFD FDFD FDFD FDF5 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2B2B FDF9 FDF5 F5F5 F5F5 F5F5"            /* ...+++.......... */
	$"F5F5 F5F5 F5F5 F5F5 FDF5 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2B2B FDF9 FDF5 2B2B 2B2B 2B2B"            /* ...+++....++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 2B2B 2BFF 0000"            /* ++++++++..+++... */
	$"0000 FF2B 2B2B FDF9 FDF5 2B2B 2B2B 2B2B"            /* ...+++....++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 2B2B 2BFF 0000"            /* ++++++++..+++... */
	$"0000 FFFC FCFC FCFC FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFC FCFC FDF5 E3E3 2BFF 0000"            /* ............+... */
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5F5 FDF5 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 2B2B 2BFF 0000"            /* ++++++++..+++... */
	$"0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 0505 2BFF 0000"            /* ++++++++....+... */
	$"0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 2B2B 2BFF 0000"            /* ++++++++..+++... */
	$"0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDF5 2B2B 2BFF 0000"            /* ++++++++..+++... */
	$"0000 00FF FFFF FDFD FDFD FDFD FDFD FDFD"            /* ................ */
	$"FDFD FDFD FDFD FDFD FCF5 D8D8 2BFF 0000"            /* ..........+... */
	$"0000 0000 0000 FF2B 2B2B 2B2B 2B2B 2B2B"            /* .......+++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF 0000"            /* +++++++++++++... */
	$"0000 0000 0000 FCFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (kDTPIconID, purgeable, sysheap) 
{
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"00FC CCED CDCC DCCD CCDC CDCC ECCC CF00"            /* ....... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED CD0C DCCD 0CDC CD0C ECCC CF00"            /* .......... */
	$"00FC CCED CDCC D0CD CCD0 CDCC E0CC CF00"            /* ..... */
	$"00FC CCED EEEE EEEE EEEE EEEE ECCC CF00"            /* ............. */
	$"00FC CCED E0C0 C0C0 C0C0 C0C0 E0CC CF00"            /* ...... */
	$"00FC CCED ECCC CCCC CCCC CCCC ECCC CF00"            /* ...... */
	$"00FC CCED E0CC CCCC CCCC CCCC E0CC CF00"            /* ...... */
	$"00FE EEEE EEEE EEEE EEEE EEEE EC88 CF00"            /* .............. */
	$"00F0 C0C0 C0C0 C0C0 C0C0 C0C0 E0CC CF00"            /* .... */
	$"00FC CCCC CCCC CCCC CCCC CCCC ECCC CF00"            /* .... */
	$"00FC CCCC CCCC CCCC CCCC CCCC E011 CF00"            /* ..... */
	$"00FC CCCC CCCC CCCC CCCC CCCC ECCC CF00"            /* .... */
	$"00FC CCCC CCCC CCCC CCCC CCCC E0CC CF00"            /* .... */
	$"000F FFEE EEEE EEEE EEEE EEEE EC33 CF00"            /* .............3. */
	$"0000 00FC CCCC CCCC CCCC CCCC CCCC CF00"            /* ..... */
	$"0000 00EF FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


data 'ics#' (kDTPIconID, purgeable, sysheap) 
{
	$"3FFC 4AA2 4AA2 4AA2 4AA2 4AA2 4AA2 4AA2"            /* ?.JJJJJJJ */
	$"4AA2 4AAA 7FE2 402A 4022 7FEA 1002 1FFC"            /* JJ..@*@"...... */
	$"3FFC 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE"            /* ?............... */
	$"7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 1FFE 1FFC"            /* ................ */
};


data 'ics4' (kDTPIconID, purgeable, sysheap) 
{
	$"00FF FFFF FFFF FF00 0FCC ECDC DCEC CCF0"            /* .............. */
	$"0FCC ECDC DCEC CCF0 0FCC ECDC DCEC CCF0"            /* ............ */
	$"0FCC ECDC DCEC CCF0 0FCC ECDC DCEC CCF0"            /* ............ */
	$"0FCC ECDC DCEC CCF0 0FCC ECDC DCEC CCF0"            /* ............ */
	$"0FCC ECDC DCEC CCF0 0FCC ECDC DCEC 8CF0"            /* ............ */
	$"0FEE EEEE EEEC CCF0 0FCC CCCC CCEC 1CF0"            /* ........... */
	$"0FCC CCCC CCEC CCF0 0EFE EEEE EEEC 3CF0"            /* .........<. */
	$"000F CCCC CCCC CCF0 000E FFFF FFFF FF00"            /* ........... */
};

data 'ics8' (kDTPIconID, purgeable, sysheap) 
{
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B 2B2B FF00"            /* ..++.+.+.+.+++.. */
	$"00FF 2B2B FC2B FA2B FA2B FC2B E32B FF00"            /* ..++.+.+.+.+.+.. */
	$"00FF FCFC FCFC FCFC FCFC FC2B 2B2B FF00"            /* ...........+++.. */
	$"00FF 2B2B 2B2B 2B2B 2B2B FC2B 052B FF00"            /* ..++++++++.+.+.. */
	$"00FF 2B2B 2B2B 2B2B 2B2B FC2B 2B2B FF00"            /* ..++++++++.+++.. */
	$"00FC FFFC FCFC FCFC FCFC FC2B D82B FF00"            /* ...........++.. */
	$"0000 00FF 2B2B 2B2B 2B2B 2B2B 2B2B FF00"            /* ....++++++++++.. */
	$"0000 00FC FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
};


/************** LaserWriter SC Desktop Printer Icons - Current/notShared  representation **************/

data 'ICN#' (kDTPCurrentNotSharedID, purgeable, sysheap) 
{
	$"7FFF FFFE FFFF FFFF FFFF FFFF E249 2487"            /* .............I$ */
	$"E249 2487 E249 2487 E249 2487 E249 2487"            /* .I$.I$.I$.I$ */
	$"E249 2487 E249 2487 E249 2487 E249 2487"            /* .I$.I$.I$.I$ */
	$"E249 2487 E249 2487 E249 2487 E249 2487"            /* .I$.I$.I$.I$ */
	$"E249 2487 E249 2487 E2FF FF87 E280 0087"            /* .I$.I$..... */
	$"E280 0087 FFFF FFB7 E000 0087 E000 0087"            /* ........... */
	$"E000 0087 E000 0087 E000 0087 FFFF FFB7"            /* ............ */
	$"FE00 0007 7FFF FFFF 0FFF FFFF 07FF FFFE"            /* ................ */
	$"7FFF FFFE FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF 7FFF FFFF 0FFF FFFF 07FF FFFE"            /* ................ */
};

data 'icl8' (kDTPCurrentNotSharedID, purgeable, sysheap) 
{
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 2BF9 002B F900 2BF9"            /* ...+++..+..+..+. */
	$"002B F900 2BF9 002B FC00 2B2B 2BFF FFFF"            /* .+..+..+..+++... */
	$"FFFF FF2B 2B2B FCF9 FCFC FCFC FCFC FCFC"            /* ...+++.......... */
	$"FCFC FCFC FCFC FCFC FC00 2B2B 2BFF FFFF"            /* ..........+++... */
	$"FFFF FF2B 2B2B FCF9 FC00 0000 0000 0000"            /* ...+++.......... */
	$"0000 0000 0000 0000 FC00 2B2B 2BFF FFFF"            /* ..........+++... */
	$"FFFF FF2B 2B2B FCF9 FC00 2B2B 2B2B 2B2B"            /* ...+++....++++++ */
	$"2B2B 2B2B 2B2B 2B2B FC00 2B2B 2BFF FFFF"            /* ++++++++..+++... */
	$"FFFF FFFC FCFC FCFC FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFC FCFC FC00 E3E3 2BFF FFFF"            /* ............+... */
	$"FFFF FF00 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FC00 2B2B 2BFF FFFF"            /* ..........+++... */
	$"FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FC00 2B2B 2BFF FFFF"            /* ++++++++..+++... */
	$"FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FC00 0505 2BFF FFFF"            /* ++++++++....+... */
	$"FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FC00 2B2B 2BFF FFFF"            /* ++++++++..+++... */
	$"FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ...+++++++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FC00 2B2B 2BFF FFFF"            /* ++++++++..+++... */
	$"FFFF FFFC FCFC FCFC FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFC FCFC FC00 D8D8 2BFF FFFF"            /* ..........+... */
	$"FFFF FFFF FFFF FF2B 2B2B 2B2B 2B2B 2B2B"            /* .......+++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF"            /* +++++++++++++... */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0000 0000 FFFF FCFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
};


data 'icl4' (kDTPCurrentNotSharedID, purgeable, sysheap) 
{
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED CD0C D0CD 0CD0 CD0C E0CC CFFF"            /* ........ */
	$"FFFC CCED EEEE EEEE EEEE EEEE E0CC CFFF"            /* ............. */
	$"FFFC CCED E000 0000 0000 0000 E0CC CFFF"            /* ............. */
	$"FFFC CCED E0CC CCCC CCCC CCCC E0CC CFFF"            /* ...... */
	$"FFFE EEEE EEEE EEEE EEEE EEEE E088 CFFF"            /* .............. */
	$"FFF0 0000 0000 0000 0000 0000 E0CC CFFF"            /* .............. */
	$"FFFC CCCC CCCC CCCC CCCC CCCC E0CC CFFF"            /* .... */
	$"FFFC CCCC CCCC CCCC CCCC CCCC E011 CFFF"            /* ..... */
	$"FFFC CCCC CCCC CCCC CCCC CCCC E0CC CFFF"            /* .... */
	$"FFFC CCCC CCCC CCCC CCCC CCCC E0CC CFFF"            /* .... */
	$"FFFE EEEE EEEE EEEE EEEE EEEE E033 CFFF"            /* .............3. */
	$"FFFF FFFC CCCC CCCC CCCC CCCC CCCC CFFF"            /* ..... */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0000 FFEF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
};


/************** LaserWriter SC Desktop Printer Icons - notCurrent/Shared  representation **************/

data 'ICN#' (kDTPNotCurrentSharedID, purgeable, sysheap) 
{
	$"07FF FFF0 0892 4908 0892 4908 0892 4908"            /* .....I..I..I. */
	$"0892 4908 0892 4908 0892 4908 0892 4908"            /* .I..I..I..I. */
	$"0892 4908 0892 4908 0892 4908 0892 4908"            /* .I..I..I..I. */
	$"0892 4908 08BF FF08 08A0 0108 08A0 0108"            /* .I.......... */
	$"08A0 0108 0FFF FF68 0800 0108 0800 0108"            /* ......h........ */
	$"0800 0108 0800 0108 0800 0108 07FF FF68"            /* ...............h */
	$"0080 0008 00FF FFF0 0000 03E0 0000 02A0"            /* .............. */
	$"BFFF FC9D 0000 0140 BFFF FE3D 0000 0000"            /* .....@..=.... */
	$"07FF FFF0 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* ................ */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* ................ */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* ................ */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* ................ */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* ................ */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 07FF FFF8"            /* ................ */
	$"00FF FFF8 00FF FFF0 0000 03E0 0000 03E0"            /* ................ */
	$"FFFF FFFF FFFF FF7F FFFF FE3F 0000 0000"            /* ...........?.... */
};

data 'icl8' (kDTPNotCurrentSharedID, purgeable, sysheap) 
{
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 2BFA F52B FAF5"            /* .....+++..+..+.. */
	$"2BFA F52B FAF5 2BFD F52B 2B2B FF00 0000"            /* +..+..+..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 FCFD FDFD FDFD"            /* .....+++........ */
	$"FDFD FDFD FDFD FDFD F52B 2B2B FF00 0000"            /* .........+++.... */
	$"0000 0000 FF2B 2B2B FDF9 FDF5 F5F5 F5F5"            /* .....+++........ */
	$"F5F5 F5F5 F5F5 F5FD F52B 2B2B FF00 0000"            /* .........+++.... */
	$"0000 0000 FF2B 2B2B FDF9 FDF5 2B2B 2B2B"            /* .....+++....++++ */
	$"2B2B 2B2B 2B2B 2BFD F52B 2B2B FF00 0000"            /* +++++++..+++.... */
	$"0000 0000 FF2B 2B2B FDF9 FDF5 2B2B 2B2B"            /* .....+++....++++ */
	$"2B2B 2B2B 2B2B 2BFD F52B 2B2B FF00 0000"            /* +++++++..+++.... */
	$"0000 0000 FFFC FCFC FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFC FCFD F5E3 E32B FF00 0000"            /* ...........+.... */
	$"0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5F5 F5FD F52B 2B2B FF00 0000"            /* .........+++.... */
	$"0000 0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2BFD F52B 2B2B FF00 0000"            /* +++++++..+++.... */
	$"0000 0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2BFD F505 052B FF00 0000"            /* +++++++....+.... */
	$"0000 0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2BFD F52B 2B2B FF00 0000"            /* +++++++..+++.... */
	$"0000 0000 FF2B 2B2B 2B2B 2B2B 2B2B 2B2B"            /* .....+++++++++++ */
	$"2B2B 2B2B 2B2B 2BFD F52B 2B2B FF00 0000"            /* +++++++..+++.... */
	$"0000 0000 00FF FFFF FDFD FDFD FDFD FDFD"            /* ................ */
	$"FDFD FDFD FDFD FDFC F5D8 D82B FF00 0000"            /* .........+.... */
	$"0000 0000 0000 0000 FF2B 2B2B 2B2B 2B2B"            /* .........+++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2B2B FF00 0000"            /* ++++++++++++.... */
	$"0000 0000 0000 0000 FCFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF2B FE2B FD00 0000 0000"            /* .......+.+...... */
	$"F6F6 F6F6 F7F7 F7F8 F8F8 F9F9 F9FA FAFA"            /* ................ */
	$"FBFB FBFC FCFC 2B2B FE2B 2BFD FDFC FCFC"            /* ......++.++..... */
	$"F5F5 F5F5 F5F5 F6F6 F6F6 F6F6 F62B 2B2B"            /* .............+++ */
	$"2B2B 2B2B 2B2B 2BFE 00FE 2B2B 2B2B 2B2B"            /* +++++++...++++++ */
	$"F7F7 F8F8 F8F9 F9F9 FAFA FAFB FBFB FCFC"            /* ................ */
	$"FCFD FDFD FEFE FE00 0000 FEFE FDFD FCFC"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


data 'icl4' (kDTPNotCurrentSharedID, purgeable, sysheap) 
{
	$"0000 0FFF FFFF FFFF FFFF FFFE FFFF 0000"            /* ................ */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDCD 0CD0 CD0C D0CE 0CCC F000"            /* ......... */
	$"0000 FCCC EDEE EEEE EEEE EEEE 0CCC F000"            /* .............. */
	$"0000 FCCC EDE0 0000 0000 000E 0CCC F000"            /* .............. */
	$"0000 FCCC EDE0 CCCC CCCC CCCE 0CCC F000"            /* ........ */
	$"0000 FCCC EDE0 CCCC CCCC CCCE 0CCC F000"            /* ........ */
	$"0000 FEEE EEEE EEEE EEEE EEEE 088C F000"            /* ............... */
	$"0000 F000 0000 0000 0000 000E 0CCC F000"            /* ............... */
	$"0000 FCCC CCCC CCCC CCCC CCCE 0CCC F000"            /* ...... */
	$"0000 FCCC CCCC CCCC CCCC CCCE 011C F000"            /* ....... */
	$"0000 FCCC CCCC CCCC CCCC CCCE 0CCC F000"            /* ...... */
	$"0000 FCCC CCCC CCCC CCCC CCCE 0CCC F000"            /* ...... */
	$"0000 0FFE EEEE EEEE EEEE EEEE 033C F000"            /* .............<.. */
	$"0000 0000 FCCC CCCC CCCC CCCC CCCC F000"            /* ....... */
	$"0000 0000 EFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FF FFF0 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FC FCE0 0000"            /* ................ */
	$"DDDD DDDD DDDE EEEE EEEE EECC FCCE EEEE"            /* .............. */
	$"CCCC CCCC CCCC CCCC CCCC CCCF 0FCC CCCC"            /* . */
	$"DDDD DDDD DDDE EEEE EEEE FFF0 00FE EEEE"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};


/************** LaserWriter SC Desktop Printer Icons - Current/Shared  representation **************/

data 'ICN#' (kDTPCurrentSharedID, purgeable, sysheap) 
{
	$"0FFF FFF0 1FFF FFF8 1FFF FFF8 1C49 2438"            /* .............I$8 */
	$"1C49 2438 1C49 2438 1C49 2438 1C49 2438"            /* .I$8.I$8.I$8.I$8 */
	$"1C49 2438 1C49 2438 1C49 2438 1C49 2438"            /* .I$8.I$8.I$8.I$8 */
	$"1C49 2438 1C5F FC38 1C50 0438 1C50 05B8"            /* .I$8._.8.P.8.P. */
	$"1C50 0438 1FFF FC38 1C00 0438 1C00 0438"            /* .P.8...8...8...8 */
	$"1C00 0438 1C00 05B8 1FFF FC38 0FFF FFF8"            /* ...8......8.... */
	$"03FF FFF0 007F FFC0 0000 0F80 0000 0A80"            /* ............. */
	$"BFFF F27D 0000 0500 BFFF F8FD 0000 0000"            /* ..}........... */
	$"0FFF FFF0 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 1FFF FFF8"            /* ................ */
	$"1FFF FFF8 1FFF FFF8 1FFF FFF8 0FFF FFF8"            /* ................ */
	$"03FF FFF0 007F FFC0 0000 0F80 0000 0F80"            /* ............. */
	$"FFFF FFFF FFFF FDFF FFFF F8FF 0000 0000"            /* ................ */
};

data 'icl8' (kDTPCurrentSharedID, purgeable, sysheap) 
{
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFFF FF00 0000"            /* .+..+..+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F9FC FDFD FDFD"            /* ......+++....... */
	$"FDFD FDFD FDFD F52B 2B2B FFFF FF00 0000"            /* .......+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F9FD F5F5 F5F5"            /* ......+++....... */
	$"F5F5 F5F5 F5FD F52B 2B2B FFFF FF00 0000"            /* .......+++...... */
	$"0000 00FF FFFF 2B2B 2BFD F9FD F52B 2B2B"            /* ......+++....+++ */
	$"2B2B 2B2B 2BFD F5E3 E32B FFFF FF00 0000"            /* +++++....+...... */
	$"0000 00FF FFFF 2B2B 2BFD F9FD F52B 2B2B"            /* ......+++....+++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFFF FF00 0000"            /* +++++..+++...... */
	$"0000 00FF FFFF FCFC FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFD F52B 2B2B FFFF FF00 0000"            /* .......+++...... */
	$"0000 00FF FFFF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5FD F505 052B FFFF FF00 0000"            /* .........+...... */
	$"0000 00FF FFFF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFFF FF00 0000"            /* +++++..+++...... */
	$"0000 00FF FFFF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFFF FF00 0000"            /* +++++..+++...... */
	$"0000 00FF FFFF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F5D8 D82B FFFF FF00 0000"            /* +++++..+...... */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF F52B 2B2B FFFF FF00 0000"            /* .......+++...... */
	$"0000 0000 FFFF FFFF FFFD FDFD FDFD FDFD"            /* ................ */
	$"FDFD FDFD FDFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 00FC FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 FF2B FE2B FD00 0000 0000 0000"            /* .....+.+........ */
	$"F6F6 F6F7 F7F8 F8F8 F9F9 F9FA FAFA FBFB"            /* ................ */
	$"FBFC FCFC 2B2B FE2B 2BFD FDFC FCFC FCFC"            /* ....++.++....... */
	$"F5F5 F5F5 F6F6 F6F6 F6F6 F62B 2B2B 2B2B"            /* ...........+++++ */
	$"2B2B 2B2B 2BFE 00FE 2B2B 2B2B 2B2B 2B2B"            /* +++++...++++++++ */
	$"F7F7 F8F9 F9F9 FAFA FAFB FBFB FCFC FCFD"            /* ................ */
	$"FDFD FEFE FE00 0000 FEFE FDFD FCFC FCFC"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (kDTPCurrentSharedID, purgeable, sysheap) 
{
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF F000"            /* ................ */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDC D0CD 0CD0 CE0C CCFF F000"            /* ......... */
	$"000F FFCC CEDE EEEE EEEE EE0C CCFF F000"            /* ............. */
	$"000F FFCC CEDE 0000 0000 0E0C CCFF F000"            /* ............. */
	$"000F FFCC CEDE 0CCC CCCC CE08 8CFF F000"            /* ......... */
	$"000F FFCC CEDE 0CCC CCCC CE0C CCFF F000"            /* ......... */
	$"000F FFEE EEEE EEEE EEEE EE0C CCFF F000"            /* ............... */
	$"000F FF00 0000 0000 0000 0E01 1CFF F000"            /* ................ */
	$"000F FFCC CCCC CCCC CCCC CE0C CCFF F000"            /* ....... */
	$"000F FFCC CCCC CCCC CCCC CE0C CCFF F000"            /* ....... */
	$"000F FFCC CCCC CCCC CCCC CE03 3CFF F000"            /* ....<... */
	$"000F FFFF FFFF FFFF FFFF FE0C CCFF F000"            /* ............... */
	$"0000 FFFE EEEE EEEE EEEE EFFF FFFF F000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 0000 0EFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 FFFF F000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 FCFC E000 0000"            /* ................ */
	$"DDDD DDDD DEEE EEEE EEEE CCFC CEEE EEEE"            /* .............. */
	$"CCCC CCCC CCCC CCCC CCCC CF0F CCCC CCCC"            /* . */
	$"DDDD DDDD DEEE EEEE EEEF F000 FEEE EEEE"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

/************** LaserWriter SC Desktop Printer Icons - Not Active  representation **************/

data 'ICN#' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"6FFF FFF6 F249 248F FA49 249F 7E49 24BE"            /* o....I$.I$~I$ */
	$"3E49 24FC 3F49 24FC 2FC9 25F4 27C9 27E4"            /* >I$.?I$./%.''. */
	$"23E9 27C4 23F9 2F84 22F9 3F84 227D 3E84"            /* #.'#./".?"}> */
	$"227F 7C84 225F FC84 224F F484 224F E484"            /* ".|"_."O."O. */
	$"224F E484 224F F484 22FF FF84 22BE 7C84"            /* "O."O.".."| */
	$"22FC 3E84 22F8 1FB4 3FFF FFB4 23E0 07C4"            /* ".>"..?..#.. */
	$"27C0 03F4 2F80 01F4 3F00 00FC 3E00 00FC"            /* '../..?...>... */
	$"7FFF FFBE FA00 001F F3FF FFFF 6000 0006"            /* ...........`... */
	$"6FFF FFF6 FFFF FFFF FFFF FFFF 7FFF FFFE"            /* o............... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"3FFF FFFC 3FFF FFFC 3FFF FFFC 3FFF FFFC"            /* ?...?...?...?... */
	$"7FFF FFFE FBFF FFFF F3FF FFFF 6000 0006"            /* ............`... */
};

data 'icl8' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"00FF FF00 FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 00FF FF00"            /* ................ */
	$"FFFF FFFF 2B2B FDF9 2BFA F52B FAF5 2BFA"            /* ....++..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2B2B FFFF FFFF"            /* .+..+..+..++.... */
	$"FFFF FFFF FF2B FDF9 2BFA F52B FAF5 2BFA"            /* .....+..+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 2BFF FFFF FFFF"            /* .+..+..+..+..... */
	$"00FF FFFF FFFF FDF9 2BFA F52B FAF5 2BFA"            /* ........+..+..+. */
	$"F52B FAF5 2BFA F52B FDF5 FFFF FFFF FF00"            /* .+..+..+........ */
	$"0000 FFFF FFFF FFF9 2BFA F52B FAF5 2BFA"            /* ........+..+..+. */
	$"F52B FAF5 2BFA F52B FDFF FFFF FFFF 0000"            /* .+..+..+........ */
	$"0000 FFFF FFFF FFFF 2BFA F52B FAF5 2BFA"            /* ........+..+..+. */
	$"F52B FAF5 2BFA F52B FFFF FFFF FFFF 0000"            /* .+..+..+........ */
	$"0000 FF2B FFFF FFFF FFFA F52B FAF5 2BFA"            /* ...+.......+..+. */
	$"F52B FAF5 2BFA F5FF FFFF FFFF 2BFF 0000"            /* .+..+.......+... */
	$"0000 FF2B 2BFF FFFF FFFF F52B FAF5 2BFA"            /* ...++......+..+. */
	$"F52B FAF5 2BFA FFFF FFFF FF2B 2BFF 0000"            /* .+..+......++... */
	$"0000 FF2B 2B2B FFFF FFFF FF2B FAF5 2BFA"            /* ...+++.....+..+. */
	$"F52B FAF5 2BFF FFFF FFFF 2B2B 2BFF 0000"            /* .+..+.....+++... */
	$"0000 FF2B 2B2B FDFF FFFF FFFF FAF5 2BFA"            /* ...+++........+. */
	$"F52B FAF5 FFFF FFFF FFF5 2B2B 2BFF 0000"            /* .+........+++... */
	$"0000 FF2B 2B2B FDF9 FFFF FFFF FFF5 2BFA"            /* ...+++........+. */
	$"F52B FAFF FFFF FFFF FDF5 2B2B 2BFF 0000"            /* .+........+++... */
	$"0000 FF2B 2B2B FDF9 2BFF FFFF FFFF 2BFA"            /* ...+++..+.....+. */
	$"F52B FFFF FFFF FF2B FDF5 2B2B 2BFF 0000"            /* .+.....+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA FFFF FFFF FFFA"            /* ...+++..+....... */
	$"F5FF FFFF FFFF F52B FDF5 2B2B 2BFF 0000"            /* .......+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F5FF FFFF FFFF"            /* ...+++..+....... */
	$"FFFF FFFF FFFA F52B FDF5 2B2B 2BFF 0000"            /* .......+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FFFF FFFF"            /* ...+++..+..+.... */
	$"FFFF FFFF 2BFA F52B FDF5 2B2B 2BFF 0000"            /* ....+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAFF FFFF"            /* ...+++..+..+.... */
	$"FFFF FFF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* ....+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FAFF FFFF"            /* ...+++..+..+.... */
	$"FFFF FFF5 2BFA F52B FDF5 2B2B 2BFF 0000"            /* ....+..+..+++... */
	$"0000 FF2B 2B2B FDF9 2BFA F52B FFFF FFFF"            /* ...+++..+..+.... */
	$"FFFF FFFF 2BFA F52B FDF5 2B2B 2BFF 0000"            /* ....+..+..+++... */
	$"0000 FF2B 2B2B FDF9 FCFD FDFF FFFF FFFF"            /* ...+++.......... */
	$"FFFF FFFF FFFD FDFD FDF5 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2B2B FDF9 FDF5 FFFF FFFF FFF5"            /* ...+++.......... */
	$"F5FF FFFF FFFF F5F5 FDF5 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2B2B FDF9 FDFF FFFF FFFF 2B2B"            /* ...+++........++ */
	$"2B2B FFFF FFFF FF2B FDF5 2B2B 2BFF 0000"            /* ++.....+..+++... */
	$"0000 FF2B 2B2B FDF9 FFFF FFFF FF2B 2B2B"            /* ...+++.......+++ */
	$"2B2B 2BFF FFFF FFFF FDF5 2B2B 2BFF 0000"            /* +++.......+++... */
	$"0000 FFFC FCFC FCFF FFFF FFFF FCFC FCFC"            /* ................ */
	$"FCFC FCFC FFFF FFFF FFF5 E3E3 2BFF 0000"            /* ............+... */
	$"0000 FFF5 F5F5 FFFF FFFF FFF5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5FF FFFF FFFF 2B2B 2BFF 0000"            /* ..........+++... */
	$"0000 FF2B 2BFF FFFF FFFF 2B2B 2B2B 2B2B"            /* ...++.....++++++ */
	$"2B2B 2B2B 2B2B FFFF FFFF FF2B 2BFF 0000"            /* ++++++.....++... */
	$"0000 FF2B FFFF FFFF FF2B 2B2B 2B2B 2B2B"            /* ...+.....+++++++ */
	$"2B2B 2B2B 2B2B 2BFF FFFF FFFF 2BFF 0000"            /* +++++++.....+... */
	$"0000 FFFF FFFF FFFF 2B2B 2B2B 2B2B 2B2B"            /* ........++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FFFF FFFF FFFF 0000"            /* ++++++++........ */
	$"0000 FFFF FFFF FF2B 2B2B 2B2B 2B2B 2B2B"            /* .......+++++++++ */
	$"2B2B 2B2B 2B2B 2B2B FDFF FFFF FFFF 0000"            /* ++++++++........ */
	$"00FF FFFF FFFF FDFD FDFD FDFD FDFD FDFD"            /* ................ */
	$"FDFD FDFD FDFD FDFD FCF5 FFFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FF00 FF2B 2B2B 2B2B 2B2B 2B2B"            /* .......+++++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FFFF FFFF"            /* +++++++++++..... */
	$"FFFF FFFF 0000 FCFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"00FF FF00 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 00FF FF00"            /* ................ */
};

data 'icl4' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"0FF0 FFFF FFFF FFFF FFFF FFFF FFFF 0FF0"            /* ................ */
	$"FFFF CCED CDCC DCCD CCDC CDCC ECCC FFFF"            /* ........ */
	$"FFFF FCED CD0C DCCD 0CDC CD0C ECCF FFFF"            /* ............ */
	$"0FFF FFED CDCC D0CD CCD0 CDCC E0FF FFF0"            /* ........ */
	$"00FF FFFD CD0C DCCD 0CDC CD0C EFFF FF00"            /* ............. */
	$"00FF FFFF CDCC D0CD CCD0 CDCC FFFF FF00"            /* ........ */
	$"00FC FFFF FD0C DCCD 0CDC CD0F FFFF CF00"            /* ............. */
	$"00FC CFFF FFCC D0CD CCD0 CDFF FFFC CF00"            /* ........ */
	$"00FC CCFF FFFC DCCD 0CDC CFFF FFCC CF00"            /* ........... */
	$"00FC CCEF FFFF D0CD CCD0 FFFF F0CC CF00"            /* ......... */
	$"00FC CCED FFFF FCCD 0CDF FFFF ECCC CF00"            /* ............ */
	$"00FC CCED CFFF FFCD CCFF FFFC E0CC CF00"            /* .......... */
	$"00FC CCED CDFF FFFD 0FFF FF0C ECCC CF00"            /* ............ */
	$"00FC CCED CDCF FFFF FFFF FDCC E0CC CF00"            /* .......... */
	$"00FC CCED CD0C FFFF FFFF CD0C ECCC CF00"            /* ........... */
	$"00FC CCED CDCC DFFF FFF0 CDCC E0CC CF00"            /* ......... */
	$"00FC CCED CD0C DFFF FFFC CD0C ECCC CF00"            /* ........... */
	$"00FC CCED CDCC FFFF FFFF CDCC E0CC CF00"            /* ......... */
	$"00FC CCED EEEF FFFF FFFF FEEE ECCC CF00"            /* ............. */
	$"00FC CCED E0FF FFF0 CFFF FFC0 E0CC CF00"            /* ........... */
	$"00FC CCED EFFF FFCC CCFF FFFC ECCC CF00"            /* ........... */
	$"00FC CCED FFFF FCCC CCCF FFFF E0CC CF00"            /* .......... */
	$"00FE EEEF FFFF EEEE EEEE FFFF FC88 CF00"            /* .............. */
	$"00F0 C0FF FFF0 C0C0 C0C0 CFFF FFCC CF00"            /* ........ */
	$"00FC CFFF FFCC CCCC CCCC CCFF FFFC CF00"            /* ........ */
	$"00FC FFFF FCCC CCCC CCCC CCCF FFFF CF00"            /* ........ */
	$"00FF FFFF CCCC CCCC CCCC CCCC FFFF FF00"            /* ........ */
	$"00FF FFFC CCCC CCCC CCCC CCCC EFFF FF00"            /* ........ */
	$"0FFF FFEE EEEE EEEE EEEE EEEE ECFF FFF0"            /* ................ */
	$"FFFF F0FC CCCC CCCC CCCC CCCC CCCF FFFF"            /* ...... */
	$"FFFF 00EF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0FF0 0000 0000 0000 0000 0000 0000 0FF0"            /* ................ */
};

data 'ics#' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"5FFA EAA7 7AAE 7ABE 5EBA 4EF2 4FE2 4BE2"            /* _..zz^N.O.K. */
	$"4BE2 4FEA 7FF2 5C3A 783E 7FEE F007 5FFA"            /* K.O...\:x>...._. */
	$"5FFA FFFF 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE"            /* _............... */
	$"7FFE 7FFE 7FFE 7FFE 7FFE 7FFE FFFF 5FFA"            /* .............._. */
};

data 'ics8' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"00FF 00FF FFFF FFFF FFFF FFFF FF00 FF00"            /* ................ */
	$"FFFF FF2B FC2B FA2B FA2B FC2B 2BFF FFFF"            /* ...+.+.+.+.++... */
	$"00FF FFFF FC2B FA2B FA2B FC2B FFFF FF00"            /* .....+.+.+.+.... */
	$"00FF FFFF FF2B FA2B FA2B FCFF FFFF FF00"            /* .....+.+.+...... */
	$"00FF 2BFF FFFF FA2B FA2B FFFF FF2B FF00"            /* ..+....+.+...+.. */
	$"00FF 2B2B FFFF FF2B FAFF FFFF 2B2B FF00"            /* ..++...+....++.. */
	$"00FF 2B2B FCFF FFFF FFFF FF2B 2B2B FF00"            /* ..++.......+++.. */
	$"00FF 2B2B FC2B FFFF FFFF FC2B 2B2B FF00"            /* ..++.+.....+++.. */
	$"00FF 2B2B FC2B FFFF FFFF FC2B 2B2B FF00"            /* ..++.+.....+++.. */
	$"00FF 2B2B FCFF FFFF FFFF FF2B E32B FF00"            /* ..++.......+.+.. */
	$"00FF FCFC FFFF FFFC FCFF FFFF 2B2B FF00"            /* ............++.. */
	$"00FF 2BFF FFFF 2B2B 2B2B FFFF FF2B FF00"            /* ..+...++++...+.. */
	$"00FF FFFF FF2B 2B2B 2B2B FCFF FFFF FF00"            /* .....+++++...... */
	$"00FF FFFF FCFC FCFC FCFC FC2B FFFF FF00"            /* ...........+.... */
	$"FFFF FFFF 2B2B 2B2B 2B2B 2B2B 2BFF FFFF"            /* ....+++++++++... */
	$"00FF 00FC FFFF FFFF FFFF FFFF FF00 FF00"            /* ................ */
};

data 'ics4' (kDTPNotActiveID, purgeable, sysheap) 
{
	$"0F0F FFFF FFFF F0F0 FFFC ECDC DCEC CFFF"            /* ............... */
	$"0FFF ECDC DCEC FFF0 0FFF FCDC DCEF FFF0"            /* ................ */
	$"0FCF FFDC DCFF FCF0 0FCC FFFC DFFF CCF0"            /* ............. */
	$"0FCC EFFF FFFC CCF0 0FCC ECFF FFEC CCF0"            /* ............ */
	$"0FCC ECFF FFEC CCF0 0FCC EFFF FFFC 8CF0"            /* ............ */
	$"0FEE FFFE EFFF CCF0 0FCF FFCC CCFF FCF0"            /* ............ */
	$"0FFF FCCC CCEF FFF0 0FFF EEEE EEEC FFF0"            /* .............. */
	$"FFFF CCCC CCCC CFFF 0F0E FFFF FFFF F0F0"            /* ........... */
};

/************** LaserWriter SC Desktop Printer Icons - Puzzle representation **************/

data 'ICN#' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"00FF FC00 0100 0200 0080 0400 7F80 07FE"            /* .............. */
	$"8000 0001 83FF FFC1 8449 2421 8449 2421"            /* .....I$!I$! */
	$"8449 2421 8449 2421 8449 2421 8449 2421"            /* I$!I$!I$!I$! */
	$"8449 2421 8449 2421 845F FC21 8450 0421"            /* I$!I$!_.!P.! */
	$"8450 0421 8450 0421 87FF FDA1 8400 0421"            /* P.!P.!....! */
	$"8400 0421 8400 05A1 8400 0421 8400 0421"            /* ..!....!..! */
	$"83FF FDA1 8040 0021 807F FFC1 8000 0001"            /* ..@.!..... */
	$"80FF FE01 8080 0201 8040 0401 7FE0 0FFE"            /* .....@...... */
	$"00FF FC00 01FF FE00 00FF FC00 7FFF FFFE"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FF80 03FF FFC0 07FF 7FE0 0FFE"            /* .............. */
};

data 'icl8' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"0000 0000 0000 0000 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF00 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 FF00 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6FF 0000 0000 0000 0000 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF FF00 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6FF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"FF00 0000 0000 0000 00F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F600 0000 0000 0000 00FF"            /* ................ */
	$"FF00 F6F6 F6F6 FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F92B FAF5 2BFA"            /* ......+++..+..+. */
	$"F52B FAF5 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* .+..+..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F9FC FDFD FDFD"            /* ......+++....... */
	$"FDFD FDFD FDFD F52B 2B2B FFF6 F6F6 F6FF"            /* .......+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F9FD F5F5 F5F5"            /* ......+++....... */
	$"F5F5 F5F5 F5FD F52B 2B2B FFF6 F6F6 F6FF"            /* .......+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F9FD F52B 2B2B"            /* ......+++....+++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* +++++..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2BFD F9FD F52B 2B2B"            /* ......+++....+++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* +++++..+++...... */
	$"FF00 F6F6 F6FF FCFF FCFC FCFC FCFC FCFC"            /* ................ */
	$"FCFC FCFC FCFD F5E3 E32B FFF6 F6F6 F6FF"            /* .........+...... */
	$"FF00 F6F6 F6FF F5F5 F5F5 F5F5 F5F5 F5F5"            /* ................ */
	$"F5F5 F5F5 F5FD F52B 2B2B FFF6 F6F6 F6FF"            /* .......+++...... */
	$"FF00 F6F6 F6FF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* +++++..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F505 052B FFF6 F6F6 F6FF"            /* +++++....+...... */
	$"FF00 F6F6 F6FF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* +++++..+++...... */
	$"FF00 F6F6 F6FF 2B2B 2B2B 2B2B 2B2B 2B2B"            /* ......++++++++++ */
	$"2B2B 2B2B 2BFD F52B 2B2B FFF6 F6F6 F6FF"            /* +++++..+++...... */
	$"FF00 F6F6 F6F6 FFFF FFFD FDFD FDFD FDFD"            /* ................ */
	$"FDFD FDFD FDFC F5D8 D82B FFF6 F6F6 F6FF"            /* .......+...... */
	$"FF00 F6F6 F6F6 F6F6 F6FF 2B2B 2B2B 2B2B"            /* ..........++++++ */
	$"2B2B 2B2B 2B2B 2B2B 2B2B FFF6 F6F6 F6FF"            /* ++++++++++...... */
	$"FF00 F6F6 F6F6 F6F6 F6FC FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6"            /* ................ */
	$"F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFF6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF00 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FF00 F6F6 F6F6 F6F6 F6FF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
};

data 'icl4' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"0000 0000 FFFF FFFF FFFF FF00 0000 0000"            /* ................ */
	$"0000 000F 0000 0000 0000 00F0 0000 0000"            /* ................ */
	$"0000 0000 F0C0 C0C0 C0C0 CF00 0000 0000"            /* .......... */
	$"0FFF FFFF 000C 0C0C 0C0C 0CFF FFFF FFF0"            /* ................ */
	$"F000 0000 00C0 C0C0 C0C0 C0C0 0000 000F"            /* ......... */
	$"F00C 0CFF FFFF FFFF FFFF FFFF FF0C 0C0F"            /* ................ */
	$"F0C0 CFCC CEDC D0CD 0CD0 CE0C CCF0 C0CF"            /* ..... */
	$"F00C 0FCC CEDC D0CD 0CD0 CE0C CCFC 0C0F"            /* ......... */
	$"F0C0 CFCC CEDC D0CD 0CD0 CE0C CCF0 C0CF"            /* ..... */
	$"F00C 0FCC CEDC D0CD 0CD0 CE0C CCFC 0C0F"            /* ......... */
	$"F0C0 CFCC CEDC D0CD 0CD0 CE0C CCF0 C0CF"            /* ..... */
	$"F00C 0FCC CEDC D0CD 0CD0 CE0C CCFC 0C0F"            /* ......... */
	$"F0C0 CFCC CEDC D0CD 0CD0 CE0C CCF0 C0CF"            /* ..... */
	$"F00C 0FCC CEDC D0CD 0CD0 CE0C CCFC 0C0F"            /* ......... */
	$"F0C0 CFCC CEDE EEEE EEEE EE0C CCF0 C0CF"            /* ......... */
	$"F00C 0FCC CEDE 0000 0000 0E0C CCFC 0C0F"            /* ............. */
	$"F0C0 CFCC CEDE 0CCC CCCC CE0C CCF0 C0CF"            /* ..... */
	$"F00C 0FCC CEDE 0CCC CCCC CE0C CCFC 0C0F"            /* ......... */
	$"F0C0 CFEF EEEE EEEE EEEE EE08 8CF0 C0CF"            /* ........... */
	$"F00C 0F00 0000 0000 0000 0E0C CCFC 0C0F"            /* ............... */
	$"F0C0 CFCC CCCC CCCC CCCC CE0C CCF0 C0CF"            /* ... */
	$"F00C 0FCC CCCC CCCC CCCC CE01 1CFC 0C0F"            /* ........ */
	$"F0C0 CFCC CCCC CCCC CCCC CE0C CCF0 C0CF"            /* ... */
	$"F00C 0FCC CCCC CCCC CCCC CE0C CCFC 0C0F"            /* ....... */
	$"F0C0 C0FF FEEE EEEE EEEE EE03 3CF0 C0CF"            /* ..........<. */
	$"F00C 0C0C 0FCC CCCC CCCC CCCC CCFC 0C0F"            /* ........ */
	$"F0C0 C0C0 CEFF FFFF FFFF FFFF FFC0 C0CF"            /* ......... */
	$"F00C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 FFFF FFFF FFFF FFF0 C0C0 C0CF"            /* ......... */
	$"F00C 0C0C F000 0000 0000 00F0 0C0C 0C0F"            /* ................ */
	$"F0C0 C0C0 CF00 0000 0000 0F00 C0C0 C0CF"            /* ........ */
	$"0FFF FFFF FFF0 0000 0000 FFFF FFFF FFF0"            /* ................ */
};

data 'ics#' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"0FF0 781E 8001 9FF9 AB65 AB65 AB65 AFE5"            /* ..x...eee. */
	$"AC25 BFED A02D A02D 9FF9 8001 8FF1 7C3E"            /* %.--...|> */
	$"0FF0 7FFE FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 7C3E"            /* ..............|> */
};

data 'ics8' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"0000 0000 FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"00FF FFFF FFF6 F6F6 F6F6 F6FF FFFF FF00"            /* ................ */
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FFF6 F6FF FFFF FFFF FFFF FFFF FFF6 F6FF"            /* ................ */
	$"FFF6 FF2B FDF9 FAFA F5FA FDF5 2BFF F6FF"            /* ...+........+... */
	$"FFF6 FF2B FDF9 FAFA F5FA FDF5 2BFF F6FF"            /* ...+........+... */
	$"FFF6 FF2B FDF9 FAFA F5FA FDF5 2BFF F6FF"            /* ...+........+... */
	$"FFF6 FF2B FDFD FDFD FDFD FDF5 2BFF F6FF"            /* ...+........+... */
	$"FFF6 FF2B FDFD F52B 2B2B FDF5 2BFF F6FF"            /* ...+...+++..+... */
	$"FFF6 FFFF FCFC FCFC FCFC FDF5 E3FF F6FF"            /* ................ */
	$"FFF6 FF2B 2B2B 2B2B 2B2B FDF5 05FF F6FF"            /* ...+++++++...... */
	$"FFF6 FF2B 2B2B 2B2B 2B2B FDF5 D8FF F6FF"            /* ...+++++++..... */
	$"FFF6 F6FF FFFD FDFD FDFD FDFD FDF6 F6FF"            /* ................ */
	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F6 F6FF"            /* ................ */
	$"FFF6 F6F6 FFFF FFFF FFFF FFFF F6F6 F6FF"            /* ................ */
	$"00FF FFFF FFFF 0000 0000 FFFF FFFF FF00"            /* ................ */
};

data 'ics4' (kDTPPuzzleID, purgeable, sysheap) 
{
	$"0000 FFFF FFFF 0000 0FFF FCCC CCCF FFF0"            /* ............. */
	$"FCCC CCCC CCCC CCCF FCCF FFFF FFFF FCCF"            /* ....... */
	$"FCFC FDDD 0DF0 CFCF FCFC FDDD 0DF0 CFCF"            /* .......... */
	$"FCFC FDDD 0DF0 CFCF FCFC FFFF FFF0 CFCF"            /* ........... */
	$"FCFC FF0C CCF0 CFCF FCFF EEEE EEF0 8FCF"            /* ........... */
	$"FCFC CCCC CCF0 1FCF FCFC CCCC CCF0 3FCF"            /* .......? */
	$"FCCF FFFF FFFF FCCF FCCC CCCC CCCC CCCF"            /* ....... */
	$"FCCC FFFF FFFF CCCF 0FFF FF00 00FF FFF0"            /* ............. */
};
