#==============================================================================================
#
#	Make FILE:		LaserWriterIISC.make
#
#	VERSION:			1.0
#
#	COPYRIGHT:		(c) 1992-1994 Apple Computer Inc.
#						All rights reserved.
#
#	PURPOSE:			This file contains the build commands for the LaserWriterIISC driver.
#
#  8/28/94 - dmh - Finalized for SDK.
# 12/18/93 - dmh - Updated for the b3 seed.
#	9/13/93 - dmh - Updated for the b2 seed.
#	4/26/93 - dmh - Made makefile totally self-supporting for b1 seed.
#	4/26/93 - dh  - Made makefile totally self-supporting for f1 seed.
#
#==============================================================================================

#======= Point this variable to your GX libraries directory =======

GXLibrariesSources	=	{MPW}'Graphics Libraries:'


#========== Directories Containing Source and Object Files ==========

Objects					=	:Objects:
Sources					=	

#========== Compiler Options ==========

AsmOptions				=	-case obj
RezOptions				=	-rd -d SystemSevenOrLater -i {RIncludes}
COptions					=	-b2 -d SystemSevenOrLater -d applec -i {CIncludes}
DriverLinkOptions		=	-ra =resSysHeap,resPurgeable

#========== Printing Manager Dependent Header Files ==========

PrintManagerHeaderFiles	=	{CIncludes}"PrintingManager.h"			
									{CIncludes}"PrintingMessages.h"			
									{CIncludes}"PrintingDrivers.h"			
									{CIncludes}"PrintingExtensions.h"		
									{CIncludes}"Collections.h"					
									{CIncludes}"Messages.h"						
									{CIncludes}"PrintingResTypes.h"			
									{CIncludes}"PrintingErrors.h"

GraphicsHeaderFiles		=	{CIncludes}"graphics routines.h"		
									{CIncludes}"graphics libraries.h"	
									{CIncludes}"math routines.h"			

#========== Files to Link into OldAPI Segment ==========

OldAPISegObjs	=	"{Objects}OldAPIMsgJumpTable.a.o"		
						"{Objects}OldAPIMessageIntf.c.o"			
						"{Libraries}Runtime.o"


#========== Files to Link into Universal Message Segment ==========

UnivSegObjs		=	"{Objects}UniversalMsgJumpTable.a.o"	
						"{Objects}LaserSCIntf.c.o"					
						"{Objects}SCPrinterStatus.c.o"			
						"{Objects}UniversalMessageIntf.c.o"		
						"{Objects}qd library.c.o"					
						"{Objects}color library.c.o"				
						"{CLibraries}StdCLib.o"						
						"{Libraries}Runtime.o"


#========== Files to Link into the Chooser PACK ==========

ChooserPackObjs =	"{Objects}ChooserSupport.a.o"				
						"{Objects}ChooserSupport.c.o"


#========== Files to Link into the Chooser LDEF ==========

ChooserLDEFObjs =	"{Objects}ChooserSupport.c.o"				


#========== Link and Rez Build Statements ==========

"LaserWriterIISC"				{OldAPISegObjs} 								
									{UnivSegObjs}									
									{ChooserPackObjs}								
									{ChooserLDEFObjs}								
									"{Sources}LaserWriterIISC.make"			
									"{Sources}LaserSCResources.r"				
									"{Sources}OldAPIResources.r"				
									"{Sources}UniversalMessageResources.r"		
		Echo "Linking LaserWriterIISC"
		Link {UnivSegObjs}									
			  {DriverLinkOptions}							
			  -rt pdvr=0										
			  -sg "LaserWriterIISC"							
			  -m SD_UniversalMsgJumpTable					
			  -o "{Objects}LWSC_UnivSeg" 
		Link {OldAPISegObjs}									
			  {DriverLinkOptions}							
			  -rt pdvr=1										
			  -sg "LaserWriterIISC"							
			  -m SD_OldAPIMsgJumpTable						
			  -o "{Objects}LWSC_OldAPISeg" 
		Link	{ChooserPackObjs}								
				-rt PACK=-4096									
				-sg PrintingPACK								
				-m EntryPoint									
				-o "{Objects}LWSC_PACK"
		Link	{ChooserLDEFObjs}								
				-w													
				-rt LDEF=-4096									
				-sg LDEF											
				-m LDEF											
				-o "{Objects}LWSC_LDEF"
		Echo "Rezzing LaserWriterIISC Driver"
		Rez	{RezOptions} -c 'scSC' -t 'pdvr' -ov -s {Objects}					
				-o "LaserWriterIISC" "{Sources}LaserSCResources.r" "{Sources}OldAPIResources.r"	
				"{Sources}UniversalMessageResources.r" "{Sources}ChooserSupport.r" -append


#========== Assemble Build Statements - OldAPIMsgJumpTable.a ==========

"{Objects}OldAPIMsgJumpTable.a.o"	 	"{Sources}OldAPIMsgJumpTable.a"		
													"{Sources}LaserWriterIISC.make"
	Echo "Assembling OldAPIMsgJumpTable.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}OldAPIMsgJumpTable.a -o {Objects}OldAPIMsgJumpTable.a.o
	

#========== Assemble Build Statements - UniversalMsgJumpTable.a ==========

"{Objects}UniversalMsgJumpTable.a.o"	 	"{Sources}UniversalMsgJumpTable.a"		
														"{Sources}LaserWriterIISC.make"
	Echo "Assembling UniversalMsgJumpTable.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}UniversalMsgJumpTable.a -o {Objects}UniversalMsgJumpTable.a.o
	

#========== Assemble Build Statements - ChooserSupport.a ==========

"{Objects}ChooserSupport.a.o"	 	"{Sources}ChooserSupport.a"		
											"{Sources}LaserWriterIISC.make"
	Echo "Assembling ChooserSupport.a"
	Asm {AsmOptions} {MakeJumpTable} {Sources}ChooserSupport.a -o {Objects}ChooserSupport.a.o
	

#========== Compile Build Statements - LaserSCIntf.c ==========

"{Objects}qd library.c.o"		 {GXLibrariesSources}"qd library.c"
	Echo "compiling qd library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"qd library.c"

"{Objects}color library.c.o"		 {GXLibrariesSources}"color library.c"
	Echo "compiling color library.c"
	C {COptions} -o {Objects} {GXLibrariesSources}"color library.c"

"{Objects}LaserSCIntf.c.o"		"{Sources}LaserSCIntf.c"			
										{PrintManagerHeaderFiles}			
										{GraphicsHeaderFiles}				
										"{Sources}LaserWriterIISC.make"	
										"{Sources}LaserSCResources.h" 	
										"{Sources}LaserSCIntf.h"
	Echo "Compiling LaserSCIntf.c"
	C "{Sources}LaserSCIntf.c" -o "{Objects}LaserSCIntf.c.o"  {COptions}


#========== Compile Build Statements - OldAPIMessageIntf.c ==========

"{Objects}OldAPIMessageIntf.c.o"		"{Sources}OldAPIMessageIntf.c"	
												{PrintManagerHeaderFiles}			
												{GraphicsHeaderFiles}				
												"{Sources}LaserWriterIISC.make"	
												"{Sources}LaserSCResources.h" 	
												"{Sources}OldAPIMessageIntf.h"
	Echo "Compiling OldAPIMessageIntf.c"
	C "{Sources}OldAPIMessageIntf.c" -o "{Objects}OldAPIMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - SCPrinterStatus.c ==========

"{Objects}SCPrinterStatus.c.o"		"{Sources}SCPrinterStatus.c"		
												{PrintManagerHeaderFiles}			
												{GraphicsHeaderFiles}				
												"{Sources}LaserWriterIISC.make"	
												"{Sources}LaserSCResources.h" 	
												"{Sources}LaserSCIntf.h"			
												"{Sources}SCPrinterStatus.h"
	Echo "Compiling SCPrinterStatus.c"
	C "{Sources}SCPrinterStatus.c" -o "{Objects}SCPrinterStatus.c.o"  {COptions}


#========== Compile Build Statements - UniversalMessageIntf.c ==========

"{Objects}UniversalMessageIntf.c.o"		"{Sources}UniversalMessageIntf.c"		
													{PrintManagerHeaderFiles}					
													{GraphicsHeaderFiles}						
													"{Sources}LaserWriterIISC.make"			
													"{Sources}LaserSCResources.h" 			
													"{Sources}LaserSCIntf.h"					
													"{Sources}SCPrinterStatus.h"				
													"{Sources}UniversalMessageIntf.h"
	Echo "Compiling UniversalMessageIntf.c"
	C "{Sources}UniversalMessageIntf.c" -o "{Objects}UniversalMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - ChooserSupport.c ==========

"{Objects}ChooserSupport.c.o"		"{Sources}ChooserSupport.c"		
											{PrintManagerHeaderFiles}			
											{GraphicsHeaderFiles}				
											"{Sources}LaserWriterIISC.make"	
											"{Sources}ChooserSupport.a" 		
											"{Sources}ChooserSupport.r" 			
	Echo "Compiling ChooserSupport.c"
	C "{Sources}ChooserSupport.c" -o "{Objects}ChooserSupport.c.o"  {COptions}


